-- ---------------------------------------------------------------------------
-- Система:   "Электронный архив"
-- Модуль:    SQL-команды для первоначального заполнения справочных
--            и основных таблиц базы данных "Электронный архив"
-- Автор:     Моргунов Е. П.
-- Дата:      15.04.2012
-- Версия:    0.6
-- ---------------------------------------------------------------------------

-- ---------------------------------------------------------------------------
-- Команды для заполнения справочных таблиц базы данных
-- ---------------------------------------------------------------------------

BEGIN;

-- ---------------------------------------------------------------------------
-- Таблица "Пользователи"
-- ---------------------------------------------------------------------------
INSERT INTO Users VALUES ( 'admin', 'Администратор системы', 'yes' );
INSERT INTO Users VALUES ( 'admin_d', 'Администратор системы ' ||
                                      '(с правом удаления записей)',
                            'yes' );
INSERT INTO Users VALUES ( 'debug', 'Администратор системы (режим отладки)',
                           'yes' );
INSERT INTO Users VALUES ( 'debug_d', 'Администратор системы ' ||
                                      '(с правом удаления записей) ' ||
                                      '(режим отладки)',
                           'yes' );

-- ---------------------------------------------------------------------------
-- Таблица "Права доступа"
-- ---------------------------------------------------------------------------
-- пользователи admin и debug не могут выполнять операцию удаления во всех
-- модулях (это сделано для того, чтобы для выполнения деструктивных действий
-- пользователь осуществлял специальный вход, т. е. выполнял удаление данных
-- осознанно)
INSERT INTO Access VALUES ( 'admin', 'ALL', 'ALL', 'yes' );
INSERT INTO Access VALUES ( 'admin', 'ALL', 'DELETE', 'no' );

INSERT INTO Access VALUES ( 'debug', 'ALL', 'ALL', 'yes' );
INSERT INTO Access VALUES ( 'debug', 'ALL', 'DELETE', 'no' );

-- для выполнения операций удаления во всех модулях созданы специальные 
-- учетные записи, которыми рекомендуется пользоваться для выполнения
-- операций удаления, хотя и реализована функции запроса подтверждения
-- деструктивных действий пользователя
INSERT INTO Access VALUES ( 'admin_d', 'ALL', 'ALL', 'yes' );
INSERT INTO Access VALUES ( 'debug_d', 'ALL', 'ALL', 'yes' );


-- ---------------------------------------------------------------------------
-- Таблица "Языки"
-- ---------------------------------------------------------------------------
INSERT INTO Langs VALUES ( 1, 'русский', 'рус.' );
INSERT INTO Langs VALUES ( 2, 'английский', 'англ.' );
INSERT INTO Langs VALUES ( 3, 'немецкий', 'нем.' );
INSERT INTO Langs VALUES ( 4, 'испанский', 'исп.' );
INSERT INTO Langs VALUES ( 5, 'китайский', 'кит.' );
INSERT INTO Langs VALUES ( 6, 'португальский', 'порт.' );
INSERT INTO Langs VALUES ( 7, 'турецкий', 'тур.' );
INSERT INTO Langs VALUES ( 8, 'польский', 'польск.' );
INSERT INTO Langs VALUES ( 9, 'чешский', 'чеш.' );


-- ---------------------------------------------------------------------------
-- Таблица "Каналы поступления"
-- ---------------------------------------------------------------------------
-- эта запись нужна в тех случаях, когда канал поступления не известен,
-- но конкретное значение ввести все же требуется
-- ПРИМЕЧАНИЕ. Выбрана такая формулировка -- 'фиктивный канал' -- по некоторым
--             соображениям, которые по прошествии времени уже кажутся
--             не столь убедительными. Однако подобные 'фиктивные' значения
--             используются еще в целом ряде таблиц-справочников. Возможно,
--             есть и более благозвучный вариант. Нужно подумать.
INSERT INTO Acq_ways VALUES ( 0, 'фиктивный канал поступления',
                                 'фиктивный канал' );
INSERT INTO Acq_ways VALUES ( 1, 'покупка в книжном магазине',
                                 'книжный магазин' );
INSERT INTO Acq_ways VALUES ( 2, 'книги родителей', 'книги родителей' );
INSERT INTO Acq_ways VALUES ( 3, 'получено в подарок', 'подарок' );
INSERT INTO Acq_ways VALUES ( 4, 'найдено в сети Internet', 'Internet' );
INSERT INTO Acq_ways VALUES ( 5, 'копирование в библиотеке',
                                 'копир. в библиотеке',
                                 'различные виды копий: ксерокопии и др.' );
INSERT INTO Acq_ways VALUES ( 6, 'приобретено или получено на конференции',
                                 'конференция' );
INSERT INTO Acq_ways VALUES ( 7, 'другой канал поступления', 'другое' );


-- ---------------------------------------------------------------------------
-- Таблица "Коды видов деятельности организаций, учреждений"
-- ---------------------------------------------------------------------------
INSERT INTO Activity_types VALUES ( 1, 'научная', 'науч.' );
INSERT INTO Activity_types VALUES ( 2, 'образовательная', 'образоват.' );
INSERT INTO Activity_types VALUES ( 3, 'издательская', 'издат.' );
INSERT INTO Activity_types VALUES ( 4, 'библиотечная', 'библиотеч.' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды статуса мероприятий"
-- ---------------------------------------------------------------------------
INSERT INTO Conf_status_types VALUES ( 1, 'Всероссийская', 'Всеросс.' );
INSERT INTO Conf_status_types VALUES ( 2, 'Международная', 'Междунар.' );
INSERT INTO Conf_status_types VALUES ( 3, 'региональная', 'регион.' );
INSERT INTO Conf_status_types VALUES ( 4, 'межрегиональная', 'межрегион.' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды мероприятий"
-- ---------------------------------------------------------------------------
INSERT INTO Conf_types VALUES ( 1, 'конференция', 'конф.' );
INSERT INTO Conf_types VALUES ( 2, 'научная конференция', 'науч. конф.' );
INSERT INTO Conf_types VALUES ( 3, 'научно-методическая конференция',
                                   'науч.-метод. конф.' );
INSERT INTO Conf_types VALUES ( 4, 'научно-практическая конференция',
                                   'науч.-практ. конф.' );
INSERT INTO Conf_types VALUES ( 5, 'симпозиум', 'симпозиум' );
INSERT INTO Conf_types VALUES ( 6, 'конгресс', 'конгресс' );
INSERT INTO Conf_types VALUES ( 7, 'семинар', 'семинар' );


-- ---------------------------------------------------------------------------
-- Таблица "Страны"
-- ---------------------------------------------------------------------------
-- код языка 1 -- русский язык
-- код языка 2 -- английский язык
INSERT INTO Countries VALUES ( 0, 'фиктивная страна', 'фиктивная страна',
                               null, 1 );
INSERT INTO Countries VALUES ( 1, 'Российская Федерация', 'Россия', null, 1 );
INSERT INTO Countries VALUES ( 2, 'Союз Советских Социалистических Республик',
                                  'СССР', 1, 1 );
INSERT INTO Countries VALUES ( 3, 'Соединенные Штаты Америки', 'США',
                                  null, 1 );
INSERT INTO Countries VALUES ( 4, 'Соединенное Королевство Великобритании ' ||
                                  'и Северной Ирландии',
                                  'Великобритания', null, 1 );
INSERT INTO Countries VALUES ( 5, 'Федеративная Республика Германия', 'ФРГ',
                                  null, 1 );
INSERT INTO Countries VALUES ( 6, 'Французская Республика', 'Франция',
                                  null, 1 );
INSERT INTO Countries VALUES ( 7, 'Итальянская Республика', 'Италиия',
                                  null, 1 );
INSERT INTO Countries VALUES ( 8, 'Испания', 'Испания', null, 1 );
INSERT INTO Countries VALUES ( 9, 'United States of America', 'USA', null, 2 );
INSERT INTO Countries VALUES ( 10, 'Украина', 'Украина', null, 1 );
INSERT INTO Countries VALUES ( 11, 'Great Britain', 'Great Britain', null, 2 );
INSERT INTO Countries VALUES ( 12, 'Netherlands', 'Netherlands', null, 2 );
INSERT INTO Countries VALUES ( 13, 'Нидерланды', 'Нидерланды', 12, 1 );
INSERT INTO Countries VALUES ( 14, 'Singapore', 'Singapore', null, 2 );
INSERT INTO Countries VALUES ( 15, 'Сингапур', 'Сингапур', 14, 1 );
INSERT INTO Countries VALUES ( 16, 'Латвия', 'Латвия', null, 1 );
INSERT INTO Countries VALUES ( 17, 'India', 'India', null, 2 );
INSERT INTO Countries VALUES ( 18, 'Индия', 'Индия', 17, 1 );
-- значения кодов стран, являющихся началом цепочки для США и Великобритании,
-- введем путем обновления записей, по-другому внешний ключ не позволит
UPDATE Countries SET country_code_orig = 9 WHERE country_code = 3;
UPDATE Countries SET country_code_orig = 11 WHERE country_code = 4;


-- ---------------------------------------------------------------------------
-- Таблица "Города"
-- ПРИМЕЧАНИЕ. Если страна, в которой находится город, меняла свое
--             наименование (или распадалась и т. п.), то можно вводить более
--             одной записи для данного города. Если название города
--             приводится на разных языках, то следует ввести в таблицу записи
--             для каждого языка, а в таблицу Countries также следует ввести
--             записи на этих языках.
-- ---------------------------------------------------------------------------
INSERT INTO Cities VALUES ( 0, 0, null, 'фиктивный город',
                            'фиктивный город', null, 1 );
INSERT INTO Cities VALUES ( 1, 1, null, 'Москва', 'М.', null, 1 );
INSERT INTO Cities VALUES ( 2, 1, null, 'Санкт-Петербург', 'СПб.',
                            null, 1 );
INSERT INTO Cities VALUES ( 3, 2, null, 'Ленинград', 'Л.',
                            2, 1 );
INSERT INTO Cities VALUES ( 4, 1, 'Красноярский край', 'Красноярск',
                            'Красноярск', null, 1 );
INSERT INTO Cities VALUES ( 5, 1, 'Оренбургская область', 'Оренбург',
                            'Оренбург', null, 1 );
INSERT INTO Cities VALUES ( 6, 11, null, 'London', 'London', null, 2 );
INSERT INTO Cities VALUES ( 7, 4, null, 'Лондон', 'Лондон', 6, 1 );


-- ---------------------------------------------------------------------------
-- Таблица "Валюты"
-- ---------------------------------------------------------------------------
INSERT INTO Currencies VALUES ( 0, 'фиктивная валюта', 'фиктивная валюта', 0,
                                null, null, 1 );
INSERT INTO Currencies VALUES ( 1, 'российский рубль', 'рубль', 1,
                                '1991-12-12', null, 1 );
INSERT INTO Currencies VALUES ( 2, 'рубль СССР', 'рубль', 2,
                                '1922-12-30', 1, 1 );
INSERT INTO Currencies VALUES ( 3, 'Доллар США', 'Доллар США', 3,
                                null, null, 1 );


-- ---------------------------------------------------------------------------
-- Таблица "Типы связей между объектами библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Dep_types VALUES ( 1, 'том многотомного издания', 'том' );
INSERT INTO Dep_types VALUES ( 2, 'выпуск сериального издания', 'выпуск' );

-- ПРИМЕЧАНИЕ. Для обратимых связей нужно вводить по 2 записи.
--             Например, "Книга является переводом книги такой-то" и
--             "Книга является оригинальным изданием для такого-то переводного
--             издания".


-- ---------------------------------------------------------------------------
-- Таблица "Виды характеристик объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Det_char_types VALUES ( 1, 'сложность материала', 'сложность' );
INSERT INTO Det_char_types VALUES ( 2, 'практическая полезность сведений',
                                       'полезность',
       'Подразумевается ориентация на практическое использование ' ||
       'полученных сведений (например, при выполнении научной или ' ||
       'преподавательской работы, при решении каких-либо иных ' ||
       'практических задач, которые могут возникнуть с некоторой ' ||
       'вероятностью).' );
INSERT INTO Det_char_types VALUES ( 3, 'доходчивость изложения',
                                    'доходчивость' );
INSERT INTO Det_char_types VALUES ( 4, 'легкость восприятия языка текста',
                                    'язык текста' );
INSERT INTO Det_char_types VALUES ( 5, 'объем и качество иллюстраций',
                                    'иллюстрации',
       'Имеется в виду не полиграфическое качество, а смысловое, ' ||
       'содержательное.' );
INSERT INTO Det_char_types VALUES ( 6, 'информативность', 'информативность',
       'Насколько информация, содержащаяся в источнике, является новой для ' ||
       'меня. Позволяет ли данный источник узнать что-то новое.' );
INSERT INTO Det_char_types VALUES ( 7, 'интересность', 'интересность',
       'Насколько данный источник интересно читать.' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды тиражей"
-- ---------------------------------------------------------------------------
INSERT INTO Edition_types VALUES ( 1, 'основной тираж' );
INSERT INTO Edition_types VALUES ( 2, 'допечатка тиража' );
INSERT INTO Edition_types VALUES ( 3, 'разовый тираж сериального издания' );


-- ---------------------------------------------------------------------------
-- Таблица "Группы признаков объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Feature_groups VALUES ( 1, 'Виды изданий по целевому назначению',
                                       'ОСТ 29.130--97 (п. 2.1)' );
INSERT INTO Feature_groups VALUES ( 2, 'Виды изданий по читательскому адресу',
                                       'ОСТ 29.130--97 (п. 2.2)' );
INSERT INTO Feature_groups VALUES ( 3, 'Виды изданий по характеру информации' ||
                                       ' (Виды научных изданий)',
                                       'ОСТ 29.130--97 (п. 2.3.1)' );
INSERT INTO Feature_groups VALUES ( 4, 'Виды изданий по характеру информации' ||
                                       ' (Виды официальных и нормативных' ||
                                       ' изданий)',
                                       'ОСТ 29.130--97 (п. 2.3.2)' );
INSERT INTO Feature_groups VALUES ( 5, 'Виды изданий по характеру информации' ||
                                       ' (Виды производственно-практических' ||
                                       ' изданий)',
                                       'ОСТ 29.130--97 (п. 2.3.3)' );
INSERT INTO Feature_groups VALUES ( 6, 'Виды изданий по характеру информации' ||
                                       ' (Виды учебных изданий)',
                                       'ОСТ 29.130--97 (п. 2.3.4)' );
INSERT INTO Feature_groups VALUES ( 7, 'Виды изданий по характеру информации' ||
                                       ' (Виды справочных и рекламных изданий)',
                                       'ОСТ 29.130--97 (п. 2.3.5)' );
INSERT INTO Feature_groups VALUES ( 8, 'Виды изданий по характеру информации' ||
                                       ' (Виды литературно-художественных' ||
                                       ' изданий)',
                                       'ОСТ 29.130--97 (п. 2.3.6)' );
INSERT INTO Feature_groups VALUES ( 9, 'Виды изданий по степени аналитико-' ||
                                       'синтетической переработки информации',
                                       'ОСТ 29.130--97 (п. 2.4)' );
INSERT INTO Feature_groups VALUES ( 10, 'Виды изданий по оригинальности ' ||
                                        'содержания',
                                        'ОСТ 29.130--97 (п. 2.5)' );
INSERT INTO Feature_groups VALUES ( 11, 'Виды изданий по знаковой природе ' ||
                                        'информации',
                                        'ОСТ 29.130--97 (п. 2.6)' );
INSERT INTO Feature_groups VALUES ( 12, 'Виды изданий по составу основного ' ||
                                        'текста',
                                        'ОСТ 29.130--97 (п. 2.7)' );
INSERT INTO Feature_groups VALUES ( 13, 'Виды изданий по способу организации',
                                        'ОСТ 29.130--97 (п. 2.8)' );
INSERT INTO Feature_groups VALUES ( 14, 'Виды изданий по периодичности ' ||
                                        'выпуска',
                                        'ОСТ 29.130--97 (п. 2.9)' );
INSERT INTO Feature_groups VALUES ( 15, 'Виды периодических и продолжающихся' ||
                                        ' изданий',
                                        'ОСТ 29.130--97 (п. 2.10)' );
INSERT INTO Feature_groups VALUES ( 16, 'Виды изданий по материальной ' ||
                                        'конструкции',
                                        'ОСТ 29.130--97 (п. 2.11)' );
INSERT INTO Feature_groups VALUES ( 17, 'Виды изданий по объему и тиражу',
                                        'ОСТ 29.130--97 (п. 2.12)' );
INSERT INTO Feature_groups VALUES ( 18, 'Виды изданий по формату',
                                        'ОСТ 29.130--97 (п. 2.13)' );
INSERT INTO Feature_groups VALUES ( 19, 'Виды изданий по характеру ' ||
                                        'оформления и способу ' ||
                                        'полиграфического исполнения',
                                        'ОСТ 29.130--97 (п. 2.14)' );
INSERT INTO Feature_groups VALUES ( 20, 'Виды изданий по принадлежности ' ||
                                        'издателю, автору',
                                        'ОСТ 29.130--97 (п. 2.15)' );
INSERT INTO Feature_groups VALUES ( 21, 'Виды изданий по характеру обращения',
                                        'ОСТ 29.130--97 (п. 2.16)' );
INSERT INTO Feature_groups VALUES ( 22, 'Виды изданий: первое издание и ' ||
                                        'переиздание',
                                        'ОСТ 29.130--97 (п. 2.17)' );
INSERT INTO Feature_groups VALUES ( 23, 'Виды изданий: издания, выпущенные ' ||
                                        'в честь какого-либо события или лица',
                                        'ОСТ 29.130--97 (п. 2.18)' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды признаков объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Feature_types VALUES ( 1, 1, 'Массово-политическое издание',
                                         'ОСТ 29.130--97 (п. 2.1.1)' );
INSERT INTO Feature_types VALUES ( 2, 1, 'Научное издание',
                                         'ОСТ 29.130--97 (п. 2.1.2)' );
INSERT INTO Feature_types VALUES ( 3, 1, 'Научно-популярное издание',
                                         'ОСТ 29.130--97 (п. 2.1.3)' );
INSERT INTO Feature_types VALUES ( 4, 1, 'Официальное издание',
                                         'ОСТ 29.130--97 (п. 2.1.4)' );
INSERT INTO Feature_types VALUES ( 5, 1, 'Производственно-практическое ' ||
                                         'издание',
                                         'ОСТ 29.130--97 (п. 2.1.5)' );
INSERT INTO Feature_types VALUES ( 6, 1, 'Нормативное производственно-' ||
                                         'практическое издание',
                                         'ОСТ 29.130--97 (п. 2.1.6)' );
INSERT INTO Feature_types VALUES ( 7, 1, 'Учебное издание',
                                         'ОСТ 29.130--97 (п. 2.1.7)' );
INSERT INTO Feature_types VALUES ( 8, 1, 'Справочное издание',
                                         'ОСТ 29.130--97 (п. 2.1.8)' );
INSERT INTO Feature_types VALUES ( 9, 1, 'Издание для досуга',
                                         'ОСТ 29.130--97 (п. 2.1.9)' );
INSERT INTO Feature_types VALUES ( 10, 1, 'Информационное издание',
                                          'ОСТ 29.130--97 (п. 2.1.10)' );
INSERT INTO Feature_types VALUES ( 11, 1, 'Рекламное издание',
                                          'ОСТ 29.130--97 (п. 2.1.11)' );
INSERT INTO Feature_types VALUES ( 12, 1, 'Литературно-художественное издание',
                                          'ОСТ 29.130--97 (п. 2.1.12)' );

INSERT INTO Feature_types VALUES ( 13, 2, 'Адаптированное издание',
                                          'ОСТ 29.130--97 (п. 2.2.1)' );
INSERT INTO Feature_types VALUES ( 14, 2, 'Библиотечное издание',
                                          'ОСТ 29.130--97 (п. 2.2.2)' );
INSERT INTO Feature_types VALUES ( 15, 2, 'Библиофильское издание',
                                          'ОСТ 29.130--97 (п. 2.2.3)' );
INSERT INTO Feature_types VALUES ( 16, 2, 'Издание для служебного пользования',
                                          'ОСТ 29.130--97 (п. 2.2.4)' );
INSERT INTO Feature_types VALUES ( 17, 2, 'Издание для детей и юношества',
                                          'ОСТ 29.130--97 (п. 2.2.5)' );
INSERT INTO Feature_types VALUES ( 18, 2, 'Массовое издание',
                                          'ОСТ 29.130--97 (п. 2.2.6)' );
INSERT INTO Feature_types VALUES ( 19, 2, 'Популярное издание',
                                          'ОСТ 29.130--97 (п. 2.2.7)' );
INSERT INTO Feature_types VALUES ( 20, 2, 'Элитарное издание',
                                          'ОСТ 29.130--97 (п. 2.2.8)' );

INSERT INTO Feature_types VALUES ( 21, 3, 'Введение',
                                          'ОСТ 29.130--97 (п. 2.3.1-1)' );
INSERT INTO Feature_types VALUES ( 22, 3, 'Документальное издание',
                                          'ОСТ 29.130--97 (п. 2.3.1-2)' );
INSERT INTO Feature_types VALUES ( 23, 3, 'Монография',
                                          'ОСТ 29.130--97 (п. 2.3.1-3)' );
INSERT INTO Feature_types VALUES ( 24, 3, 'Препринт',
                                          'ОСТ 29.130--97 (п. 2.3.1-4)' );
INSERT INTO Feature_types VALUES ( 25, 3, 'Тезисы докладов/сообщений ' ||
                                          'научной конференции (съезда, ' ||
                                          'симпозиума)',
                                          'ОСТ 29.130--97 (п. 2.3.1-5)' );
INSERT INTO Feature_types VALUES ( 26, 3, 'Материалы конференции (съезда, ' ||
                                          'симпозиума)',
                                          'ОСТ 29.130--97 (п. 2.3.1-6)' );
INSERT INTO Feature_types VALUES ( 27, 3, 'Сборник научных трудов',
                                          'ОСТ 29.130--97 (п. 2.3.1-7)' );

INSERT INTO Feature_types VALUES ( 28, 4, 'Инструкция',
                                          'ОСТ 29.130--97 (п. 2.3.2-1)' );
INSERT INTO Feature_types VALUES ( 29, 4, 'Прейскурант',
                                          'ОСТ 29.130--97 (п. 2.3.2-2)' );
INSERT INTO Feature_types VALUES ( 30, 4, 'Стандарт',
                                          'ОСТ 29.130--97 (п. 2.3.2-3)' );
INSERT INTO Feature_types VALUES ( 31, 4, 'Технические условия',
                                          'ОСТ 29.130--97 (п. 2.3.2-4)' );
INSERT INTO Feature_types VALUES ( 32, 4, 'Уставное издание',
                                          'ОСТ 29.130--97 (п. 2.3.2-5)' );

INSERT INTO Feature_types VALUES ( 33, 5, 'Инструктивно-методическое издание',
                                          'ОСТ 29.130--97 (п. 2.3.3-1)' );
INSERT INTO Feature_types VALUES ( 34, 5, 'Номенклатурный каталог',
                                          'ОСТ 29.130--97 (п. 2.3.3-2)' );
INSERT INTO Feature_types VALUES ( 35, 5, 'Промышленный каталог',
                                          'ОСТ 29.130--97 (п. 2.3.3-3)' );
INSERT INTO Feature_types VALUES ( 36, 5, 'Памятка',
                                          'ОСТ 29.130--97 (п. 2.3.3-4)' );
INSERT INTO Feature_types VALUES ( 37, 5, 'Практическое пособие',
                                          'ОСТ 29.130--97 (п. 2.3.3-5)' );
INSERT INTO Feature_types VALUES ( 38, 5, 'Практическое руководство',
                                          'ОСТ 29.130--97 (п. 2.3.3-6)' );

INSERT INTO Feature_types VALUES ( 39, 6, 'Учебник',
                                          'ОСТ 29.130--97 (п. 2.3.4-1)' );
INSERT INTO Feature_types VALUES ( 40, 6, 'Букварь',
                                          'ОСТ 29.130--97 (п. 2.3.4-1.1)' );
INSERT INTO Feature_types VALUES ( 41, 6, 'Учебное пособие',
                                          'ОСТ 29.130--97 (п. 2.3.4-2)' );
INSERT INTO Feature_types VALUES ( 42, 6, 'Учебно-методическое пособие',
                                          'ОСТ 29.130--97 (п. 2.3.4-2.1)' );
INSERT INTO Feature_types VALUES ( 43, 6, 'Учебное наглядное пособие',
                                          'ОСТ 29.130--97 (п. 2.3.4-2.2)' );
INSERT INTO Feature_types VALUES ( 44, 6, 'Рабочая тетрадь',
                                          'ОСТ 29.130--97 (п. 2.3.4-2.3)' );
INSERT INTO Feature_types VALUES ( 45, 6, 'Самоучитель',
                                          'ОСТ 29.130--97 (п. 2.3.4-2.4)' );
INSERT INTO Feature_types VALUES ( 46, 6, 'Хрестоматия',
                                          'ОСТ 29.130--97 (п. 2.3.4-2.5)' );
INSERT INTO Feature_types VALUES ( 47, 6, 'Практикум',
                                          'ОСТ 29.130--97 (п. 2.3.4-3)' );
INSERT INTO Feature_types VALUES ( 48, 6, 'Задачник',
                                          'ОСТ 29.130--97 (п. 2.3.4-3.1)' );
INSERT INTO Feature_types VALUES ( 49, 6, 'Учебная программа',
                                          'ОСТ 29.130--97 (п. 2.3.4-4)' );

INSERT INTO Feature_types VALUES ( 50, 7, 'Энциклопедия',
                                          'ОСТ 29.130--97 (п. 2.3.5-1)' );
INSERT INTO Feature_types VALUES ( 51, 7, 'Словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2)' );
INSERT INTO Feature_types VALUES ( 52, 7, 'Энциклопедический словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.1)' );
INSERT INTO Feature_types VALUES ( 53, 7, 'Языковой словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2)' );
INSERT INTO Feature_types VALUES ( 54, 7, 'Идеографический словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.1)' );
INSERT INTO Feature_types VALUES ( 55, 7, 'Орфографический словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.2)' );
INSERT INTO Feature_types VALUES ( 56, 7, 'Орфоэпический словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.3)' );
INSERT INTO Feature_types VALUES ( 57, 7, 'Переводной словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.4)' );
INSERT INTO Feature_types VALUES ( 58, 7, 'Разговорник',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.4.1)' );
INSERT INTO Feature_types VALUES ( 59, 7, 'Толковый словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.5)' );
INSERT INTO Feature_types VALUES ( 60, 7, 'Частотный словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.6)' );
INSERT INTO Feature_types VALUES ( 61, 7, 'Этимологический словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.2.7)' );
INSERT INTO Feature_types VALUES ( 62, 7, 'Терминологический словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-2.3)' );
INSERT INTO Feature_types VALUES ( 63, 7, 'Справочник',
                                          'ОСТ 29.130--97 (п. 2.3.5-3)' );
INSERT INTO Feature_types VALUES ( 64, 7, 'Адресная/телефонная книга',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.1)' );
INSERT INTO Feature_types VALUES ( 65, 7, 'Каталог',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.2)' );
INSERT INTO Feature_types VALUES ( 66, 7, 'Каталог аукциона',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.2.1)' );
INSERT INTO Feature_types VALUES ( 67, 7, 'Каталог выставки',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.2.2)' );
INSERT INTO Feature_types VALUES ( 68, 7, 'Музейный каталог',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.2.3)' );
INSERT INTO Feature_types VALUES ( 69, 7, 'Проспект',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.3)' );
INSERT INTO Feature_types VALUES ( 70, 7, 'Путеводитель',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.4)' );
INSERT INTO Feature_types VALUES ( 71, 7, 'Биографический справочник/словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.5)' );
INSERT INTO Feature_types VALUES ( 72, 7, 'Биобиблиографический справочник/' ||
                                          'словарь',
                                          'ОСТ 29.130--97 (п. 2.3.5-3.6)' );
INSERT INTO Feature_types VALUES ( 73, 7, 'Афиша',
                                          'ОСТ 29.130--97 (п. 2.3.5-4)' );

INSERT INTO Feature_types VALUES ( 74, 8, 'Альманах',
                                          'ОСТ 29.130--97 (п. 2.3.6-1)' );
INSERT INTO Feature_types VALUES ( 75, 8, 'Антология',
                                          'ОСТ 29.130--97 (п. 2.3.6-2)' );
INSERT INTO Feature_types VALUES ( 76, 8, 'Документально-художественное ' ||
                                          'издание',
                                          'ОСТ 29.130--97 (п. 2.3.6-3)' );
INSERT INTO Feature_types VALUES ( 77, 8, 'Научно-художественное издание',
                                          'ОСТ 29.130--97 (п. 2.3.6-4)' );
INSERT INTO Feature_types VALUES ( 78, 8, 'Песенник',
                                          'ОСТ 29.130--97 (п. 2.3.6-5)' );

INSERT INTO Feature_types VALUES ( 79, 9, 'Автореферат диссертации',
                                          'ОСТ 29.130--97 (п. 2.4.1)' );
INSERT INTO Feature_types VALUES ( 80, 9, 'Библиографическое издание',
                                          'ОСТ 29.130--97 (п. 2.4.2)' );
INSERT INTO Feature_types VALUES ( 81, 9, 'Аннотированный тематический ' ||
                                          'план выпуска изданий',
                                          'ОСТ 29.130--97 (п. 2.4.2-1)' );
INSERT INTO Feature_types VALUES ( 82, 9, 'Библиографический указатель',
                                          'ОСТ 29.130--97 (п. 2.4.2-2)' );
INSERT INTO Feature_types VALUES ( 83, 9, 'Государственный ' ||
                                          'библиографический указатель',
                                          'ОСТ 29.130--97 (п. 2.4.2-2.1)' );
INSERT INTO Feature_types VALUES ( 84, 9, 'Издательский библиографический ' ||
                                          'указатель; Издательский каталог',
                                          'ОСТ 29.130--97 (п. 2.4.2-2.2)' );
INSERT INTO Feature_types VALUES ( 85, 9, 'Книготорговый библиографический ' ||
                                          'указатель; Книготорговый каталог',
                                          'ОСТ 29.130--97 (п. 2.4.2-2.3)' );
INSERT INTO Feature_types VALUES ( 86, 9, 'Печатная каталожная карточка',
                                          'ОСТ 29.130--97 (п. 2.4.2-3)' );
INSERT INTO Feature_types VALUES ( 87, 9, 'Обзорное издание',
                                          'ОСТ 29.130--97 (п. 2.4.3)' );
INSERT INTO Feature_types VALUES ( 88, 9, 'Библиографический обзор',
                                          'ОСТ 29.130--97 (п. 2.4.3-1)' );
INSERT INTO Feature_types VALUES ( 89, 9, 'Реферативное издание',
                                          'ОСТ 29.130--97 (п. 2.4.4)' );
INSERT INTO Feature_types VALUES ( 90, 9, 'Информационный листок',
                                          'ОСТ 29.130--97 (п. 2.4.4-1)' );
INSERT INTO Feature_types VALUES ( 91, 9, 'Реферативный сборник',
                                          'ОСТ 29.130--97 (п. 2.4.4-2)' );
INSERT INTO Feature_types VALUES ( 92, 9, 'Экспресс-информация',
                                          'ОСТ 29.130--97 (п. 2.4.4-3)' );

INSERT INTO Feature_types VALUES ( 93, 10, 'Издание с параллельным текстом',
                                           'ОСТ 29.130--97 (п. 2.5.1)' );
INSERT INTO Feature_types VALUES ( 94, 10, 'Многоязычное издание',
                                           'ОСТ 29.130--97 (п. 2.5.2)' );
INSERT INTO Feature_types VALUES ( 95, 10, 'Оригинальное издание (1) ' ||
                                           '(издание впервые вышедшее на ' ||
                                           'языке оригинала)',
                                           'ОСТ 29.130--97 (п. 2.5.3)' );
INSERT INTO Feature_types VALUES ( 96, 10, 'Оригинальное издание (2) ' ||
                                           '(издание произведения, не ' ||
                                           'повторяющее ранее выпущенные ' ||
                                           'издания, отличающееся от них ' ||
                                           'новым издательским и худож.-' ||
                                           'полиграф. решением)',
                                           'ОСТ 29.130--97 (п. 2.5.4)' );
INSERT INTO Feature_types VALUES ( 97, 10, 'Параллельное издание',
                                           'ОСТ 29.130--97 (п. 2.5.5)' );
INSERT INTO Feature_types VALUES ( 98, 10, 'Переводное издание',
                                           'ОСТ 29.130--97 (п. 2.5.6)' );

INSERT INTO Feature_types VALUES ( 99, 11, 'Текстовое издание',
                                           'ОСТ 29.130--97 (п. 2.6.1)' );
INSERT INTO Feature_types VALUES ( 100, 11, 'Изоиздание',
                                            'ОСТ 29.130--97 (п. 2.6.2)' );
INSERT INTO Feature_types VALUES ( 101, 11, 'Альбом',
                                            'ОСТ 29.130--97 (п. 2.6.2-1)' );
INSERT INTO Feature_types VALUES ( 102, 11, 'Художественный альбом',
                                            'ОСТ 29.130--97 (п. 2.6.2-1.1)' );
INSERT INTO Feature_types VALUES ( 103, 11, 'Технический альбом',
                                            'ОСТ 29.130--97 (п. 2.6.2-1.2)' );
INSERT INTO Feature_types VALUES ( 104, 11, 'Фотоальбом',
                                            'ОСТ 29.130--97 (п. 2.6.2-1.3)' );
INSERT INTO Feature_types VALUES ( 105, 11, 'Атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2)' );
INSERT INTO Feature_types VALUES ( 106, 11, 'Анатомический атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2.1)' );
INSERT INTO Feature_types VALUES ( 107, 11, 'Астрономический атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2.2)' );
INSERT INTO Feature_types VALUES ( 108, 11, 'Ботанический атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2.3)' );
INSERT INTO Feature_types VALUES ( 109, 11, 'Географический атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2.4)' );
INSERT INTO Feature_types VALUES ( 110, 11, 'Зоологический атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2.5)' );
INSERT INTO Feature_types VALUES ( 111, 11, 'Лингвистический атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2.6)' );
INSERT INTO Feature_types VALUES ( 112, 11, 'Медицинский атлас',
                                            'ОСТ 29.130--97 (п. 2.6.2-2.7)' );
INSERT INTO Feature_types VALUES ( 113, 11, 'Изобразительная открытка',
                                            'ОСТ 29.130--97 (п. 2.6.2-3)' );
INSERT INTO Feature_types VALUES ( 114, 11, 'Изобразительный плакат',
                                            'ОСТ 29.130--97 (п. 2.6.2-4)' );
INSERT INTO Feature_types VALUES ( 115, 11, 'Гравюра',
                                            'ОСТ 29.130--97 (п. 2.6.2-5)' );
INSERT INTO Feature_types VALUES ( 116, 11, 'Ксилография',
                                            'ОСТ 29.130--97 (п. 2.6.2-5.1)' );
INSERT INTO Feature_types VALUES ( 117, 11, 'Линогравюра',
                                            'ОСТ 29.130--97 (п. 2.6.2-5.2)' );
INSERT INTO Feature_types VALUES ( 118, 11, 'Литография',
                                            'ОСТ 29.130--97 (п. 2.6.2-5.3)' );
INSERT INTO Feature_types VALUES ( 119, 11, 'Офорт',
                                            'ОСТ 29.130--97 (п. 2.6.2-5.4)' );
INSERT INTO Feature_types VALUES ( 120, 11, 'Эстамп',
                                            'ОСТ 29.130--97 (п. 2.6.2-5.5)' );
INSERT INTO Feature_types VALUES ( 121, 11, 'Книжка-картинка',
                                            'ОСТ 29.130--97 (п. 2.6.2-6)' );
INSERT INTO Feature_types VALUES ( 122, 11, 'Лубочное издание',
                                            'ОСТ 29.130--97 (п. 2.6.2-7)' );
INSERT INTO Feature_types VALUES ( 123, 11, 'Наглядное пособие',
                                            'ОСТ 29.130--97 (п. 2.6.2-8)' );
INSERT INTO Feature_types VALUES ( 124, 11, 'Художественная репродукция',
                                            'ОСТ 29.130--97 (п. 2.6.2-9)' );
INSERT INTO Feature_types VALUES ( 125, 11, 'Олеография',
                                            'ОСТ 29.130--97 (п. 2.6.2-9.1)' );
INSERT INTO Feature_types VALUES ( 126, 11, 'Экслибрис',
                                            'ОСТ 29.130--97 (п. 2.6.2-10)' );
INSERT INTO Feature_types VALUES ( 127, 11, 'Картографическое издание',
                                            'ОСТ 29.130--97 (п. 2.6.3)' );
INSERT INTO Feature_types VALUES ( 128, 11, 'Карта (2) (картографическое ' ||
                                            'листовое издание, содержащее ' ||
                                            'карту (1))',
                                            'ОСТ 29.130--97 (п. 2.6.3-1)' );
INSERT INTO Feature_types VALUES ( 129, 11, 'Карта-схема (2) ' ||
                                            '(картографическое листовое ' ||
                                            'издание, содержащее карту-' ||
                                            'схему (1))',
                                            'ОСТ 29.130--97 (п. 2.6.3-2)' );
INSERT INTO Feature_types VALUES ( 130, 11, 'Издание для слепых',
                                            'ОСТ 29.130--97 (п. 2.6.4)' );
INSERT INTO Feature_types VALUES ( 131, 11, 'Нотное издание',
                                            'ОСТ 29.130--97 (п. 2.6.5)' );

INSERT INTO Feature_types VALUES ( 132, 12, 'Моноиздание',
                                            'ОСТ 29.130--97 (п. 2.7.1)' );
INSERT INTO Feature_types VALUES ( 133, 12, 'Сборник',
                                            'ОСТ 29.130--97 (п. 2.7.2)' );
INSERT INTO Feature_types VALUES ( 134, 12, 'Дайджест',
                                            'ОСТ 29.130--97 (п. 2.7.2-1)' );

INSERT INTO Feature_types VALUES ( 135, 13, 'Однотомное издание; Однотомник',
                                            'ОСТ 29.130--97 (п. 2.8.1)' );
INSERT INTO Feature_types VALUES ( 136, 13, 'Многотомное издание; Многотомник',
                                            'ОСТ 29.130--97 (п. 2.8.2)' );
INSERT INTO Feature_types VALUES ( 137, 13, 'Академическое издание',
                                            'ОСТ 29.130--97 (п. 2.8.3)' );
INSERT INTO Feature_types VALUES ( 138, 13, 'Избранные сочинения; Избранные ' ||
                                            'произведения',
                                            'ОСТ 29.130--97 (п. 2.8.4)' );
INSERT INTO Feature_types VALUES ( 139, 13, 'Собрание сочинений',
                                            'ОСТ 29.130--97 (п. 2.8.5)' );
INSERT INTO Feature_types VALUES ( 140, 13, 'Отдельное издание',
                                            'ОСТ 29.130--97 (п. 2.8.6)' );
INSERT INTO Feature_types VALUES ( 141, 13, 'Приложение (1) (Издание, не ' ||
                                            'имеющее самостоятельного ' ||
                                            'значения...)',
                                            'ОСТ 29.130--97 (п. 2.8.7)' );
INSERT INTO Feature_types VALUES ( 142, 13, 'Приложение (2) (Издание, ' ||
                                            'имеющее самостоятельное ' ||
                                            'значение, распространяемое ' ||
                                            'вместе с основным изданием...)',
                                            'ОСТ 29.130--97 (п. 2.8.8)' );
INSERT INTO Feature_types VALUES ( 143, 13, 'Серия',
                                            'ОСТ 29.130--97 (п. 2.8.9)' );
INSERT INTO Feature_types VALUES ( 144, 13, 'Закрытая серия; "Библиотека"',
                                            'ОСТ 29.130--97 (п. 2.8.9-1)' );
INSERT INTO Feature_types VALUES ( 145, 13, 'Открытая серия',
                                            'ОСТ 29.130--97 (п. 2.8.9-2)' );
INSERT INTO Feature_types VALUES ( 146, 13, 'Библиотечная серия',
                                            'ОСТ 29.130--97 (п. 2.8.9-3)' );
INSERT INTO Feature_types VALUES ( 147, 13, 'Подсерия',
                                            'ОСТ 29.130--97 (п. 2.8.9-4)' );
INSERT INTO Feature_types VALUES ( 148, 13, 'Серийное издание',
                                            'ОСТ 29.130--97 (п. 2.8.10)' );

INSERT INTO Feature_types VALUES ( 149, 14, 'Непериодическое издание',
                                            'ОСТ 29.130--97 (п. 2.9.1)' );
INSERT INTO Feature_types VALUES ( 150, 14, 'Сериальное издание',
                                            'ОСТ 29.130--97 (п. 2.9.2)' );
INSERT INTO Feature_types VALUES ( 151, 14, 'Периодическое издание',
                                            'ОСТ 29.130--97 (п. 2.9.2-1)' );
INSERT INTO Feature_types VALUES ( 152, 14, 'Продолжающееся издание',
                                            'ОСТ 29.130--97 (п. 2.9.2-2)' );

INSERT INTO Feature_types VALUES ( 153, 15, 'Газета',
                                            'ОСТ 29.130--97 (п. 2.10.1)' );
INSERT INTO Feature_types VALUES ( 154, 15, 'Общеполитическая газета',
                                            'ОСТ 29.130--97 (п. 2.10.1-1)' );
INSERT INTO Feature_types VALUES ( 155, 15, 'Специализированная газета',
                                            'ОСТ 29.130--97 (п. 2.10.1-2)' );
INSERT INTO Feature_types VALUES ( 156, 15, 'Специальный газетный выпуск',
                                            'ОСТ 29.130--97 (п. 2.10.1-3)' );
INSERT INTO Feature_types VALUES ( 157, 15, 'Журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2)' );
INSERT INTO Feature_types VALUES ( 158, 15, 'Общественно-политический журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2-1)' );
INSERT INTO Feature_types VALUES ( 159, 15, 'Научный журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2-2)' );
INSERT INTO Feature_types VALUES ( 160, 15, 'Научно-популярный журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2-3)' );
INSERT INTO Feature_types VALUES ( 161, 15, 'Производственно-практический ' ||
                                            'журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2-4)' );
INSERT INTO Feature_types VALUES ( 162, 15, 'Популярный журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2-5)' );
INSERT INTO Feature_types VALUES ( 163, 15, 'Реферативный журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2-6)' );
INSERT INTO Feature_types VALUES ( 164, 15, 'Литературно-художественный ' ||
                                            'журнал',
                                            'ОСТ 29.130--97 (п. 2.10.2-7)' );
INSERT INTO Feature_types VALUES ( 165, 15, 'Бюллетень',
                                            'ОСТ 29.130--97 (п. 2.10.3)' );
INSERT INTO Feature_types VALUES ( 166, 15, 'Нормативный бюллетень',
                                            'ОСТ 29.130--97 (п. 2.10.3-1)' );
INSERT INTO Feature_types VALUES ( 167, 15, 'Справочный бюллетень',
                                            'ОСТ 29.130--97 (п. 2.10.3-2)' );
INSERT INTO Feature_types VALUES ( 168, 15, 'Рекламный бюллетень',
                                            'ОСТ 29.130--97 (п. 2.10.3-3)' );
INSERT INTO Feature_types VALUES ( 169, 15, 'Бюллетень-хроника',
                                            'ОСТ 29.130--97 (п. 2.10.3-4)' );
INSERT INTO Feature_types VALUES ( 170, 15, 'Бюллетень-таблица',
                                            'ОСТ 29.130--97 (п. 2.10.3-5)' );
INSERT INTO Feature_types VALUES ( 171, 15, 'Статистический бюллетень',
                                            'ОСТ 29.130--97 (п. 2.10.3-5.1)' );
INSERT INTO Feature_types VALUES ( 172, 15, 'Календарь',
                                            'ОСТ 29.130--97 (п. 2.10.4)' );
INSERT INTO Feature_types VALUES ( 173, 15, 'Табель-календарь',
                                            'ОСТ 29.130--97 (п. 2.10.4-1)' );
INSERT INTO Feature_types VALUES ( 174, 15, 'Отрывной/перекидной календарь',
                                            'ОСТ 29.130--97 (п. 2.10.4-2)' );
INSERT INTO Feature_types VALUES ( 175, 15, 'Календарь книжного типа',
                                            'ОСТ 29.130--97 (п. 2.10.4-3)' );
INSERT INTO Feature_types VALUES ( 176, 15, 'Календарь знаменательных дат',
                                            'ОСТ 29.130--97 (п. 2.10.4-4)' );

INSERT INTO Feature_types VALUES ( 177, 16, 'Книжное издание',
                                            'ОСТ 29.130--97 (п. 2.11.1)' );
INSERT INTO Feature_types VALUES ( 178, 16, 'Журнальное издание',
                                            'ОСТ 29.130--97 (п. 2.11.2)' );
INSERT INTO Feature_types VALUES ( 179, 16, 'Газетно-журнальное издание',
                                            'ОСТ 29.130--97 (п. 2.11.2-1)' );
INSERT INTO Feature_types VALUES ( 180, 16, 'Листовое издание',
                                            'ОСТ 29.130--97 (п. 2.11.3)' );
INSERT INTO Feature_types VALUES ( 181, 16, 'Газетное издание',
                                            'ОСТ 29.130--97 (п. 2.11.3-1)' );
INSERT INTO Feature_types VALUES ( 182, 16, 'Буклет',
                                            'ОСТ 29.130--97 (п. 2.11.3-2)' );
INSERT INTO Feature_types VALUES ( 183, 16, 'Плакат',
                                            'ОСТ 29.130--97 (п. 2.11.3-3)' );
INSERT INTO Feature_types VALUES ( 184, 16, 'Карточное издание',
                                            'ОСТ 29.130--97 (п. 2.11.3-4)' );
INSERT INTO Feature_types VALUES ( 185, 16, 'Открытка',
                                            'ОСТ 29.130--97 (п. 2.11.3-4.1)' );
INSERT INTO Feature_types VALUES ( 186, 16, 'Книжная закладка',
                                            'ОСТ 29.130--97 (п. 2.11.3-5)' );
INSERT INTO Feature_types VALUES ( 187, 16, 'Книжка-игрушка',
                                            'ОСТ 29.130--97 (п. 2.11.4)' );
INSERT INTO Feature_types VALUES ( 188, 16, 'Книга с двойным входом',
                                            'ОСТ 29.130--97 (п. 2.11.5)' );
INSERT INTO Feature_types VALUES ( 189, 16, 'Комбинированное издание',
                                            'ОСТ 29.130--97 (п. 2.11.6)' );
INSERT INTO Feature_types VALUES ( 190, 16, 'Комплектное издание',
                                            'ОСТ 29.130--97 (п. 2.11.7)' );

INSERT INTO Feature_types VALUES ( 191, 17, 'Брошюра',
                                            'ОСТ 29.130--97 (п. 2.12.1)' );
INSERT INTO Feature_types VALUES ( 192, 17, 'Книга',
                                            'ОСТ 29.130--97 (п. 2.12.2)' );
INSERT INTO Feature_types VALUES ( 193, 17, 'Листовка',
                                            'ОСТ 29.130--97 (п. 2.12.3)' );
INSERT INTO Feature_types VALUES ( 194, 17, 'Малотиражное издание ' ||
                                            '(издание, отпечатанное тиражом ' ||
                                            'менее 1000 экз.)',
                                            'ОСТ 29.130--97 (п. 2.12.4)' );

INSERT INTO Feature_types VALUES ( 195, 18, 'Малоформатное издание',
                                            'ОСТ 29.130--97 (п. 2.13.1)' );
INSERT INTO Feature_types VALUES ( 196, 18, 'Карманное издание',
                                            'ОСТ 29.130--97 (п. 2.13.1-1)' );
INSERT INTO Feature_types VALUES ( 197, 18, 'Миниатюрное издание',
                                            'ОСТ 29.130--97 (п. 2.13.2)' );
INSERT INTO Feature_types VALUES ( 198, 18, 'Портативное издание',
                                            'ОСТ 29.130--97 (п. 2.13.3)' );
INSERT INTO Feature_types VALUES ( 199, 18, 'Фолиант',
                                            'ОСТ 29.130--97 (п. 2.13.4)' );

INSERT INTO Feature_types VALUES ( 200, 19, 'Пейпербек',
                                            'ОСТ 29.130--97 (п. 2.14.1)' );
INSERT INTO Feature_types VALUES ( 201, 19, 'Улучшенное издание',
                                            'ОСТ 29.130--97 (п. 2.14.2)' );
INSERT INTO Feature_types VALUES ( 202, 19, 'Кипсек',
                                            'ОСТ 29.130--97 (п. 2.14.2-1)' );
INSERT INTO Feature_types VALUES ( 203, 19, 'Подарочное издание',
                                            'ОСТ 29.130--97 (п. 2.14.2-2)' );
INSERT INTO Feature_types VALUES ( 204, 19, 'Факсимильное издание',
                                            'ОСТ 29.130--97 (п. 2.14.3)' );
INSERT INTO Feature_types VALUES ( 205, 19, 'Репринтное издание; Репринт',
                                            'ОСТ 29.130--97 (п. 2.14.3-1)' );
INSERT INTO Feature_types VALUES ( 206, 19, 'Ксилографическая книга',
                                            'ОСТ 29.130--97 (п. 2.14.4)' );
INSERT INTO Feature_types VALUES ( 207, 19, 'Литографированное издание',
                                            'ОСТ 29.130--97 (п. 2.14.5)' );

INSERT INTO Feature_types VALUES ( 208, 20, 'Анонимное издание',
                                            'ОСТ 29.130--97 (п. 2.15.1)' );
INSERT INTO Feature_types VALUES ( 209, 20, 'Ведомственное издание',
                                            'ОСТ 29.130--97 (п. 2.15.2)' );
INSERT INTO Feature_types VALUES ( 210, 20, 'Пиратское издание',
                                            'ОСТ 29.130--97 (п. 2.15.3)' );
INSERT INTO Feature_types VALUES ( 211, 20, 'Посмертное издание',
                                            'ОСТ 29.130--97 (п. 2.15.4)' );
INSERT INTO Feature_types VALUES ( 212, 20, 'Прижизненное издание',
                                            'ОСТ 29.130--97 (п. 2.15.5)' );
INSERT INTO Feature_types VALUES ( 213, 20, 'Собственное издание',
                                            'ОСТ 29.130--97 (п. 2.15.6)' );
INSERT INTO Feature_types VALUES ( 214, 20, 'Совместное издание',
                                            'ОСТ 29.130--97 (п. 2.15.7)' );
INSERT INTO Feature_types VALUES ( 215, 20, 'Фирменное издание',
                                            'ОСТ 29.130--97 (п. 2.15.8)' );

INSERT INTO Feature_types VALUES ( 216, 21, 'Бесплатное издание',
                                            'ОСТ 29.130--97 (п. 2.16.1)' );
INSERT INTO Feature_types VALUES ( 217, 21, 'Бестселлер',
                                            'ОСТ 29.130--97 (п. 2.16.2)' );
INSERT INTO Feature_types VALUES ( 218, 21, 'Букинистическая книга',
                                            'ОСТ 29.130--97 (п. 2.16.3)' );
INSERT INTO Feature_types VALUES ( 219, 21, 'Издание на правах рукописи',
                                            'ОСТ 29.130--97 (п. 2.16.4)' );
INSERT INTO Feature_types VALUES ( 220, 21, 'Нумерованное издание',
                                            'ОСТ 29.130--97 (п. 2.16.5)' );
INSERT INTO Feature_types VALUES ( 221, 21, 'Подписное издание',
                                            'ОСТ 29.130--97 (п. 2.16.6)' );
INSERT INTO Feature_types VALUES ( 222, 21, 'Обязательный экземпляр',
                                            'ОСТ 29.130--97 (п. 2.16.7)' );

INSERT INTO Feature_types VALUES ( 223, 22, 'Первое издание',
                                            'ОСТ 29.130--97 (п. 2.17.1)' );
INSERT INTO Feature_types VALUES ( 224, 22, 'Первое отдельное издание',
                                            'ОСТ 29.130--97 (п. 2.17.1-1)' );
INSERT INTO Feature_types VALUES ( 225, 22, 'Переиздание',
                                            'ОСТ 29.130--97 (п. 2.17.2)' );
INSERT INTO Feature_types VALUES ( 226, 22, 'Новое издание',
                                            'ОСТ 29.130--97 (п. 2.17.2-1)' );
INSERT INTO Feature_types VALUES ( 227, 22, 'Дополненное издание',
                                            'ОСТ 29.130--97 (п. 2.17.2-2)' );
INSERT INTO Feature_types VALUES ( 228, 22, 'Исправленное издание',
                                            'ОСТ 29.130--97 (п. 2.17.2-3)' );
INSERT INTO Feature_types VALUES ( 229, 22, 'Переработанное издание',
                                            'ОСТ 29.130--97 (п. 2.17.2-4)' );
INSERT INTO Feature_types VALUES ( 230, 22, 'Пересмотренное издание',
                                            'ОСТ 29.130--97 (п. 2.17.2-5)' );
INSERT INTO Feature_types VALUES ( 231, 22, 'Расширенное издание',
                                            'ОСТ 29.130--97 (п. 2.17.2-6)' );
INSERT INTO Feature_types VALUES ( 232, 22, 'Стереотипное издание (1) ' ||
                                            '(переиздание без изменений)',
                                            'ОСТ 29.130--97 (п. 2.17.2-7)' );
INSERT INTO Feature_types VALUES ( 233, 22, 'Перепечатка',
                                            'ОСТ 29.130--97 (п. 2.17.2-7.1)' );
INSERT INTO Feature_types VALUES ( 234, 22, 'Повторное издание',
                                            'ОСТ 29.130--97 (п. 2.17.2-7.2)' );
INSERT INTO Feature_types VALUES ( 235, 22, 'Стереотипное издание (2) ' ||
                                            '(переиздание, отпечатанное со ' ||
                                            'стереотипов)',
                                            'ОСТ 29.130--97 (п. 2.17.2-7.3)' );

INSERT INTO Feature_types VALUES ( 236, 23, 'Мемориальное издание',
                                            'ОСТ 29.130--97 (п. 2.18.1)' );
INSERT INTO Feature_types VALUES ( 237, 23, 'Юбилейное издание',
                                            'ОСТ 29.130--97 (п. 2.18.2)' );
INSERT INTO Feature_types VALUES ( 238, 13, 'Том многотомного издания',
                                            'Добавлено мною (Е. П. Моргунов)' );
INSERT INTO Feature_types VALUES ( 239, 3, 'Научная статья',
       'Добавлено мною (Е. П. Моргунов), хотя статья не является изданием ' ||
       'в строгом смысле слова. Наличие этого признака призвано упростить ' ||
       'SQL-запросы для поиска научных статей.' );
INSERT INTO Feature_types VALUES ( 240, 13, 'Выпуск сериального издания',
                                            'Добавлено мною (Е. П. Моргунов)' );
INSERT INTO Feature_types VALUES ( 241, 3, 'Диссертация',
       'Добавлено мною (Е. П. Моргунов), хотя диссертация не является ' ||
       'изданием в строгом смысле слова. Наличие этого признака призвано ' ||
       'упростить SQL-запросы для поиска диссертаций.' );


-- ---------------------------------------------------------------------------
-- Таблица "Коды общего обозначения материала"
-- ---------------------------------------------------------------------------
INSERT INTO Gen_mater_types VALUES ( 1, 'Текст', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 2, 'Text', 1, 2 );
INSERT INTO Gen_mater_types VALUES ( 3, 'Видеозапись', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 4, 'Videorecording', 3, 2 );
INSERT INTO Gen_mater_types VALUES ( 5, 'Звукозапись', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 6, 'Sound recording', 5, 2 );
INSERT INTO Gen_mater_types VALUES ( 7, 'Изоматериал', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 8, 'Graphic', 7, 2 );
INSERT INTO Gen_mater_types VALUES ( 9, 'Карты', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 10, 'Cartographic material', 9, 2 );
INSERT INTO Gen_mater_types VALUES ( 11, 'Комплект', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 12, 'Kit', 11, 2 );
INSERT INTO Gen_mater_types VALUES ( 13, 'Кинофильм', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 14, 'Motion picture', 13, 2 );
INSERT INTO Gen_mater_types VALUES ( 15, 'Микроформа', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 16, 'Microform', 15, 2 );
INSERT INTO Gen_mater_types VALUES ( 17, 'Мультимедиа', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 18, 'Multimedia', 17, 2 );
INSERT INTO Gen_mater_types VALUES ( 19, 'Ноты', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 20, 'Music', 19, 2 );
INSERT INTO Gen_mater_types VALUES ( 21, 'Предмет', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 22, 'Object', 21, 2 );
INSERT INTO Gen_mater_types VALUES ( 23, 'Рукопись', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 24, 'Manuscript', 23, 2 );
INSERT INTO Gen_mater_types VALUES ( 25, 'Шрифт Брайля', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 26, 'Braille', 25, 2 );
INSERT INTO Gen_mater_types VALUES ( 27, 'Электронный ресурс', null, 1 );
INSERT INTO Gen_mater_types VALUES ( 28, 'Electronic resource', 27, 2 );


-- ---------------------------------------------------------------------------
-- Таблица "Коды видов упаковки"
-- ---------------------------------------------------------------------------
INSERT INTO Pack_types VALUES ( 1, 'в переплете', 'в пер.' );
INSERT INTO Pack_types VALUES ( 2, 'в коробке', 'в кор.' );
INSERT INTO Pack_types VALUES ( 3, 'в конверте', 'в конв.' );
INSERT INTO Pack_types VALUES ( 4, 'в папке', 'в папке' );
INSERT INTO Pack_types VALUES ( 5, 'в альбоме', 'в альб.' );
INSERT INTO Pack_types VALUES ( 6, 'в мягкой обложке', 'в мягкой обл.',
       'Нестандартный тип упаковки -- добавлен мною (Е. П. Моргунов)' );
INSERT INTO Pack_types VALUES ( 7, 'в бумажной обложке', 'в бум. обл.',
       'Нестандартный тип упаковки -- добавлен мною (Е. П. Моргунов)' );
INSERT INTO Pack_types VALUES ( 8, 'без упаковки', 'без упак.',
       'Добавлено мною, т. к. у электронных изданий, размещаемых на ' ||
       'сайтах, упаковки нет (Е. П. Моргунов)' );
INSERT INTO Pack_types VALUES ( 9, 'не известен', 'не известен',
       'Полезно в тех случаях, когда приходится иметь дело только ' ||
       'с электронными копиями бумажных изданий, например, с pdf-файлом, ' ||
       'содержащим сканированные страницы книги. При этом доступа ' ||
       'к бумажной (оригинальной) версии издания нет (Е. П. Моргунов)' );


-- ---------------------------------------------------------------------------
-- Таблица "Коды физической формы, в которой присутствуют единицы хранения"
-- ---------------------------------------------------------------------------
INSERT INTO Phys_form_types VALUES ( 1, 'в оригинальном виде',
                                        'в ориг. виде' );
INSERT INTO Phys_form_types VALUES ( 2, 'ксерокопия', 'ксерокопия' );
INSERT INTO Phys_form_types VALUES ( 3, 'распечатка из текстового файла',
                                        'распечатка из текстового файла' );
INSERT INTO Phys_form_types VALUES ( 4, 'распечатка из файла образов',
                                        'распечатка из файла образов' );
INSERT INTO Phys_form_types VALUES ( 5, 'файл текстовый оригинальный',
                                        'файл текстовый оригинальный',
       'Это означает, что содержимое файла доступно на уровне отдельных ' ||
       'символов. При этом формат такого файла может быть ascii, pdf, doc ' ||
       'и др. Это может быть, например, файл с текстом научной статьи ' ||
       'в формате pdf, полученный с сайта издательства, выпускающего этот ' ||
       'журнал.' );
INSERT INTO Phys_form_types VALUES ( 6, 'файл с образами фрагментов ' ||
                                        'оригинального материала',
                                        'файл образов',
       'Такой файл содержит образы, например, страниц книги. Каждая ' ||
       'страница доступна только как единое целое. Формат такого файла ' ||
       'может быть pdf, DjVu, jpeg и др. Такие файлы могут сохранять, ' ||
       'естественно, и все дефекты оригинала, например, пометки ' ||
       'в книге-оригинале, сделанные читателем. Фактически, это ' ||
       '-- электронная ксерокопия.' );
INSERT INTO Phys_form_types VALUES ( 7, 'магнитофонная запись с ' ||
                                        'оригинальной грампластинки',
                                        'магнитоф. зап. с ориг. грампл.' );
INSERT INTO Phys_form_types VALUES ( 8, 'рукописная выписка',
                                        'рукописная выписка' );
INSERT INTO Phys_form_types VALUES ( 9, 'рукопись', 'рукопись' );
INSERT INTO Phys_form_types VALUES ( 10, 'копия диска CD/DVD',
                                         'копия диска CD/DVD' );
INSERT INTO Phys_form_types VALUES ( 11, 'файл текстовый неоригинальный',
                                         'файл текстовый неоригинальный',
       'Это означает, что содержимое файла доступно на уровне отдельных ' ||
       'символов. При этом формат такого файла может быть ascii, pdf, doc ' ||
       'и др. Это может быть, например, файл с текстом научной статьи или ' ||
       'книги, созданный на основе оригинального материала путем набора ' ||
       'текста вручную или путем сканирования напечатанного текста ' ||
       'с последующим его распознаванием с помощью программных средств.' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды языковой обработки элементов библиографических описаний"
-- ---------------------------------------------------------------------------
INSERT INTO Process_types VALUES ( 1, 'в оригинале', 'ориг.' );
INSERT INTO Process_types VALUES ( 2, 'в транслитерации', 'транслит.' );
INSERT INTO Process_types VALUES ( 3, 'в транскрипции', 'транскр.' );
INSERT INTO Process_types VALUES ( 4, 'в переводе', 'перев.' );


-- ---------------------------------------------------------------------------
-- Таблица "Коды источников библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Recs_sources VALUES ( 1, 'объект библиографического описания' );
INSERT INTO Recs_sources VALUES ( 2, 'план издательства' );
INSERT INTO Recs_sources VALUES ( 3, 'прайс-лист торговой организации' );
INSERT INTO Recs_sources VALUES ( 4, 'библиографический список в книге, ' ||
                                     'журнале' );
INSERT INTO Recs_sources VALUES ( 5, 'библиографический список в диссертации' );
INSERT INTO Recs_sources VALUES ( 6, 'библиотечный каталог' );
INSERT INTO Recs_sources VALUES ( 7, 'другое' );


-- ---------------------------------------------------------------------------
-- Таблица "Роли"
-- ---------------------------------------------------------------------------
INSERT INTO Roles VALUES ( 1, 'автор', 'автор', null, 1, 1 );
INSERT INTO Roles VALUES ( 2, 'author', 'author', 1, 2, 1 );
INSERT INTO Roles VALUES ( 3, 'переводчик', 'перев.', null, 1, 1 );
INSERT INTO Roles VALUES ( 4, 'автор предисловия', 'авт. предисл.',
                              null, 1, 1 );
INSERT INTO Roles VALUES ( 5, 'редактор перевода', 'ред. перев.', null, 1, 1 );
INSERT INTO Roles VALUES ( 6, 'редактор', 'ред.', null, 1, 1 );
INSERT INTO Roles VALUES ( 7, 'составитель', 'составит.', null, 1, 1 );
INSERT INTO Roles VALUES ( 8, 'редактор (общая редакция)', 'общ. ред.', null,
                              1, 1 );
INSERT INTO Roles VALUES ( 9, 'председатель редакционного совета',
                              'пред. ред. совета', null, 1, 1 );
INSERT INTO Roles VALUES ( 10, 'организация, ответственная за издание',
                               'отв. орг.', null, 1, 1 );
INSERT INTO Roles VALUES ( 11, 'автор послесловия', 'авт. послесл.',
                               null, 1, 1 );
INSERT INTO Roles VALUES ( 12, 'подготовка издания', 'подгот. изд.',
                               null, 1, 1 );
INSERT INTO Roles VALUES ( 13, 'редактор серии', 'ред. серии', null, 1, 1 );
INSERT INTO Roles VALUES ( 14, 'series editor', 'ser. ed.', 13, 2, 1 );
INSERT INTO Roles VALUES ( 15, 'organization responsible for edition', 
                               'resp. org.', 10, 2, 1 );
INSERT INTO Roles VALUES ( 16, 'ответственный редактор', 'отв. ред.',
                               null, 1, 1 );
INSERT INTO Roles VALUES ( 17, 'при участии', 'участие', null, 1, 1 );
INSERT INTO Roles VALUES ( 18, 'автор вступительной статьи', 'авт. вступ. ст.',
                               null, 1, 1 );
INSERT INTO Roles VALUES ( 19, 'editor', 'ed.', 6, 2, 1 );
INSERT INTO Roles VALUES ( 20, 'оформление обложки', 'оформл. обл.', 
                               null, 1, 1 );


-- ---------------------------------------------------------------------------
-- Таблица "Отрасли науки"
-- ---------------------------------------------------------------------------
INSERT INTO Sci_branches VALUES ( 1, 'физико-математические', 'физ.-мат.' );
INSERT INTO Sci_branches VALUES ( 2, 'технические', 'техн.' );
INSERT INTO Sci_branches VALUES ( 3, 'экономические', 'экон.' );
INSERT INTO Sci_branches VALUES ( 4, 'философские', 'филос.' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды ученых степеней"
-- ---------------------------------------------------------------------------
INSERT INTO Sci_degrees VALUES ( 1, 'кандидат', 'канд.' );
INSERT INTO Sci_degrees VALUES ( 2, 'доктор', 'докт.' );
INSERT INTO Sci_degrees VALUES ( 3, 'Ph. D.', 'PhD' );


-- ---------------------------------------------------------------------------
-- Таблица "Научные специальности"
-- ---------------------------------------------------------------------------
INSERT INTO Sci_specs VALUES ( 1, '05.13.01', 'Системный анализ, ' ||
                               'управление и обработка информации',
                               '2000-01-01', '9999-12-31' );


-- ---------------------------------------------------------------------------
-- Таблица "Группы специфических обозначений материала"
-- ПРИМЕЧАНИЕ. См. библиотечную систему IRBIS.
-- ---------------------------------------------------------------------------
INSERT INTO Spec_mater_groups VALUES ( 1, 'Печатные материалы', 'Печать' );
INSERT INTO Spec_mater_groups VALUES ( 2, 'Аудиоматериалы', 'Аудио' );
INSERT INTO Spec_mater_groups VALUES ( 3, 'Визуально-проекционные материалы',
                                          'Виз.-проекц.' );
INSERT INTO Spec_mater_groups VALUES ( 4, 'Видеоматериалы', 'Видео' );
INSERT INTO Spec_mater_groups VALUES ( 5, 'Кинофильмы', 'Кинофильмы' );
INSERT INTO Spec_mater_groups VALUES ( 6, 'Картографические материалы',
                                          'Карты' );
INSERT INTO Spec_mater_groups VALUES ( 7, 'Компьютерные файлы',
                                          'Комп. файлы' );
INSERT INTO Spec_mater_groups VALUES ( 8, 'Микроформы', 'Микроформы' );
INSERT INTO Spec_mater_groups VALUES ( 9, 'Нотные материалы', 'Ноты' );


-- ---------------------------------------------------------------------------
-- Таблица "Специфические обозначения материала"
-- ПРИМЕЧАНИЕ. См. библиотечную систему IRBIS.
-- ---------------------------------------------------------------------------
INSERT INTO Spec_mater_types VALUES ( 1, 1, 'брошюра', 'бр.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 2, 1, 'лист', 'л.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 3, 1, 'папка', 'папка', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 4, 1, 'столбец', 'столб.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 5, 1, 'страница', 'с.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 6, 1, 'page', 'p', 5, 2 );
INSERT INTO Spec_mater_types VALUES ( 7, 2, 'электронно-оптический диск ' ||
                                            'CD-ROM (аудио)',
                                            'электрон.-опт. диск', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 8, 2, 'грампластинка (диск)',
                                            'грп.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 9, 2, 'магнитная лента', 'мл.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 10, 2, 'магнитный цилиндр',
                                             'цил.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 11, 2, 'магнитная проволока',
                                             'пр.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 12, 2, 'валик', 'вл.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 13, 2, 'пленка', 'пл.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 14, 3, 'диапозитив', 'дп.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 15, 3, 'диафильм', 'дф.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 16, 3, 'набор диапозитивов',
                                             'ндп.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 17, 3, 'слайд', 'сл.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 18, 3, 'транспарант', 'тр.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 19, 4, 'электронно-оптический диск ' ||
                                             'CD-ROM (видео)',
                                             'электрон.-опт. диск', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 20, 4, 'видеокассета', 'вк.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 21, 4, 'видеолента', 'вл.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 22, 5, 'кинофильм', 'кф.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 23, 6, 'страница', 'с.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 24, 6, 'лист', 'л.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 25, 6, 'сдвоенный лист',
                                             'сдв. л.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 26, 6, 'номера карт', 'нк.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 27, 7, 'электронно-оптический диск ' ||
                                             'CD-ROM',
                                             'электрон.-опт. диск', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 28, 7, 'электронно-оптический диск WORM',
                                             'электрон.-опт. диск WORM',
                                             null, 1 );
INSERT INTO Spec_mater_types VALUES ( 29, 7, 'электронно-оптический диск ' ||
                                             'перезаписываемый',
                                             'электрон.-опт. диск перезапис.',
                                             null, 1 );
INSERT INTO Spec_mater_types VALUES ( 30, 7, 'магнитный диск, дискета',
                                             'мд.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 31, 8, 'апертурная карта',
                                             'апк.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 32, 8, 'микрофильм', 'мкф.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 33, 8, 'микроформа', 'мкфм.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 34, 8, 'микрофиша', 'мкфш.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 35, 8, 'джекет (микрофильм в отрезке)',
                                             'дж.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 36, 9, 'страница', 'с.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 37, 9, 'лист', 'л.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 38, 9, 'партия', 'парт.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 39, 9, 'партитура', 'партит.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 40, 1, 'том', 'т.', null, 1 );
INSERT INTO Spec_mater_types VALUES ( 41, 1, 'книга', 'кн.', null, 1,
                                      'Добавлено мною (Е. П. Моргунов)' );
INSERT INTO Spec_mater_types VALUES ( 42, 1, 'часть', 'ч.', null, 1,
                                      'Добавлено мною (Е. П. Моргунов)' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды стандартных номеров (ISBN, ISSN и др.)"
-- ---------------------------------------------------------------------------
INSERT INTO Std_num_types VALUES ( 1, 'ISBN' );
INSERT INTO Std_num_types VALUES ( 2, 'ISSN' );
INSERT INTO Std_num_types VALUES ( 3, 'авторский знак' );
INSERT INTO Std_num_types VALUES ( 4, 'код ГРНТИ' );
INSERT INTO Std_num_types VALUES ( 5, 'УДК' );
INSERT INTO Std_num_types VALUES ( 6, 'ББК' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды заглавий"
-- ---------------------------------------------------------------------------
INSERT INTO Title_types VALUES ( 1, 'основное', 'осн.' );
INSERT INTO Title_types VALUES ( 2, 'параллельное', 'парал.' );
INSERT INTO Title_types VALUES ( 3, 'другое', 'др.' );
INSERT INTO Title_types VALUES ( 4, 'ключевое (для сериального издания)',
                                    'ключ. (для сериал. изд.)' );


-- ---------------------------------------------------------------------------
-- Таблица "Виды справочных материалов"
-- ---------------------------------------------------------------------------
INSERT INTO Ref_types VALUES ( 1, 'указатель предметный', 'указ. предм.' );
INSERT INTO Ref_types VALUES ( 2, 'указатель именной', 'указ. имен.' );
INSERT INTO Ref_types VALUES ( 3, 'словарь терминологический',
                                  'слов. термин.' );
INSERT INTO Ref_types VALUES ( 4, 'список иллюстраций', 'список ил.' );
INSERT INTO Ref_types VALUES ( 5, 'список таблиц', 'список табл.' );
INSERT INTO Ref_types VALUES ( 6, 'список обозначений', 'список обозн.' );


-- ---------------------------------------------------------------------------
-- Команды для заполнения основных таблиц базы данных
-- ---------------------------------------------------------------------------

-- ---------------------------------------------------------------------------
-- Таблица "Организации, учреждения, временные коллективы"
-- ---------------------------------------------------------------------------
INSERT INTO Orgs VALUES
  ( 0,
    'фиктивная организация',
    'фиктивная организация',
    0,
    null, null, null, null, null, default, default, default, null
  );

INSERT INTO Orgs VALUES
  ( 1,
    'Издательство "Радио и связь"',
    'Радио и связь',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 2,
    'Красноярская краевая универсальная научная библиотека',
    'Красноярская краевая библиотека',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 3,
    'Издательство "Советское радио"',
    'Советское радио',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 4,
    'Издательство "Мир"',
    'Мир',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 5,
    'Издательство "Высшая школа"',
    'Высшая школа',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 6,
    'Издательство "БХВ-Петербург"',
    'БХВ-Петербург',
    2,
    '190005, Санкт-Петербург, Измайловский пр., 29',
    'E-mail: mail@bhv.ru; Internet: www.bhv.ru',
    'тел.: (812) 251-42-44', null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 7,
    'ООО Издательство "Алгоритм-Книга"',
    'Алгоритм',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 8,
    'ЗАО Издательский дом "Питер"',
    'Питер',
    2,
    'г. Санкт-Петербург, Б. Сампсониевский пр., 29а',
    'www.piter.com; sales@piter.com',
    'Тел./факс. (812) 703-7383', null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 9,
    'Издательский дом "Вильямс"',
    'Вильямс',
    1,
    '101509, Москва, ул. Лесная, д.43, стр. 1',
    'http://www.williamspubplishing.com; info@williamspubplishing.com',
    null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 10,
    'Издательство "Бином-Пресс"',
    'Бином',
    1,
    '103473, Москва, Краснопролетарская ул., 16',
    null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 11,
    'Издательский дом "ИНФРА-М"',
    'ИНФРА-М',
    1,
    '127214, Москва, Дмитровское шоссе, 107',
    'http://www.infra-m.ru; books@infra-m.ru',
    null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 12,
    'Издательство "Лань"',
    'Лань',
    2,
    '193012, Санкт-Петербург, пр. Обуховской обороны, 277',
    'http://www.lanpbl.spb.ru',
    null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 13,
    'Издательская фирма "Физико-математическая литература"',
    'ФИЗМАТЛИТ',
    1,
    '117997, Москва, ул. Профсоюзная, 90', 
    'http://www.fml.ru',
    null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 14,
    'Издательство "Машиностроение"',
    'Машиностроение',
    1,
    '107076, Москва, Стромынский пер., 4',
    null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 15,
    'Издательство "Экономика"',
    'Экономика',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 16,
    'Издательство "Наука"',
    'Наука',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 17,
    'Издательство "Наука". Главная редакция физико-математической литературы',
    'Наука. Гл. ред. физ.-мат. лит.',
    1,
    null, null, null, null, 16, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 18,
    'Российская академия наук',
    'РАН',
    1,
    null, null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 19,
    'Институт проблем управления им. В. А. Трапезникова РАН',
    'ИПУ РАН',
    1,
    null, null, null, null, 18, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 20,
    'Санкт-Петербургский государственный политехнический университет',
    'СПбГПУ',
    2,
    '195251, Санкт-Петербург, ул. Политехническая, 29',
    null, null, null, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 21,
    'Издательство СПбГПУ',
    'Изд-во СПбГПУ',
    2,
    '195251, Санкт-Петербург, ул. Политехническая, 29',
    null, null, null, 20, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 22,
    'Санкт-Петербургский государственный технический университет',
    'СПбГТУ',
    2,
    '195251, Санкт-Петербург, ул. Политехническая, 29',
    null, null, 20, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 23,
    'Издательство СПбГТУ',
    'Изд-во СПбГТУ',
    2,
    '195251, Санкт-Петербург, ул. Политехническая, 29',
    null, null, 21, null, 'no', 1, 1, null
  );

INSERT INTO Orgs VALUES
  ( 24,
    'Санкт-Петербургская издательская фирма "Наука" РАН',
    'Наука (СПб.)',
    2,
    '199034, Санкт-Петербург, Менделеевская линия, 1',
    'www.nauka.nw.ru; maim@nauka.nw.ru',
    null, null, 16, 'no', 1, 1, null
  );


-- ---------------------------------------------------------------------------
-- Таблица "Персоналии"
-- ---------------------------------------------------------------------------
INSERT INTO Persons VALUES
  (
    0,
    'фиктивная персоналия',
    null, null, null, 1, 1, null, null, null
  );

-- вместо Моргунова Е. П. введите свою фамилию, имя и отчество
INSERT INTO Persons VALUES
  (
    1,
    'Моргунов, Евгений Павлович',
    null, null, null, 1, 1, null, null, null
  );

INSERT INTO Persons VALUES
  (
    2,
    'Beer, Stafford',
    null, null, null, 2, 1, null, null, null
  );

INSERT INTO Persons VALUES
  (
    3,
    'Бир, Стаффорд',
    null, null, 2, 1, 1, null, null, null
  );

INSERT INTO Persons VALUES
  (
    4,
    'Лопухин, М. М.',
    null, null, null, 1, 1, null, null, null
  );


-- ---------------------------------------------------------------------------
-- Таблица "Общий список объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Bib_objs VALUES ( 1, null, null );
                                                                                          

-- ---------------------------------------------------------------------------
-- Таблица "Библиографические описания (записи)"
-- ---------------------------------------------------------------------------
INSERT INTO Bib_recs VALUES
  ( 1, 0, 1, 'Бир, Стаффорд.', 
    'Бир, С. Мозг фирмы [Текст] / Стаффорд Бир ; пер. с англ. ' ||
    'М. М. Лопухина. -- М. : Радио и связь, 1993. -- 416 с. : ил. ' ||
    '-- Табл.: 2. Ил.: 60. -- Библиогр.: с. 409--414 (68 назв.). -- ' ||
    'Перевод изд.: Beer, S. Brain of the firm / Stafford Beer. 2-nd ed. ' ||
    'Chichester ; New York : John Wiley & Sons, 1981. -- 2000 экз. -- ' ||
    'ISBN 5-256-00426-3 (рус.). -- ISBN 0-471-27687-1 (англ.)',
    'Бир, С. Мозг фирмы [Текст] : пер. с англ. / Стаффорд Бир. -- ' ||
    'М. : Радио и связь, 1993. -- 416 с. : ил. -- ' ||
    'ISBN 5-256-00426-3 (рус.). -- ISBN 0-471-27687-1 (англ.)',
    null, 1, 'yes', 1, 1, null, null, null
  );
  

-- ---------------------------------------------------------------------------
-- Таблица "Тиражи объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Editions VALUES ( 1, 2000, 1, null );


-- ---------------------------------------------------------------------------
-- Таблица "Признаки объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Features VALUES ( 1, 2, null );
INSERT INTO Features VALUES ( 1, 98, null );
INSERT INTO Features VALUES ( 1, 99, null );
INSERT INTO Features VALUES ( 1, 132, null );
INSERT INTO Features VALUES ( 1, 177, null );
INSERT INTO Features VALUES ( 1, 192, null );


-- ---------------------------------------------------------------------------
-- Таблица "Ключевые слова"
-- ---------------------------------------------------------------------------
INSERT INTO Keywords VALUES ( 1, 'кибернетика', null, 1, null );
INSERT INTO Keywords VALUES ( 2, 'управление', null, 1, null );


-- ---------------------------------------------------------------------------
-- Таблица "Примечания"
-- ---------------------------------------------------------------------------
INSERT INTO Notes VALUES ( 1, 0, 1, 'Табл.: 2. Ил.: 60', null );
INSERT INTO Notes VALUES ( 1, 0, 2, 'Библиогр.: с. 409--414 (68 назв.)',
                           null );
INSERT INTO Notes VALUES ( 1, 0, 3, 'Перевод изд.: Beer, S. Brain of the ' ||
       'firm / Stafford Beer. 2-nd ed. Chichester ; New York : John ' ||
       'Wiley & Sons, 1981', null );


-- ---------------------------------------------------------------------------
-- Таблица "Ключевые слова, назначенные объектам библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Obj_keywords VALUES ( 1, 1, null );
INSERT INTO Obj_keywords VALUES ( 1, 2, null );


-- ---------------------------------------------------------------------------
-- Таблица "Языки текста объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Obj_langs VALUES ( 1, 1, null );


-- ---------------------------------------------------------------------------
-- Таблица "Цены объектов библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Prices VALUES ( 1, null, 1, 1, null, null, null );


-- ---------------------------------------------------------------------------
-- Таблица "Дата издания, печатания, изготовления"
-- ---------------------------------------------------------------------------
INSERT INTO Pub_print_date VALUES ( 1, 1993, 'no', null, null, 'no', 'yes',
                                    null );


-- ---------------------------------------------------------------------------
-- Таблица "Место издания, изготовления"
-- ---------------------------------------------------------------------------
INSERT INTO Pub_print_place VALUES ( 1, 0, 1, 1, 1, 1, 0, 1, 'no', 'yes',
                                     null, null );


-- ---------------------------------------------------------------------------
-- Таблица "Издатель, изготовитель, распространитель"
-- ---------------------------------------------------------------------------
INSERT INTO Pub_printer VALUES ( 1, 0, 1, 1, 2, 1, 0, 1, null, 'no', 'yes',
                                 null, null );


-- ---------------------------------------------------------------------------
-- Таблица "Сведения об ответственности"
-- ---------------------------------------------------------------------------
INSERT INTO Resp_stat VALUES ( 1, 0, 1, 1, 2, 3, 1, 4, 0, null, null, null );
INSERT INTO Resp_stat VALUES ( 1, 0, 1, 1, 1, 1, 1, 3, 0, null, null, null );


-- ---------------------------------------------------------------------------
-- Таблица "Стандартные номера (ISBN, ISSN и др.), присвоенные объектам
-- библиографического описания"
-- ---------------------------------------------------------------------------
INSERT INTO Std_nums VALUES ( 1, 1, '5-256-00426-3', '(рус.)', 'no', null );
INSERT INTO Std_nums VALUES ( 1, 1, '0-471-27687-1', '(англ.)', 'no', null );
INSERT INTO Std_nums VALUES ( 1, 5, '681.51', null, 'no', null );


-- ---------------------------------------------------------------------------
-- Таблица "Экземпляры (единицы хранения)"
-- ---------------------------------------------------------------------------
INSERT INTO Stor_objs VALUES ( 1, 1, 1, 1, 0, 1, null, null, null, null, 
                               9, 'yes', '1993-12-22', 'yes', null, 3, 0, 1,
                               null, 1, null, 1500.00, null, null, 'no',
                               null, null );


-- ---------------------------------------------------------------------------
-- Таблица "Заглавия"
-- ---------------------------------------------------------------------------
INSERT INTO Titles VALUES ( 1, 0, 1, 1, 'Мозг фирмы', 1, 1, 'no', 
                            'пер. с англ.', null );


-----------------------------

END;
