#!/bin/sh

# -----------------------------------------------------------------------------
# Система:   "Электронный архив"
# Программа: установка программных модулей и конфигурационных файлов
#            в целевые каталоги
# Автор:     Моргунов Е. П.
# Дата:      15.04.2012
# Версия:    0.6
# -----------------------------------------------------------------------------

# файл с параметрами конфигурации
if [ -f ../../install.cfg ]; then
  . ../../install.cfg
else
  echo "Отсутствует конфигурационный файл install.cfg"
  echo "Необходимо выполнить конфигурирование с помощью программы configure"
  exit 1
fi

# целевой каталог
TARGET_DIR=$APACHE/e_arch

if [ -d $TARGET_DIR ]; then
  echo "Каталог $TARGET_DIR уже существует"
  exit 1
fi

mkdir $TARGET_DIR

mkdir $TARGET_DIR/cfg
mkdir $TARGET_DIR/css
mkdir $TARGET_DIR/js
mkdir $TARGET_DIR/exp_imp

# скрипт exp_imp.pl должен иметь право на запись в этот каталог
# по умолчанию web-сервер запускается от имени пользователя daemon, поэтому
# дадим право на запись "прочим" пользователям
chmod 777 $TARGET_DIR/exp_imp

DIR=`pwd`

# имя текущего каталога (только последний уровень иерархии) совпадает
# с наименованием кодировки символов (KOI8-R или UTF-8), установленной
# в системе
LOCALE=`echo $DIR | sed -E 's/^.+\///'`

# нужно сначала выйти на ДВА уровня иерархии вверх, в уже затем спуститься вниз
# (если мы вышли из подкаталога KOI8-R, то и спуститься потом должны 
# в подкаталог KOI8-R)
PREFIX=../../prg/$LOCALE

# копируем программные модули (*.pl, *.pm, .htaccess)
cp $PREFIX/* $TARGET_DIR
cp $PREFIX/.htaccess $TARGET_DIR

# будем модифицировать префикс пути к файлам и копировать остальные файлы
PREFIX=../../prg/cfg/$LOCALE
cp $PREFIX/* $TARGET_DIR/cfg

PREFIX=../../prg/css/$LOCALE
cp $PREFIX/* $TARGET_DIR/css

PREFIX=../../prg/js/$LOCALE
cp $PREFIX/* $TARGET_DIR/js

# скопируем файл mk_links.sh
PREFIX=../../install/$LOCALE
cp $PREFIX/mk_links.sh $TARGET_DIR

# создадим жесткие ссылки на модуль langs.pl
DIR=`pwd`
cd $TARGET_DIR
./mk_links.sh

# в файле .htaccess откорректируем значение параметра AuthUserFile
# (в качестве ограничителей регулярного выражения используем символ "#";
# перед символом "$" ставим символ "\", поскольку мы формируем команду
# в виде символьной строки, и нам требуется сохранить символ "$" буквально)
cmd="sed -E -e '\#^AuthUserFile#s#^.+\$#AuthUserFile $APACHE/bin/.htpasswd#'"
cat .htaccess | eval $cmd > .htaccess.tmp
mv .htaccess.tmp .htaccess

# в файле ./cfg/e_arch.cfg откорректируем значения параметров DBNAME и CHARSET
# TODO. Каким образом можно вместо пробелов вставить символы табуляции?
# TODO. Почему несколько пробелов заменяются одним пробелом?
cmd="sed -E -e '/^DBNAME/s/^.+\$/DBNAME             $DB_NAME/'"
cmd="$cmd  -e '/^CHARSET/s/^.+\$/CHARSET             $LOCALE/'"
cat ./cfg/e_arch.cfg | eval $cmd > ./cfg/e_arch.cfg.tmp
mv ./cfg/e_arch.cfg.tmp ./cfg/e_arch.cfg

# в программных файлах откорректируем путь к интерпретатору Perl
# (на тот случай, когда он может отличаться от стандартного /usr/bin/perl)

# получаем список имен файлов
for prg in `ls -1 *.pl`
do
  # сформируем команду в виде символьной строки (используем "\$" для 
  # сохранения символа "$" в строке в буквальном виде)
  # заменим первую строку файла значением конфигурационной переменной $PERL
  # с параметром -w 
  # ПРИМЕЧАНИЕ. Первая команда осуществляет замену первой строки файла,
  #             а вторая команда просто выводит все строки файла, начиная 
  #             со второй строки. В качестве ограничителей регулярного
  #             выражения используем символ "#", поскольку в переменной $PERL
  #             будут присутствовать символы "/". Но теперь приходится
  #             ставить символ "\" перед символом "#", которым начинается
  #             первая строка "перлового" скрипта.
  cmd="sed -E -n -e '1s#^.+\$#\#!$PERL -w#p' -e '2,\$p' $prg"

  eval $cmd > tmp.pl
  mv tmp.pl $prg
done

# изменим права доступа к программным файлам (если по каким-то причинам
# эти файлы не имеют установленного атрибута "исполнение")
chmod 755 *.pl

# создадим учетные записи пользователей web-сервера Apache
# (используя программу bin/htpasswd)
cd $APACHE/bin

# если файла паролей еще нет, создадим его (сделаем это для упрощения
# параметров команды htpasswd)
if [ ! -f .htpasswd ]; then
  touch .htpasswd
fi

for user in admin debug admin_d debug_d
do
  grep "^$user:" .htpasswd > /dev/null

  # такой пользователь уже есть  
  if [ $? = 0 ]; then
    echo "Учетная запись пользователя $user для web-сервера уже существует"
    continue
  fi

  echo "Создаем учетную запись пользователя $user для web-сервера."
  echo "Пароль -- qwerty. Не забудьте сменить пароль!"
  ./htpasswd -b .htpasswd $user qwerty
done

# откорректируем конфигурационный файл web-сервера Apache -- httpd.conf

cd ../conf
cp httpd.conf httpd.conf.e_arch
echo "Конфигурационный файл httpd.conf сохранен с именем httpd.conf.e_arch"

# сначала подготовим временный файл
# (он необходим потому, что команда "a" редактора sed не позволяет использовать
# переменные в составе того текста, который по этой команде добавляется
# в выходной поток; в выходной поток вставляются имена переменных, а не их
# значения)
# ПРИМЕЧАНИЕ. Можно было бы использовать eval, но пусть остается использование
#             временного файла.
cat > httpd.append <<EOF
    # --- E_ARCH `date "+DATE: %Y-%m-%d% TIME: %H:%M:%S"` ---
    Alias /e_arch_js $APACHE/e_arch/js
    Alias /e_arch_css $APACHE/e_arch/css

    ScriptAlias /e_arch/ "$APACHE/e_arch/"
EOF

# вставим содержимое временного файла после строки <IfModule alias_module>
cat httpd.conf | sed -e '/^<IfModule alias_module>/r httpd.append' > \
    httpd.conf.$$

mv httpd.conf.$$ httpd.conf

# подготовим временный файл еще раз
cat > httpd.append <<EOF

# --- E_ARCH `date "+DATE: %Y-%m-%d% TIME: %H:%M:%S"` ---
<Directory "$APACHE/e_arch">
    AllowOverride All
    Options None
    Order allow,deny
    Allow from all
</Directory>

<Directory "$APACHE/e_arch/js">
    Options Indexes FollowSymLinks
    AllowOverride None
    Order allow,deny
    Allow from all
</Directory>

<Directory "$APACHE/e_arch/css">
    Options Indexes FollowSymLinks
    AllowOverride None
    Order allow,deny
    Allow from all
</Directory>
EOF

# добавим содержимое временного файла в конфигурационный файл
cat httpd.append >> httpd.conf
rm httpd.append

echo "В конфигурационный файл httpd.conf внесены необходимые изменения"
echo "Они помечены знаком E_ARCH"

# вернемся в установочный каталог
cd $DIR
