#!/bin/sh

# -----------------------------------------------------------------------------
# Система:   "Электронный архив"
# Программа: объединяющая программа для генерирования базы данных
# Автор:     Моргунов Е. П.
# Дата:      15.04.2012
# Версия:    0.6
# -----------------------------------------------------------------------------

# ПРИМЕЧАНИЕ. Для сохранения выводимых сообщений можно сделать так:
#             ./make_db.sh > create.txt 2>errors.txt &

# эту команду можно раскомментировать для отладочных целей
#set -x

# файл с параметрами конфигурации
if [ -f ../../install.cfg ]; then
  . ../../install.cfg
else
  echo "Отсутствует конфигурационный файл install.cfg"
  echo "Необходимо выполнить конфигурирование с помощью программы configure"
  exit 1
fi

# строка параметров для соединения с базой данных
# TODO. Предусмотреть наличие пароля у пользователя postgres.
#CONN_STR="dbname=$DB_NAME user=$DB_SUPERUSER password=..."
CONN_STR="dbname=$DB_NAME user=$DB_SUPERUSER"

DIR=`pwd`

# имя текущего каталога (только последний уровень иерархии) совпадает
# с наименованием кодировки символов (KOI8-R или UTF-8), установленной
# в системе
LOCALE=`echo $DIR | sed -E 's/^.+\///'`

# нужно сначала выйти на ДВА уровня иерархии вверх, в уже затем спуститься вниз
# (если мы вышли из подкаталога KOI8-R, то и спуститься потом должны 
# в подкаталог KOI8-R)
PREFIX=../../db/$LOCALE/

# -----------------------------------------------------------------------------
echo "Создание базы данных"
DB_CREATE_CMD="CREATE DATABASE $DB_NAME"

# если параметры для создания базы данных непустые, воспользуемся ими
[ "${DB_ENCODING:+set}" = "set" ] &&
  DB_CREATE_CMD="$DB_CREATE_CMD ENCODING = '$DB_ENCODING'"
[ "${DB_LC_COLLATE:+set}" = "set" ] &&
  DB_CREATE_CMD="$DB_CREATE_CMD LC_COLLATE = '$DB_LC_COLLATE'"
[ "${DB_LC_CTYPE:+set}" = "set" ] &&
  DB_CREATE_CMD="$DB_CREATE_CMD LC_CTYPE = '$DB_LC_CTYPE'"
         
# будем считать, что если пользователем указана кодировка, то она отличается
# от той, которая является стандартной для данной операционной системы, поэтому
# нужно указать еще и базу данных, используемую в качестве шаблона
[ "${DB_ENCODING:+set}" = "set" ] &&
  DB_CREATE_CMD="$DB_CREATE_CMD TEMPLATE = template0"

# TODO. Предусмотреть наличие пароля у пользователя postgres.
$PGSQL/bin/psql "user=$DB_SUPERUSER" -c "$DB_CREATE_CMD"
if [ $? != 0 ]; then
  echo "База данных $DB_NAME уже существует"
  echo "Для повторного создания этой базы данных необходимо сначала ее удалить"
  exit 1
fi

# -----------------------------------------------------------------------------
echo "Создание рабочих таблиц базы данных \"Электронный архив\""
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch.sql
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_admin.sql

# -----------------------------------------------------------------------------
echo "Создание \"теневых\" таблиц базы данных \"Электронный архив\""
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_shad.sql
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_admin_shad.sql

# -----------------------------------------------------------------------------
echo "Создание схем экспорта/импорта базы данных"
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_exp_imp.sql
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_imp.sql

# -----------------------------------------------------------------------------
echo "Создание учетных записей пользователей для работы с базой данных"
for user in admin admin_d debug debug_d
do
  $PGSQL/bin/psql "${CONN_STR}" -c "CREATE USER $user"
  if [ $? != 0 ]; then
    echo "Учетная запись пользователя $user уже существует"
  fi
done

# -----------------------------------------------------------------------------
echo "Распределение привилегий для работы с базой данных"
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_grants.sql

# -----------------------------------------------------------------------------
echo "Создание правил для таблиц базы данных"
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_rules.sql
$PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_admin_rules.sql

# -----------------------------------------------------------------------------
if [ "$INSERT_INITIAL_DATA" = "YES" ]; then
  echo "Ввод начальных данных в таблицы базы данных"
  $PGSQL/bin/psql "${CONN_STR}" -f $PREFIX/e_arch_insert.sql
fi

# -----------------------------------------------------------------------------
echo "Создание базы данных \"Электронный архив\" завершено"
# -----------------------------------------------------------------------------
