#!/usr/bin/perl -w

# -----------------------------------------------------------------------------
# Система:   "Электронный архив"
# Программа: вспомогательная программа для формирования sql-файла
#            распределения привилегий доступа к таблицам базы данных
# Автор:     Моргунов Е. П.
# Дата:      15.04.2012
# Версия:    0.6
# -----------------------------------------------------------------------------

# использование программы
# ./mk_grants.pl user_name access_rights db_schema < e_arch.sql > grants.sql
# user_name - имя пользователя
# access_rights - привилегии (например, 'ALL' или 'SELECT, INSERT')
# db_schema - схема базы данных (по умолчанию -- public)
# e_arch.sql - файл с описаниями структур таблиц
# grants.sql - файл с командами назначения привилегий

# ПРИМЕЧАНИЕ. Привилегии назначаются ОДИНАКОВЫЕ на все таблицы. Команда GRANT
#             позволяет дать все эти привилегии за один ее вызов. Но пусть
#             пока все остнется так, как есть сейчас.

use strict;

my $user = $ARGV[ 0 ];       # имя пользователя
my $priv = $ARGV[ 1 ];       # привилегии
my $db_schema = $ARGV[ 2 ];  # схема базы данных

my $table;                   # имя текущей таблицы

if ( scalar @ARGV < 2 || scalar @ARGV > 3 )
{
  print "Запуск программы:\n" .
        "mk_grants.pl user_name access_rights [db_schema] < e_arch.sql > " .
        "grants.sql\n";
  exit( 0 );
}

$db_schema = 'public' if ( scalar @ARGV == 2 );

# выведем информацию о текущем времени и дате
print "-- Этот файл создан программой " . $0 . "  " . localtime() . "\n\n\n";

print <<EOF;
-- ---------------------------------------------------------------------------
-- Привилегии доступа к таблицам базы данных "Электронный архив"
-- ---------------------------------------------------------------------------

EOF

# обработаем файл, содержащий описания структур таблиц
while ( <STDIN> )
{
  chomp;             # уберем символ новой строки
  next if $_ eq '';  # пустые строки пропускаем

  # встретилась команда на создание таблицы
  if ( /^CREATE\s+TABLE\s+/ )
  {
    ( $table ) = $_ =~ /^CREATE\s+TABLE\s+(\w+)\s*/;

    print "GRANT $priv ON $db_schema.$table TO $user;\n";
  }
}
 
print "\n\n";

exit( 0 );
