#!/bin/sh

# -----------------------------------------------------------------------------
# Система:   "Электронный архив"
# Программа: вспомогательная программа для генерирования SQL-файлов,
#            необходимых для создания базы данных
# Автор:     Моргунов Е. П.
# Дата:      15.04.2012
# Версия:    0.6
# -----------------------------------------------------------------------------

# ПРИМЕЧАНИЕ. Для сохранения выводимых сообщений можно сделать так:
#             ./prepare_sql.sh > create.txt 2>errors.txt &

# эту команду можно раскомментировать для отладочных целей
#set -x

DIR=`pwd`

# имя текущего каталога (только последний уровень иерархии) совпадает
# с наименованием кодировки символов (KOI8-R или UTF-8), установленной
# в системе
LOCALE=`echo $DIR | sed -E 's/^.+\///'`

# нужно сначала выйти на ДВА уровня иерархии вверх, в уже затем спуститься вниз
# (если мы вышли из подкаталога KOI8-R, то и спуститься потом должны 
# в подкаталог KOI8-R)
PREFIX=../../db/$LOCALE

# -----------------------------------------------------------------------------
echo "Создание SQL-файла, содержащего описания структур \"теневых\" таблиц"
echo "базы данных"
echo ""
./mk_shad_tables.pl < $PREFIX/e_arch.sql > $PREFIX/e_arch_shad.sql
./mk_shad_tables.pl < $PREFIX/e_arch_admin.sql > $PREFIX/e_arch_admin_shad.sql

# -----------------------------------------------------------------------------
echo "Создание SQL-файла, содержащего правила (RULES), сформированные "
echo "на основе \"теневых\" таблиц базы данных"
echo ""
./mk_rules.pl < $PREFIX/e_arch_shad.sql > $PREFIX/e_arch_rules.sql
./mk_rules.pl < $PREFIX/e_arch_admin_shad.sql > $PREFIX/e_arch_admin_rules.sql

# -----------------------------------------------------------------------------
echo "Создание SQL-файла, содержащего описания структур таблиц схемы"
echo "экспорта/импорта базы данных"
echo ""
cat > $PREFIX/e_arch_exp_imp.sql <<EOF
-- Этот файл создан программой `basename $0`
-- `date`

-- ---------------------------------------------------------------------------
-- Структуры таблиц схемы экспорта/импорта базы данных "Электронный архив"
-- ---------------------------------------------------------------------------

DROP SCHEMA IF EXISTS exp_imp CASCADE;
CREATE SCHEMA exp_imp;
SET SCHEMA 'exp_imp';
EOF

# копируем определения всех таблиц и индексов, но отбрасываем все 
# строки, начинающиеся с "--" (комментарии SQL)
cat $PREFIX/e_arch.sql | sed -n '/^--/!p' >> $PREFIX/e_arch_exp_imp.sql

# -----------------------------------------------------------------------------
echo "Создание SQL-файла, содержащего описания структур таблиц схемы"
echo "импорта базы данных"
echo ""
cat > $PREFIX/e_arch_imp.sql <<EOF
-- Этот файл создан программой `basename $0`
-- `date`

-- ---------------------------------------------------------------------------
-- Структуры таблиц схемы импорта базы данных "Электронный архив"
-- ---------------------------------------------------------------------------

DROP SCHEMA IF EXISTS imp CASCADE;
CREATE SCHEMA imp;
SET SCHEMA 'imp';
EOF

# копируем определения всех таблиц и индексов, но отбрасываем все 
# строки, начинающиеся с "--" (комментарии SQL)
cat $PREFIX/e_arch.sql | sed -n '/^--/!p' >> $PREFIX/e_arch_imp.sql

# -----------------------------------------------------------------------------
echo "Формирование файла, содержащего команды для назначения привилегий"
echo "для работы с базой данных"
echo ""
cat > $PREFIX/e_arch_grants.sql<<EOF
-- Этот файл создан программой `basename $0`
-- `date`

-- ---------------------------------------------------------------------------
-- Привилегии доступа к схемам и таблицам базы данных "Электронный архив"
-- ---------------------------------------------------------------------------

GRANT USAGE ON SCHEMA exp_imp, imp TO admin, admin_d, debug, debug_d;

EOF

# привилегии для работы с административными таблицами
./mk_grants.pl admin "select" < $PREFIX/e_arch_admin.sql >> \
  $PREFIX/e_arch_grants.sql
./mk_grants.pl debug "select" < $PREFIX/e_arch_admin.sql >> \
  $PREFIX/e_arch_grants.sql
./mk_grants.pl admin_d "all" < $PREFIX/e_arch_admin.sql >> \
  $PREFIX/e_arch_grants.sql
./mk_grants.pl debug_d "all" < $PREFIX/e_arch_admin.sql >> \
  $PREFIX/e_arch_grants.sql

# привилегии для пользователей admin и debug
for user in admin debug
do
  # основные таблицы в схеме public
  ./mk_grants.pl $user "select, insert, update" public < \
    $PREFIX/e_arch.sql >> $PREFIX/e_arch_grants.sql

  # схемы экспорта/импорта
  for schema in exp_imp imp
  do
    ./mk_grants.pl $user "all" $schema < \
      $PREFIX/e_arch.sql >> $PREFIX/e_arch_grants.sql
  done
done

# привилегии для пользователей admin_d и debug_d
for user in admin_d debug_d
do
  # все схемы БД
  for schema in public exp_imp imp
  do
    ./mk_grants.pl $user "all" $schema < \
      $PREFIX/e_arch.sql >> $PREFIX/e_arch_grants.sql
  done
done

# -----------------------------------------------------------------------------
echo "Подготовка SQL-файлов, необходимых для создания базы данных"
echo "\"Электронный архив\" завершена"
# -----------------------------------------------------------------------------
