#!/usr/bin/perl -w

# -----------------------------------------------------------------------------
# :  " "
# :   "  (ISBN, ISSN  .),  
#            "
# :     . .
# :     15.04.2012
# :   0.6
# -----------------------------------------------------------------------------

use strict;
use CGI;
use CGI::Carp qw( fatalsToBrowser );
use Pg;                          #    PostgreSQL

use E_ARCH;                      #  ,  

#     
$SIG{ __DIE__ } = \&CGI::Carp::confess;

my $query;                       # CGI-
my $script_name;                 #    ( )

#    (    
#      )
my $module = 'STD_NUMS';

#  ,   (   REMOTE_USER)
my $user = get_user_name(); 

#     Std_nums
my @f_names =
   ( 'obj_id',           #   
                         #  
     'std_num_code',     #    
     'std_num_val',      #   (ISBN, ISSN ...)
     'std_num_note',     #     
     'std_num_wrong',    #     (ISBN  ISSN)
     'comment'           # 
   );

my $db_schema;                     #   ( /)

$query = CGI->new();               #   CGI-

#    
select( STDERR ); 
$| = 1;
select( STDOUT );
$| = 1;

$script_name = $query->script_name;

#    /   ,   
#   ;      SQL-  
#  ,    
$db_schema = $query->param( 'exp_imp' ) ? "exp_imp." : "";

#      
common_modes( query => $query,
              module => $module,
              user => $user,
              make_form => \&make_form,
              make_command => \&make_command,
              check_param => \&check_param,
              create_top => \&create_top,
              do_query => \&do_query,
              do_view => \&do_view,
              do_add => \&do_add,
              do_del => \&do_del,
              add_rec => \&add_rec,
              update_rec => \&update_rec,
              print_add_info => \&print_add_info,
              action => $script_name
            );

exit( 0 );


# -----------------------------------------------------------------------------
#    
# -----------------------------------------------------------------------------
sub check_param
{
  my $no_errors = 1;        #     
  my @error_messages = ();  #        

  #     (  )
  if ( $query->param( 'std_num_code' ) !~ /^\d+$/ )
  {
    push( @error_messages, "       " .
          "" );
  }

  if ( $query->param( 'std_num_val' ) eq '' )
  {
    push( @error_messages, "    (ISBN, ISSN ...)" );
  }

  # DEBUG
  # print_params( $query );

  #    ,   
  if ( scalar @error_messages != 0 )
  {
    print_user_err_msgs( \@error_messages );
    $no_errors = 0;
  }
  
  return ( $no_errors );
}

# -----------------------------------------------------------------------------
#    ,     
# ""  
# -----------------------------------------------------------------------------
sub create_top
{
  #   
  create_top_block( query => $query,
                    module => $module,
                    module_title => '  ()',
                    user => $user,
                    full_top => 'no'
                  );
  return ( 0 );
}

# -----------------------------------------------------------------------------
#  
# -----------------------------------------------------------------------------
sub do_del
{
  my $obj_id;             #    . 
  my $std_num_val;        #   (ISBN, ISSN ...)
  my $target_win;         #      HTML-
  my $command;            #      

  $obj_id      = $query->param( 'obj_id' );
  $std_num_val = $query->param( 'std_num_val' );
  $target_win  = $query->param( 'target_win' );

  #         
  $command = "DELETE FROM ${db_schema}std_nums " .
             "WHERE obj_id = '$obj_id' AND " .
                   "std_num_val = '$std_num_val'";

  #   
  del_rec( query => $query,
           target => $target_win,
           create_top => \&create_top,
           print_add_info => \&print_add_info,
           command => $command
         );

  return ( 0 );
}

# -----------------------------------------------------------------------------
#        
# -----------------------------------------------------------------------------
sub do_query
{
  # .        
  #              bib_recs.pl.

  my $obj_id;             #    . 
  my $bib_rec;            # . 
  my $target_win;         #      HTML-
  my( $result, $i );      #    
  my @row;                #      
  my $command;            #      
  my $href;               #   HTML-

  #          HTML-
  #   
  my $can_view = 0;
  my $can_delete = 0;

  #  ,        
  my $alt_row = 1;

  $obj_id     = $query->param( 'obj_id' );
  $bib_rec    = $query->param( 'bib_rec' );
  $target_win = $query->param( 'target_win' );

  #  HTTP-  HTML-
  http_html_headers( query => $query, target => $target_win );

  open_top();       #     
  create_top();     #    
  close_top();      #     

  open_bottom();    #     

  print_add_info(); #     

  #  ,    
  $bib_rec = CGI::escape( $bib_rec );

  #   HTML-
  $href = ( $query->param( 'exp_imp' ) ? "exp_imp=1&" : "" ) .
          "obj_id=$obj_id" .
          "&bib_rec=$bib_rec" .
          "&target_win=$target_win";

  #         
  # (      )
  $command = "SELECT sn.*, st.std_num_name " .
             "FROM ${db_schema}std_nums sn, ${db_schema}std_num_types st " .
             "WHERE sn.obj_id = $obj_id AND " .
                   "sn.std_num_code = st.std_num_code " .
             "ORDER BY st.std_num_name";

  $result = exec_select( $command );    #    
  
  if ( $result )
  {
    $can_view = have_access( 'module' => $module, 'procedure' => 'VIEW', 
                             'user' => $user );
    $can_delete = have_access( 'module' => $module, 'procedure' => 'DELETE',
                               'user' => $user );

    #     
    print "<table class=\"list\">\n";
    print "<tr>\n";
    print "<th>  </th>\n";
    print "<th> </th>\n";
    print "<th>    </th>\n";
    print "<th>&nbsp;</th>\n" if ( $can_view || $can_delete );
    print "</tr>\n";

    #      
    while ( @row = $result->fetchrow )
    {
      #        
      if ( $CFG{ ALT_ROWS_IS_ON } )
      {
        $alt_row = ! $alt_row;
        print ( ( $alt_row ) ? "<tr class=\"alt_row\">\n" : "<tr>\n" );
      }
      else
      {
        print "<tr>\n";
      }

      #       ,   . 
      # (  &nbsp;  .   . 
      #   :    'std_num_note' 
      # null,     -)
      print "<td>$row[ $result->fnumber( 'std_num_name' ) ]</td>\n";
      print "<td>$row[ $result->fnumber( 'std_num_val' ) ]</td>\n";
      print "<td>$row[ $result->fnumber( 'std_num_note' ) ]&nbsp;</td>\n";

      #         
      print "<td>" if ( $can_view || $can_delete );
      #    ,   
      #   std_num_val (,     )
      print qq{<a class="command_link" href="$script_name/view?$href} .
            "&std_num_val=" .
            CGI::escape( $row[ $result->fnumber( 'std_num_val' ) ] ) . "\"" .
            qq{ target="$target_win"></a>} if $can_view;
      print "\n" if $can_view;

      #      
      #    ,   
      #   std_num_val (,     )
      print qq{<a class="command_link" href="$script_name/delete?$href} .
            "&std_num_val=" .
            CGI::escape( $row[ $result->fnumber( 'std_num_val' ) ] ) . "\"" .
            qq{ onclick="$confirm_delete"} .
            qq{ target="$target_win"></a>} if $can_delete;
      print "</td>\n" if ( $can_view || $can_delete );

      print "</tr>\n";
    }
    print "</table>\n";
  }

  #        
  #          "/"
  if ( ! $query->param( 'exp_imp' ) &&
       have_access( 'module' => $module, 'procedure' => 'ADD', 
                    'user' => $user ) )
  {
    print "<br />\n";
    print qq{<a class="command_link" href="$script_name/add?$href"} .
          qq{ target="$target_win"> </a>};
  }

  close_bottom();   #     
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
#      
# -----------------------------------------------------------------------------
sub do_view
{
  my $obj_id;             #    . 
  my $std_num_val;        #   (ISBN, ISSN ...)
  my $target_win;         #      HTML-
  my $command;            #      

  $obj_id      = $query->param( 'obj_id' );
  $std_num_val = $query->param( 'std_num_val' );
  $target_win  = $query->param( 'target_win' );

  #      
  $command = "SELECT * " .
             "FROM ${db_schema}std_nums " .
             "WHERE obj_id = $obj_id AND " .
                   "std_num_val = '$std_num_val'";

  #   
  view_rec( query => $query,
            create_top => \&create_top,
            make_form => \&make_form,
            action => $script_name,
            target => $target_win,
            submit_name => "submit_update",
            submit_value => "    ",
            command => $command,
            error => "        : " .
                     "   .  - " .
                     $obj_id . ", " .
                     "  (ISBN, ISSN ...) - $std_num_val",
            can_update => have_access( 'module' => $module, 
                                       'procedure' => 'UPDATE', 
                                       'user' => $user )
        );

  return ( 0 );
}

# -----------------------------------------------------------------------------
#  -      
# -----------------------------------------------------------------------------
sub make_command
{
  my $operation = shift; #   -   ?

  my $command;           # -

  #   
  # :   
  # -        ,  
  #    (f_special);
  # -        (func_special)
  $command = make_cmd( query => $query,
                       operation => $operation,
                       table => "std_nums",
                       key => "obj_id, std_num_val:std_num_val_begin",
                       f_names => \@f_names,
                       f_special => [ 'std_num_wrong' ],
                       func_special => \&non_std_fields,
                       user => $user
                     );

  return ( $command );
}

# -----------------------------------------------------------------------------
#     ()   
# -----------------------------------------------------------------------------
sub make_form
{
  # 
  my $ref_row = shift;  #   ,     
  my $res = shift;      #  

  my $i;
  my %fields = ();  # -      

  #      (    
  #   )
  my( $ref_values, $ref_labels ) = popup_std_num_types_list( $db_schema );

  #    -       
  #  , ...
  if ( $ref_row ne undef )
  {
    # ...   -,  ...
    for $i ( 0 .. $res->nfields - 1 )
    {
      # ...     ,    
      # (      - . Pg.pm)
      $fields{ $res->fname( $i ) } = $$ref_row[ $i ];
    }
  }
  else                      #      
  {
    #       
    $fields{ 'obj_id' } = $query->param( 'obj_id' );

    #   
    $fields{ 'std_num_code' } = $CFG{ STD_NUMS_STD_NUM_CODE };

    #   .       ,
    #   1  ,      
    #  :     HTML-   "ISBN" (
    #     - values),   " 
    #   (ISBN  ISSN)"    
    # (  'std_num_code'  - $fields  
    #       )
    $fields{ 'std_num_code' } = 1 if $fields{ 'std_num_code' } eq undef;
    
    #   (ISBN, ISSN ...)
    $fields{ 'std_num_val' }  = $CFG{ STD_NUMS_STD_NUM_VAL };

    # .    
    $fields{ 'std_num_note' } = $CFG{ STD_NUMS_STD_NUM_NOTE };

    # 
    $fields{ 'comment' }      = $CFG{ STD_NUMS_COMMENT };
  }
  # -------------------------------------------------------------------

  #    HTML-       
  # insert_str_into_field(),     
  #   HTML-
  print <<END_OF_SCRIPT;
  <script language="JavaScript" type="text/javascript"
          src="/$CFG{ HOME_WEB_JS_DIR }/insert_text.js"></script>
END_OF_SCRIPT
  ;

  print <<END_OF_SCRIPT;
  <script language="JavaScript" type="text/javascript">
  <!--
  //       "  
  //  (ISBN  ISSN)"      " 
  // "
  function on_change_std_num_code()
  {
    //        
    var opts = document.forms[ 0 ].std_num_code.options;
    var ind = document.forms[ 0 ].std_num_code.selectedIndex;
    
    //    "ISBN"  "ISSN"
    if ( opts[ ind ].text == "ISBN" || opts[ ind ].text == "ISSN" )
    {    
      //     "   "
      document.forms[ 0 ].std_num_wrong.disabled = false;
    }
    else
    {
      //     " ..."    
      document.forms[ 0 ].std_num_wrong.disabled = true;
      document.forms[ 0 ].std_num_wrong.checked = false;
    }
  }
  //-->
  </script>
END_OF_SCRIPT
  ;

  #    "  
  #  "   ,   
  #  ,     , ..   
  #   UPDATE   ,    
  #  INSERT (     ,   
  #    ,      )
  print $query->hidden( -name => 'obj_id' ), "\n";

  #     "  (ISBN, ISSN ...)"
  # .      'begin'  ,
  #                   ,  
  #               (.  make_cmd   E_ARCH.pm).
  #             ..       ,   
  #              (, ,   ).
  print $query->hidden( -name => 'std_num_val_begin',
                        -default => $fields{ 'std_num_val' }
                      ), "\n";

  #      .  
  #  ,     add_rec()  update_rec()
  print $query->hidden( -name => 'bib_rec' ), "\n";

  #   exp_imp,   ,   
  #   (     : exp_imp  public)
  print $query->hidden( -name => 'exp_imp' ), "\n";

  print_add_info();         #     

  print "<table class=\"form\">\n";

  #        labels  
  # ,    popup_std_num_types_list() 
  #  ,   -   
  print "<tr>\n";
  print "<th>  </th>\n";
  print "<td>",
        $query->popup_menu( -name => 'std_num_code',
                            -default => $fields{ 'std_num_code' },
                            -values => $ref_values,
                            -labels => { @{ $ref_labels } },
                            -onchange => "on_change_std_num_code()"
                          ),
        "</td>\n";
  print "</tr>\n";

  print "<tr>\n";
  print "<th>  (ISBN, ISSN ...)</th>\n";
  print "<td>";

  #   ()     
  #    
  create_hot_help( "document.forms[ 0 ].std_num_val", "STD_NUMS_STD_NUM_VAL" )
    if $CFG{ HOT_HELP_IS_ON };

  print $query->textfield( -name => 'std_num_val',
                           -default => $fields{ 'std_num_val' },
                           -size => $CFG{ STD_NUMS_STD_NUM_VAL_SIZE },
                           -maxlength => $CFG{ STD_NUMS_STD_NUM_VAL_MAXLENGTH }
                         ),
        "</td>\n";
  print "</tr>\n";

  print "<tr>\n";
  print "<th>    </th>\n";
  print "<td>";
  
  #   ()     
  #    
  create_hot_help( "document.forms[ 0 ].std_num_note",
                   "STD_NUMS_STD_NUM_NOTE" )
    if $CFG{ HOT_HELP_IS_ON };

  print $query->textarea( -name => 'std_num_note',
                          -default => $fields{ 'std_num_note' },
                          -rows => $CFG{ STD_NUMS_STD_NUM_NOTE_ROWS },
                          -columns => $CFG{ STD_NUMS_STD_NUM_NOTE_COLS }
                         ),
        "</td>\n";
  print "</tr>\n";

  print "<tr>\n";
  print "<th>    (ISBN  ISSN)</th>\n";
  print "<td>";

  #     std_num_wrong
  my @std_num_wrong_params = ( '-name', 'std_num_wrong',
                               '-checked', 
                                  $fields{ 'std_num_wrong' } eq 't' ? 
                                           '1' : '0',
                               '-value', 'yes',
                               '-label', ''
                             );
  # DEBUG
  #       ( ,  
  #      { @{ $ref_labels } } 
  #  - %tmp,     ;
  #        :
  #      "")
  # print "\$fields{ 'std_num_code' } = $fields{ 'std_num_code' }" . "<BR>\n";
  # my %tmp = @{ $ref_labels };  
  # print "\$tmp{ \$fields{ 'std_num_code' } } = " .
  #       "$tmp{ $fields{ 'std_num_code' } }" . "<BR>\n"; 
  # if ( $tmp{ $fields{ 'std_num_code' } } ne "ISBN" &&
  #      $tmp{ $fields{ 'std_num_code' } } ne "ISSN" )

  #    "  "   "ISBN"  "ISSN",
  #      "   "
  if ( { @{ $ref_labels } }->{ $fields{ 'std_num_code' } } ne "ISBN" &&
       { @{ $ref_labels } }->{ $fields{ 'std_num_code' } } ne "ISSN"
     )
  {
    push( @std_num_wrong_params, '-disabled', 'disabled' );
  }

  print $query->checkbox( @std_num_wrong_params ),
        "</td>\n";
  print "</tr>\n";

  # --------------------------------------------------------------------
  print "<tr>\n";
  print "<th></th>\n";
  print "<td>";

  #   ()     
  #    
  create_hot_help( "document.forms[ 0 ].comment", "STD_NUMS_COMMENT" )
    if $CFG{ HOT_HELP_IS_ON };

  print $query->textarea( -name => 'comment',
                          -default => $fields{ 'comment' },
                          -rows => $CFG{ STD_NUMS_COMMENT_ROWS },
                          -columns => $CFG{ STD_NUMS_COMMENT_COLS }
                        ),
        "</td\n";
  print "</tr>\n";
  # --------------------------------------------------------------------

  print "</table>\n";
  return ( 0 );
}

# -----------------------------------------------------------------------------
#   ,    
#  -      
# -----------------------------------------------------------------------------
sub non_std_fields
{
  # :
  my $fname = shift;  #  
                      #   -   ( 
                      #  ).      
  my $value;
  
  #     (ISBN  ISSN)
  if ( $fname eq 'std_num_wrong' )
  {
    #     bool,    
    #   
    $value = $query->param( $fname ) ? 'yes' : 'no';
  }

  return ( $value );  
}

# -----------------------------------------------------------------------------
#          
# -----------------------------------------------------------------------------
sub print_add_info
{
  #  .    
  print_bib_record( $query, "  (ISBN, ISSN  .), " .
                    "   " );
  return ( 0 );
}
