#!/usr/bin/perl -w

# -----------------------------------------------------------------------------
# Система:  "Электронный архив"
# Модуль:   главный модуль 
# Автор:    Моргунов Е. П.
# Дата:     15.04.2012
# Версия:   0.6
# -----------------------------------------------------------------------------

use strict;
use CGI;
use CGI::Carp qw( fatalsToBrowser );
use Pg;                          # для работы с PostgreSQL

use E_ARCH;                      # пакет функций, написанных автором

# будем выводить стек вызовов функций
$SIG{ __DIE__ } = \&CGI::Carp::confess;

my $query;                       # CGI-объект

# имя пользователя, запустившего скрипт (пока это просто REMOTE_USER)
my $user = get_user_name(); 

my $exp_imp;                     # признак работы с данными экспорта/импорта

$query = CGI->new;

# если нужно, то будем добавлять параметр к именам скриптов в HTML-ссылках
# ПРИМЕЧАНИЕ. Этот скрипт может вызываться "сам из себя", поэтому у него
#             может оказаться параметр exp_imp.
$exp_imp = $query->param( 'exp_imp' ) ? "?exp_imp=1" : "";

# отменим буферизацию на устройствах
select( STDERR ); 
$| = 1;
select( STDOUT );
$| = 1;

# сформируем HTTP- и HTML-заголовки
http_html_headers( query => $query, target => "_top" );

# если выводим самую главную страницу (а не страницу для доступа
# к экспортируемым/импортируемым данным)
if ( ! $query->param( 'exp_imp' ) )
{
  # заголовок на странице
  print qq{<h1 class="program_title">ЭЛЕКТРОННЫЙ АРХИВ</h1>\n};
  print qq{<p id="version">Версия 0.6</p>\n};
  print qq{<p id="author">Автор: Моргунов Евгений Павлович</p>\n};
  print qq{<p id="author"><a class="mail_link" } .
        qq{href="mailto:$CFG\{ AUTHOR_EMAIL \}">} .
        "$CFG{ AUTHOR_EMAIL }</a></p>\n";
  print "</p>\n";
}
else
{
  # заголовок на странице
  my $module_title;
  
  $module_title = "Экспортируемые данные" if export_enabled();
  $module_title = "Импортируемые данные" if import_enabled();

  # используем типовую процедуру
  create_top_block( query => $query,
                    module_title => $module_title,
                    user => $user,
                    full_top => 'no'
                  );
}

# сформируем все необходимые ссылки с учетом того, является ли страница
# главной или нам нужен доступ к экспортируемым/импортируемым данным
make_links();

print $query->end_html();

exit( 0 );


# ----------------------------------------------------------------------------
# формирование списка ссылок
# ----------------------------------------------------------------------------
sub make_links
{
  print "<table class=\"main_screen\">\n";

  print "<tr>\n";
  print "<th>Библиографическая информация</th>\n";
  print "<th>Справочная информация</th>\n";
  print "</tr>\n";

  print "<tr>\n";
  print "<td>\n";

  print <<END_OF_FRAGMENT;
  <ul>
    <li><a href="bib_recs.pl$exp_imp" class="module_link">
        Библиографические описания (записи)</a></li>
    <br /><br />
    <li><a href="series.pl$exp_imp" class="module_link">
        Серии/подсерии</a></li>
    <li><a href="ser_descrs.pl$exp_imp" class="module_link">
        Описания серий/подсерий</a></li>
    <br /><br />
    <li><a href="obj_groups_descrs.pl$exp_imp" class="module_link">
        Тематические списки библиографических описаний</a></li>
END_OF_FRAGMENT
;

  # самая главная страница -- выведем ссылки для режимов экспорта и импорта
  # (при просмотре экспортируемых/импортируемых данных эти две ссылки не нужны)
  if ( ! $query->param( 'exp_imp' ) )
  {
    print <<END_OF_FRAGMENT;
      <br /><br />
      <li><a href="exp_imp.pl/export" class="module_link">
          Экспорт данных</a></li>
      <li><a href="exp_imp.pl/import" class="module_link">
          Импорт данных</a></li>
END_OF_FRAGMENT
;
  }
  print "</ul>\n";
  print "</td>\n";

  print "<td>\n";
  print <<END_OF_FRAGMENT;
  <ul>
    <li><a href="persons.pl$exp_imp" class="module_link">
        Персоналии</a></li>
    <li><a href="keywords.pl$exp_imp" class="module_link">
        Ключевые слова</a></li>
    <li><a href="orgs.pl$exp_imp" class="module_link">
        Организации, учреждения, временные коллективы</a></li>
    <li><a href="confs.pl$exp_imp" class="module_link">
        Конференции, съезды, симпозиумы, семинары, выставки ...</a></li>
    <li><a href="orgs_act.pl$exp_imp" class="module_link">
        Виды деятельности организаций, учреждений</a></li>
  </ul>
END_OF_FRAGMENT
;

  print "<ul>\n";
  # сформируем список справочников программным путем на основе 
  # конфигурационного файла
  make_refs_list();

  print "</ul>\n";
  print "</td>\n";

  print "</tr>\n";
  print "</table>\n";

  return;
}

# ----------------------------------------------------------------------------
# формирование списка ссылок на основе конфигурационного файла
# ----------------------------------------------------------------------------
sub make_refs_list
{
  my $html_ref;             # текст ссылки <a href>
  my @links = ();           # двухмерный массив описаний ссылок
  my @links_sorted;         # отсортированный массив описаний ссылок
  my $link;                 # ссылка на массив описания одной HTML-ссылки

  # массив описаний модулей-справочников, не представленных
  # в файле tables34.cfg
  my @other_modules = 
     ( [ 'countries.pl', 'Страны' ],
       [ 'cities.pl', 'Города' ],
       [ 'currencies.pl', 'Валюты' ],
       [ 'feature_types.pl', 'Виды признаков объектов ' .
                             'библиографического описания' ],
       [ 'gen_mater_types.pl', 'Коды общего обозначения материала' ],
       [ 'roles.pl', 'Роли' ],
       [ 'sci_specs.pl', 'Научные специальности' ],
       [ 'spec_mater_types.pl', 'Специфические обозначения материала' ]
     );

  # открываем конфигурационный файл с описаниями таблиц-справочников
  if ( ! open( TABLES, "< ./cfg/tables34.cfg" ) )
  {
    # выводим строку команды в лог
    print STDERR "Не удалось открыть файл tables34.cfg: $!\n"; 

    # завершаем работу скрипта
    die "Не удалось открыть файл tables34.cfg: $!\n";
  }

  while ( <TABLES> )
  {
    chomp;                  # уберем символ новой строки
    next if $_ =~ /^\s*$/;  # пустые строки (и строки из пробелов) пропускаем
    next if $_ =~ /^\s*#/;  # строки-комментарии пропускаем

    s/^\s*//;               # отбросим лидирующие и ...
    s/\s*$//;               # ... замыкающие пробелы

    # имя скрипта должно совпадать с именем таблицы (в нижнем регистре)
    if ( /^TABLE\s+(.+)$/ )
    {
      # формируем первую часть HTML-ссылки ...
      # учтем, что могут формироваться два варианта ссылок за счет $exp_imp
      # (базовый вариант и вариант для работы с данными экспорта/импорта)
      $html_ref = qq{  <li><a href="} . lc( $1 ) .
                  qq{.pl$exp_imp" class="module_link">};
    }
    elsif ( /^TITLE\s+(.+)$/ )
    {
      # ... дополним ее заголовком скрипта
      # (совпадает с наименованием таблицы БД)
      $html_ref .= $1 . "</a></li>";

      # будем формировать двухмерный массив описаний ссылок (первыми элементами
      # субмассивов являются наименования таблиц-справочников -- они-то и будут
      # служить в качестве сортируемых элементов)
      push( @links, [ $1, $html_ref ] );
    }
    else     # остальная информация в конфиг. файле нам не нужна
    {
      next;
    }
  }

  # закрываем конфигурационный файл с описаниями таблиц-справочников
  if ( ! close( TABLES ) )
  {
    # выводим строку команды в лог
    print STDERR "Не удалось закрыть файл tables34.cfg: $!\n"; 

    # завершаем работу скрипта
    die "Не удалось закрыть файл tables34.cfg: $!";
  }

  # дополним двухмерный массив описаниями HTML-ссылок на модули-справочники,
  # не представленные в файле tables34.cfg
  foreach $link ( @other_modules )
  {
    # формируем HTML-ссылку
    # учтем, что могут формироваться два варианта ссылок за счет $exp_imp
    $html_ref = qq{  <li><a href="$$link[ 0 ]$exp_imp" class="module_link">} .
                $$link[ 1 ] . "</a></li>";

    push( @links, [ $$link[ 1 ], $html_ref ] );
  }

  {
    # импортируем средства обработки локализационных параметров
    # из модуля POSIX
    use POSIX qw( locale_h );
    
    # сохраним текущее значение параметра LC_COLLATE, который управляет
    # порядком сортировки строк
    # (оно определяется настройками, сделанными для той учетной записи,
    # "из-под" которой запущен web-сервер Apache, например, www или daemon --
    # см. файл httpd.conf)
    my $old_locale = setlocale( LC_COLLATE );

    # назначим русский язык в кодировке, определяемой параметром CHARSET
    setlocale( LC_COLLATE, "ru_RU." . $CFG{ CHARSET } );

    use locale;

    # отсортируем двухмерный массив описаний HTML-ссылок
    # (нулевой элемент -- наименование справочника)
    @links_sorted = sort { $$a[ 0 ] cmp $$b[ 0 ] } @links;

    foreach $link ( @links_sorted )
    {
      print $$link[ 1 ] . "\n";    # выводим сформированную ссылку   
    }
               
    no locale;

    # восстановим исходное значение параметра LC_COLLATE
    setlocale( LC_COLLATE, $old_locale );
  }

  return ( 0 );
}
