#!/usr/bin/perl -w

# -----------------------------------------------------------------------------
# Система:  "Электронный архив"
# Модуль:   справочник "Коды общего обозначения материала"
# Автор:    Моргунов Е. П.
# Дата:     15.04.2012
# Версия:   0.6
# -----------------------------------------------------------------------------

use strict;
use CGI;
use CGI::Carp qw( fatalsToBrowser );
use Pg;                          # для работы с PostgreSQL

use E_ARCH;                      # пакет функций, написанных автором

# будем выводить стек вызовов функций
$SIG{ __DIE__ } = \&CGI::Carp::confess;

my $query;                       # CGI-объект
my $script_name;                 # имя этого скрипта (включая путь)

# условное наименование модуля (используется при определении прав 
# на выполнение тех или иных процедур)
my $module = 'GEN_MATER_TYPES';

# имя пользователя, запустившего скрипт (пока это просто REMOTE_USER)
my $user = get_user_name(); 

# массив имен полей таблицы Gen_mater_types
my @f_names =
   ( 'gen_mat_code',      # Код общего обозначения материала
     'gen_mat_name',      # Наименование общего обозначения материала
     'gen_mat_code_orig', # Код общего обозначения материала, являющийся
                          # началом цепочки (для учета написаний на различных
                          # языках)
     'lang_code',         # Код языка (1 - русский язык)
     'comment'            # Примечание
   );

my $db_schema;                     # схема БД (для экспорта/импорта)

$query = CGI->new();               # создадим новый CGI-объект

# отменим буферизацию на устройствах
select( STDERR ); 
$| = 1;
select( STDOUT );
$| = 1;

$script_name = $query->script_name;

# в имя схемы экспорта/импорта включим и точку, отделяющую имя таблицы
# от имени схемы; при отсутствии имени схемы в SQL-команде не окажется
# этой точки, что нам и нужно
$db_schema = $query->param( 'exp_imp' ) ? "exp_imp." : "";

# организуем выполнение стандартного набора режимов работы
common_modes( query => $query,
              module => $module,
              user => $user,
              make_form => \&make_form,
              make_command => \&make_command,
              check_param => \&check_param,
              create_top => \&create_top,
              do_query => \&do_query,
              do_view => \&do_view,
              do_add => \&do_add,
              do_del => \&do_del,
              do_find => \&do_find,
              do_export => \&do_export,
              do_import => \&do_import,
              add_rec => \&add_rec,
              update_rec => \&update_rec,
              action => $script_name
            );

exit( 0 );


# -----------------------------------------------------------------------------
# проверка значений параметров формы
# -----------------------------------------------------------------------------
sub check_param
{
  my $no_errors = 1;        # флаг отсутствия ошибок в параметрах
  my @error_messages = ();  # массив для сбора сообщений об ошибках при вводе

  if ( $query->param( 'gen_mat_code' ) eq '' )
  {
    push( @error_messages, "Не указан код общего обозначения материала" );
  }

  if ( $query->param( 'gen_mat_name' ) eq '' )
  {
    push( @error_messages, "Не указано наименование общего обозначения " .
          "материала" );
  }

  # допускается либо пустое поле, либо только цифры
  if ( $query->param( 'gen_mat_code_orig' ) !~ /^\d*$/ )
  {
    push( @error_messages, "Неверный код общего обозначения материала, " .
          "являющийся началом цепочки" );
  }

  if ( $query->param( 'lang_code' ) eq '' )
  {
    push( @error_messages, "Не указан код языка" );
  }

  # DEBUG
  # print_params( $query );

  # выведем сообщения об ошибках, если они есть
  if ( scalar @error_messages != 0 )
  {
    print_user_err_msgs( \@error_messages );
    $no_errors = 0;
  }
  
  return ( $no_errors );
}

# -----------------------------------------------------------------------------
# формирование верхней части окна, содержащей заголовок модуля и список
# "команд" для пользователя
# -----------------------------------------------------------------------------
sub create_top
{
  # используем типовую процедуру
  create_top_block( query => $query,
                    module => $module,
                    module_title => 'Коды общего обозначения материала',
                    user => $user
                  );
  return ( 0 );
}

# -----------------------------------------------------------------------------
# удаление записи
# -----------------------------------------------------------------------------
sub do_del
{
  my $gen_mat_code;          # код общего обозначения материала
  my $command;               # строка команды для работы с БД

  $gen_mat_code = $query->param( 'gen_mat_code' );
  
  # должна быть удалена только ОДНА запись с таким ключом
  $command = "DELETE FROM ${db_schema}gen_mater_types " .
             "WHERE gen_mat_code = '$gen_mat_code'";

  # используем типовую процедуру
  del_rec( query => $query,
           create_top => \&create_top,
           target => "_self",
           command => $command
         );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# экспортирование записи
# -----------------------------------------------------------------------------
sub do_export
{
  my $gen_mat_code;          # код общего обозначения материала
  my $command;               # строка команды для работы с БД
  my @table_cmd_pairs = ();  # массив ссылок на двухэлементные массивы,
                             # содержащие имя таблицы и команду для нее

  $gen_mat_code = $query->param( 'gen_mat_code' );

  # сформируем строку-команду для выборки данных из таблицы и поместим
  # ее в массив (используем ссылку на массив из двух элементов, первым
  # из которых является имя таблицы)
  $command = "SELECT * FROM Gen_mater_types " .
             "WHERE gen_mat_code = $gen_mat_code";
  push( @table_cmd_pairs, [ 'Gen_mater_types', $command ] );

  # вызываем стандартную процедуру экспорта
  export_data( query => $query,
               create_top => \&create_top,
               table_cmd_pairs => \@table_cmd_pairs
             );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# организация формы для выполнения поиска информации
# -----------------------------------------------------------------------------
sub do_find
{
  # сформируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => "_self" );

  open_top();       # начинаем оформление верхней части окна
  create_top();     # формируем верхнюю часть окна
  close_top();      # завершаем оформление верхней части окна
  
  open_bottom();    # начинаем оформление нижней части окна
  
  print "<p class=\"info\">В настоящее время поиск не реализован</p>\n";

  close_bottom();   # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# импортирование записи
# -----------------------------------------------------------------------------
sub do_import
{
  my $gen_mat_code;          # код общего обозначения материала
  my $command;               # строка команды для работы с БД
  my @table_cmd_pairs = ();  # массив ссылок на двухэлементные массивы,
                             # содержащие имя таблицы и команду для нее

  $gen_mat_code = $query->param( 'gen_mat_code' );

  # сформируем строку-команду для выборки данных из таблицы и поместим
  # ее в массив (используем ссылку на массив из двух элементов, первым
  # из которых является имя таблицы)
  $command = "SELECT * FROM exp_imp.Gen_mater_types " .
             "WHERE gen_mat_code = $gen_mat_code";
  push( @table_cmd_pairs, [ 'Gen_mater_types', $command ] );

  # вызываем стандартную процедуру импорта
  import_data( query => $query,
               create_top => \&create_top,
               table_cmd_pairs => \@table_cmd_pairs
             );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# вывод списка всех кодов общего обозначения материала
# -----------------------------------------------------------------------------
sub do_query
{
  my( $result, $i );              # для работы с БД
  my @row;                        # для хранения одной записи из выборки
  my $command;                    # строка команды для работы с БД

  # имеет ли пользователь право на просмотр записи в виде HTML-формы
  # и удаление записи
  my $can_view = 0;
  my $can_delete = 0;

  # имеет ли пользователь право на экспортирование/импортирование записи
  my $can_export = 0;
  my $can_import = 0;

  # дополнительные параметры для скрипта при выполнении режимов просмотра
  # и удаления (цель -- ретранслировать эти параметры от одного запуска
  # скрипта к другому)
  my $add_params = '';

  # признак того, что текущую строку таблицы нужно выводить другим цветом
  my $alt_row = 1;

  my $href;    # типовая часть HTML-ссылки

  # при использовании данного модуля в режиме справочника будут существовать
  # параметры enable_select и caller_name (имя вызывающего модуля)
  if ( $query->param( 'enable_select' ) )
  {
    $add_params = "&enable_select=1&caller_name=" .
                  $query->param( 'caller_name' );
  }

  # сформируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => "_self" );

  open_top();       # начинаем оформление верхней части окна
  create_top();     # формируем верхнюю часть окна
  close_top();      # завершаем оформление верхней части окна

  open_bottom();    # начинаем оформление нижней части окна

  # выбираем все записи о кодах общего обозначения материала (а также 
  # наименование материала, являющегося началом цепочки, и краткое
  # наименование языка, на котором записано название обозначения материала)
  $command = "SELECT g1.*, g2.gen_mat_name AS gen_mat_name_orig, " .
                    "l.lang_sname " .
             "FROM ( ${db_schema}gen_mater_types g1 " .
                  "LEFT JOIN ${db_schema}gen_mater_types g2 " .
                  "ON g1.gen_mat_code_orig = g2.gen_mat_code ), " .
                  "${db_schema}langs l " .
             "WHERE g1.lang_code = l.lang_code " .
             "ORDER BY g1.gen_mat_name";

  $result = exec_select( $command );    # сделаем выборку из БД
  
  if ( $result )
  {
    # если этот модуль вызван в режиме справочника, и при этом он вызван
    # "сам из себя", то запретим операции просмотра и удаления записей
    # (поскольку режим корректировки выполняется из режима просмотра,
    # то и он будет недоступен)
    if ( $query->param( 'enable_select' ) &&
         $query->param( 'caller_name') eq $module )
    {
      $can_view = 0;
      $can_delete = 0;
    }
    else
    {
      $can_view = have_access( 'module' => $module, 'procedure' => 'VIEW', 
                               'user' => $user );
      $can_delete = have_access( 'module' => $module, 'procedure' => 'DELETE',
                                 'user' => $user );
    }

    # работаем со схемой БД "экспорт/импорт", поэтому экспорт не имеет смысла
    if ( $query->param( 'exp_imp' ) )
    {
      $can_import = import_enabled() && 
                    have_access( 'module' => $module, 'procedure' => 'IMPORT',
                                 'user' => $user );
    }
    # работаем со схемой public -- можем экспортировать данные,
    # а импортировать -- нет
    else
    {
      $can_export = export_enabled() && 
                    have_access( 'module' => $module, 'procedure' => 'EXPORT',
                                 'user' => $user );
    }

    # выведем информацию в виде таблицы
    print "<table class=\"list\">\n";
    print "<tr>\n";
    print "<th>Код обозначения</th>\n";
    print "<th>Наименование общего обозначения материала</th>\n";
    print "<th>Обозначение материала &mdash; начало цепочки " .
          "(код и наименование)</th>\n";
    print "<th>Язык</th>\n";
    print "<th>&nbsp;</th>\n" if ( $can_view || $can_delete || $can_export ||
                                   $can_import );
    print "</tr>\n";

    # если модуль вызван в режиме справочника для оказания помощи пользователю
    # при выборе конкретного кода общего обозначения материала ...
    if ( $query->param( 'enable_select' ) )
    {
      # ... то сформируем функцию JavaScript для присваивания значений полей
      # из текущей записи таблицы Gen_mater_types полям в ВЫЗЫВАЮЩЕМ окне ...
      if ( $query->param( 'caller_name' ) eq 'GEN_MATER_TYPES' )
      {
        # ... полям gen_mat_code_orig и gen_mat_name_orig в модуле 
        # GEN_MATER_TYPES
        create_assign_values_func( 'gen_mat_code_orig', 'gen_mat_name_orig' );
      }
    }

    # выводим все записи из полученной выборки
    while ( @row = $result->fetchrow )
    {
      # если включен флаг альтернативной раскраски строк в таблице
      if ( $CFG{ ALT_ROWS_IS_ON } )
      {
        $alt_row = ! $alt_row;
        print ( ( $alt_row ) ? "<tr class=\"alt_row\">\n" : "<tr>\n" );
      }
      else
      {
        print "<tr>\n";
      }

      # выводим код обозначения, наименование общего обозначения материала,
      # код и наименование обозначения материала -- начала цепочки, язык, 
      # на котором написано наименование общего обозначения материала
      # (добавим символ &nbsp; к коду обозначения материала, являющемуся
      # началом цепочки, из соображений эстетики: если значение поля
      # 'gen_mat_code_orig' равно null, то не отображаются горизонтальные
      # строки-разделители)
      print "<td class=\"center\">" .
            "$row[ $result->fnumber( 'gen_mat_code' ) ]</td>\n";

      # если модуль вызван в режиме справочника для оказания помощи
      # пользователю при выборе конкретного общего обозначения материала,
      # то значение поля gen_mat_name выведем в виде ссылки
      if ( $query->param( 'enable_select' ) )
      {
        print "<td>",
              qq{ <a class="command_link" href="javascript:void( 0 )" onclick=
                  "assign_values( $row[ $result->fnumber( 'gen_mat_code' ) ],
                                  '$row[ $result->fnumber( 'gen_mat_name' ) ]'
                                )">
                   $row[ $result->fnumber( 'gen_mat_name' ) ]</a> },
              "</td>\n";
      }
      else
      {
        print "<td>$row[ $result->fnumber( 'gen_mat_name' ) ]</td>\n";
      }

      # если общее обозначение материала, являющееся началом цепочки,
      # отсутствует, то выведем лишь символ пробела "&nbsp;"
      print "<td>",
            ( $row[ $result->fnumber( 'gen_mat_code_orig' ) ] ne undef ) ?
              "(" . $row[ $result->fnumber( 'gen_mat_code_orig' ) ] . ") " .
              $row[ $result->fnumber( 'gen_mat_name_orig' ) ] :
            "&nbsp;",
            "</td>\n";

      print "<td>$row[ $result->fnumber( 'lang_sname' ) ]</td>\n";

      # типовая часть HTML-ссылки
      $href = ( $query->param( 'exp_imp' ) ? "exp_imp=1&" : "" ) .
              "gen_mat_code=" . $row[ $result->fnumber( 'gen_mat_code' ) ] .
              $add_params;

      # просмотр общего обозначения материала в виде формы
      print "<td>" if ( $can_view || $can_delete || $can_export ||
                        $can_import );
      print qq{ <a class="command_link" href="$script_name/view?$href"} .
            qq{ target="_self">Просмотр</a> } . "\n"  if $can_view;

      # удаление записи об общем обозначении материала
      print qq{ <a class="command_link" href="$script_name/delete?$href"} .
            qq{ onclick="$confirm_delete" } .
            qq{ target="_self">Удаление</a> } . "\n"  if $can_delete;

      # экспортирование записи 
      print qq{ <a class="command_link" href="$script_name/export?$href"} .
            qq{ onclick="$confirm_export"} .
            qq{ target="_blank">Экспорт</A> } . "\n" if $can_export;

      # импортирование записи 
      print qq{ <a class="command_link" href="$script_name/import?$href"} .
            qq{ onclick="$confirm_import"} .
            qq{ target="_blank">Импорт</A> } . "\n" if $can_import;

      print "</td>" if ( $can_view || $can_delete || $can_export ||
                         $can_import );
      print "</tr>\n";
    }
    print "</table>\n";
  }

  close_bottom();   # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# просмотр одной записи в виде формы
# -----------------------------------------------------------------------------
sub do_view
{
  my $gen_mat_code;          # код общего обозначения материала
  my $command;               # строка команды для работы с БД

  $gen_mat_code = $query->param( 'gen_mat_code' );

  # выбираем одну запись об общем обозначении материала
  # выберем также название общего обозначения материала, являющегося началом
  # цепочки
  $command = "SELECT g1.*, g2.gen_mat_name AS gen_mat_name_orig " .
             "FROM ${db_schema}gen_mater_types g1 " .
                  "LEFT JOIN ${db_schema}gen_mater_types g2 " .
                  "ON g1.gen_mat_code_orig = g2.gen_mat_code " .
             "WHERE g1.gen_mat_code = '$gen_mat_code'"; 

  # используем типовую процедуру
  view_rec( query => $query,
            create_top => \&create_top,
            make_form => \&make_form,
            action => $script_name,
            target => "_self",
            submit_name => "submit_update",
            submit_value => "Записать изменения в базу данных",
            command => $command,
            error => "В базе данных имеется более одной записи с кодом " .
                     "общего обозначения материала " . $gen_mat_code,
            can_update => have_access( 'module' => $module, 
                                       'procedure' => 'UPDATE', 
                                       'user' => $user )
        );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# формирование строки-команды для выполнения добавления и корректировки записи
# -----------------------------------------------------------------------------
sub make_command
{
  my $operation = shift; # какая команда - вставка или корректировка?

  my $command;           # строка-команда

  # используем типовую процедуру
  # параметры: в том числе
  # - ссылка на массив имен полей этой таблицы БД, требующих специальной
  #   обработки (f_special);
  # - ссылка на функцию для обработки таких полей (func_special)
  $command = make_cmd( query => $query,
                       operation => $operation,
                       table => "gen_mater_types",
                       key => "gen_mat_code",
                       f_names => \@f_names,
                       f_special => undef,
                       func_special => undef,
                       user => $user
                     );

  return ( $command );
}

# -----------------------------------------------------------------------------
# создание формы для просмотра (корректировки) и добавления записей
# -----------------------------------------------------------------------------
sub make_form
{
  # параметры
  my $ref_row = shift;  # ссылка на массив, содержащий одну запись из выборки
  my $res = shift;      # результат выборки

  my $i;
  my %fields = ();  # хеш-массив с информацией о начальных значениях полей

  # получим две ссылки на массивы (они используются при формировании списка
  # языков, на которых записаны общие обозначения материала)
  my( $ref_values, $ref_labels ) = popup_langs_list( $db_schema );

  # если передан параметр - ссылка на массив значений полей одной записи
  # из выборки, ...
  if ( $ref_row ne undef )
  {
    # ... то сформируем хеш-массив, в котором...
    for $i ( 0 .. $res->nfields - 1 )
    {
      # ... каждому полю соответствует значение ключа, равное имени этого поля
      # (имя поля определим по его номеру - см. Pg.pm)
      $fields{ $res->fname( $i ) } = $$ref_row[ $i ];
    }
  }
  else                      # режим ввода новой записи в БД
  {
    # будем предлагать пользователю значение ключевого поля для новой записи,
    # которое на 1 больше максимального значения этого поля в данной таблице
    $fields{ 'gen_mat_code' } = get_next_key_value( 'gen_mater_types',
                                                    'gen_mat_code' );
    # значения по умолчанию

    # наименование общего обозначения материала
    $fields{ 'gen_mat_name' }      = $CFG{ GEN_MATER_TYPES_GEN_MAT_NAME };

    # код общего обозначения материала, являющийся началом цепочки
    # (для учета написаний на различных языках)
    $fields{ 'gen_mat_code_orig' } = $CFG{ GEN_MATER_TYPES_GEN_MAT_CODE_ORIG };

    # код языка (1 - русский язык)
    $fields{ 'lang_code' }         = $CFG{ GEN_MATER_TYPES_LANG_CODE };
    
    # примечание
    $fields{ 'comment' }           = $CFG{ GEN_MATER_TYPES_COMMENT };
  }
  # -------------------------------------------------------------------

  # включим в текст HTML-документа обращение к исходному файлу с кодом функции
  # insert_str_into_field(), которая позволяет вставить фрагмент текста
  # в поле HTML-формы
  print <<END_OF_SCRIPT;
  <script language="JavaScript" type="text/javascript"
          src="/$CFG{ HOME_WEB_JS_DIR }/insert_text.js"></script>
END_OF_SCRIPT
  ;

  # поскольку значение поля "Код общего обозначения материала" формируется
  # автоматически с использованием функции get_next_key_value(), не будем
  # позволять его редактировать, но совсем убрать его нельзя, т.к. оно
  # используется при выполнении операции UPDATE в качестве ключа
  print $query->hidden( -name => 'gen_mat_code',
                        -default => $fields{ 'gen_mat_code' }
                      ), "\n";

  # ретранслируем параметр exp_imp, если он был, для следующего вызова
  # этого скрипта (он нужен для определения схемы БД: exp_imp или public)
  print $query->hidden( -name => 'exp_imp' ), "\n";

  print "<table class=\"form\">\n";

  print "<tr>\n";
  print "<th>Код общего обозначения материала</th>\n";
  print "<td>", $fields{ 'gen_mat_code' }, "</td>\n";
  print "</tr>\n";

  print "<tr>\n";
  print "<th>Наименование общего обозначения материала</th>\n";
  print "<td>",
        $query->textfield( -name => 'gen_mat_name',
                           -default => $fields{ 'gen_mat_name' },
                           -size => $CFG{ GEN_MATER_TYPES_GEN_MAT_NAME_SIZE },
                           -maxlength =>
                             $CFG{ GEN_MATER_TYPES_GEN_MAT_NAME_MAXLENGTH }
                         ),
        "</td>\n";
  print "</tr>\n";

  print "<tr>\n";
  print "<th>Общее обозначение материала &mdash; начало цепочки " .
        "(код и наименование)</th>\n";

  # сформируем текст функции на языке JavaScript, которая вызывает
  # модуль-справочник gen_mater_types.pl
  create_selection_func( func_name => 'select_orig_gen_mat_type',
                         module_name => 'gen_mater_types.pl',
                         caller_name => $module,
                         window_name => 'orig_gen_mat_type',
                         exp_imp => $query->param( 'exp_imp' ) );

  # выведем также название общего обозначения материала, являющегося началом
  # цепочки (без возможности редактирования)
  print "<td>",
        $query->textfield( -name => 'gen_mat_code_orig',
                           -default => $fields{ 'gen_mat_code_orig' },
                           -size => 
                             $CFG{ GEN_MATER_TYPES_GEN_MAT_CODE_ORIG_SIZE },
                           -maxlength =>
                             $CFG{ 'GEN_MATER_TYPES_' .
                                   'GEN_MAT_CODE_ORIG_MAXLENGTH' }
                         ),
        "&nbsp;&nbsp;",
        $query->textfield( -name => 'gen_mat_name_orig',
                           -default => $fields{ 'gen_mat_name_orig' },
                           -size => 
                             $CFG{ GEN_MATER_TYPES_GEN_MAT_NAME_ORIG_SIZE },
                           -maxlength =>
                             $CFG{ 'GEN_MATER_TYPES_' .
                                   'GEN_MAT_NAME_ORIG_MAXLENGTH' },
                           -readonly => 'readonly'
                         ),
        "&nbsp;&nbsp;",
        qq{ <a class="command_link" href="javascript:void( 0 )" onclick=} .
        qq{"select_orig_gen_mat_type()">} . "Список</a>",
        "</td>\n";
  print "</tr>\n";

  print "<tr>\n";
  
  # для получения ссылки на хеш в параметре labels используем сложную
  # конструкцию, поскольку в функции popup_langs_list() формируется не хеш,
  # а массив - заготовка для хеша
  print "<th>Язык</th>\n";
  print "<td>",
        $query->popup_menu( -name => 'lang_code',
                            -default => $fields{ 'lang_code' },
                            -values => $ref_values,
                            -labels => { @{ $ref_labels } }
                          ),
        "</td>\n";
  print "</tr>\n";
  
  # --------------------------------------------------------------------
  print "<tr>\n";
  print "<th>Комментарий</th>\n";
  print "<td>";

  # создадим ссылки (кнопки) для быстрой вставки фрагментов текста
  # в поле на экране
  create_hot_help( "document.forms[ 0 ].comment",
                   "GEN_MATER_TYPES_COMMENT" ) if $CFG{ HOT_HELP_IS_ON };

  print $query->textarea( -name => 'comment',
                          -default => $fields{ 'comment' },
                          -rows => $CFG{ GEN_MATER_TYPES_COMMENT_ROWS },
                          -columns => $CFG{ GEN_MATER_TYPES_COMMENT_COLS }
                        ),
        "</td>\n";
  print "</tr>\n";
  # --------------------------------------------------------------------

  print "</table>\n";
  return ( 0 );
}
