#!/usr/bin/perl -w

# -----------------------------------------------------------------------------
# Система:  "Электронный архив"
# Модуль:   "Виды деятельности организаций, учреждений"
# Автор:    Моргунов Е. П.
# Дата:     15.04.2012
# Версия:   0.6
# -----------------------------------------------------------------------------

use strict;
use CGI;
use CGI::Carp qw( fatalsToBrowser );
use Pg;                          # для работы с PostgreSQL

use E_ARCH;                      # пакет функций, написанных автором

# будем выводить стек вызовов функций
$SIG{ __DIE__ } = \&CGI::Carp::confess;

my $query;                       # CGI-объект
my $script_name;                 # имя этого скрипта (включая путь)

# условное наименование модуля (используется при определении прав 
# на выполнение тех или иных процедур)
my $module = 'ORGS_ACT';

# имя пользователя, запустившего скрипт (пока это просто REMOTE_USER)
my $user = get_user_name(); 

# массив имен полей таблицы Orgs_act
my @f_names =
   ( 'org_id',         # Уникальный идентификатор организации
     'act_type_code',  # Код вида деятельности
     'comment'         # Примечание
   );

my $db_schema;                     # схема БД (для экспорта/импорта)

$query = CGI->new();               # создадим новый CGI-объект

# отменим буферизацию на устройствах
select( STDERR ); 
$| = 1;
select( STDOUT );
$| = 1;

$script_name = $query->script_name;

# в имя схемы экспорта/импорта включим и точку, отделяющую имя таблицы
# от имени схемы; при отсутствии имени схемы в SQL-команде не окажется
# этой точки, что нам и нужно
$db_schema = $query->param( 'exp_imp' ) ? "exp_imp." : "";

# организуем выполнение стандартного набора режимов работы
common_modes( query => $query,
              module => $module,
              user => $user,
              make_form => \&make_form,
              make_command => \&make_command,
              check_param => \&check_param,
              create_top => \&create_top,
              do_query => \&do_query,
              do_view => \&do_view,
              do_add => \&do_add,
              do_del => \&do_del,
              do_find => \&do_find,
              add_rec => \&add_rec,
              update_rec => \&update_rec,
              action => $script_name
            );

exit( 0 );


# -----------------------------------------------------------------------------
# проверка значений параметров формы
# -----------------------------------------------------------------------------
sub check_param
{
  my $no_errors = 1;        # флаг отсутствия ошибок в параметрах
  my @error_messages = ();  # массив для сбора сообщений об ошибках при вводе

  if ( $query->param( 'org_id' ) eq '' )
  {
    push( @error_messages, "Не указан уникальный идентификатор организации" );
  }

  if ( $query->param( 'act_type_code' ) eq '' )
  {
    push( @error_messages, "Не указан код вида деятельности" );
  }

  # DEBUG
  # print_params( $query );

  # выведем сообщения об ошибках, если они есть
  if ( scalar @error_messages != 0 )
  {
    print_user_err_msgs( \@error_messages );
    $no_errors = 0;
  }
  
  return ( $no_errors );
}

# -----------------------------------------------------------------------------
# формирование верхней части окна, содержащей заголовок модуля и список
# "команд" для пользователя
# -----------------------------------------------------------------------------
sub create_top
{
  # используем типовую процедуру
  create_top_block( query => $query,
                    module => $module,
                    module_title => 'Виды деятельности организаций, ' .
                                    'учреждений',
                    user => $user,
                    make_letters => 'yes',
                    num_last_recs => $CFG{ ORGS_ACT_NUM_LAST_RECS },
                    full_top => 'yes'
                  );
  return ( 0 );
}

# -----------------------------------------------------------------------------
# удаление записи
# -----------------------------------------------------------------------------
sub do_del
{
  my $org_id;             # уникальный идентификатор организации
  my $act_type_code;      # код вида деятельности
  my $command;            # строка команды для работы с БД

  $org_id        = $query->param( 'org_id' );
  $act_type_code = $query->param( 'act_type_code' );
  
  # должна быть удалена только ОДНА запись с таким ключом
  $command = "DELETE FROM ${db_schema}orgs_act " .
             "WHERE org_id = '$org_id' AND " .
                   "act_type_code = '$act_type_code'";

  # используем типовую процедуру
  del_rec( query => $query,
           create_top => \&create_top,
           target => "_self",
           command => $command
         );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# организация формы для выполнения поиска информации
# -----------------------------------------------------------------------------
sub do_find
{
  # сформируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => "_self" );

  open_top();       # начинаем оформление верхней части окна
  create_top();     # формируем верхнюю часть окна
  close_top();      # завершаем оформление верхней части окна
  
  open_bottom();    # начинаем оформление нижней части окна
  
  print "<p class=\"info\">В настоящее время поиск не реализован</p>\n";

  close_bottom();   # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# вывод списка всех видов деятельности организаций, учреждений
# -----------------------------------------------------------------------------
sub do_query
{
  my( $result, $i );              # для работы с БД
  my @row;                        # для хранения одной записи из выборки
  my $command;                    # строка команды для работы с БД
  my $letter;                     # первая буква наименования организации
  my $letter_lower;               # первая буква -- в нижнем регистре

  # число последних записей, введенных в таблицу, которые нужно выводить
  # при обращении по специальной ссылке
  my $num_last_recs;

  # условие WHERE, ORDER BY и LIMIT для команды выборки
  my $condition;

  # имеет ли пользователь право на просмотр записи в виде HTML-формы
  # и удаление записи
  my $can_view = 0;
  my $can_delete = 0;

  # признак того, что текущую строку таблицы нужно выводить другим цветом
  my $alt_row = 1;

  my $href;    # типовая часть HTML-ссылки

  # сформируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => "_self" );

  open_top();       # начинаем оформление верхней части окна
  create_top();     # формируем верхнюю часть окна
  close_top();      # завершаем оформление верхней части окна

  open_bottom();    # начинаем оформление нижней части окна

  $letter        = $query->param( 'letter' );
  $num_last_recs = $query->param( 'num_last_recs' );

  # если параметры не переданы, то просто завершаем работу досрочно - 
  # это происходит при первоначальном запуске скрипта
  # ПРИМЕЧАНИЕ. Проверка как на undef, так и на пустое значение '' выполнена
  #             на случай каких-либо проблем в CGI.pm.
  if ( ( $letter eq undef || $letter eq '' ) &&
       ( $num_last_recs eq undef || $num_last_recs eq '' )
     )
  {
    close_bottom();   # завершаем оформление нижней части окна
    print $query->end_html();
    return ( 0 );
  }

  # если пользователь выбрал ссылку для вывода только последних записей,
  # введенных в таблицу
  if ( $num_last_recs )
  {
    # ПРИМЕЧАНИЕ. Если даже требуемое число последних введенных записей будет
    #             больше числа всех записей, имеющихся в таблице, этот 
    #             оператор сработает. Если какие-то записи были удалены,
    #             вследствие чего образовались "дырки" в нумерации org_id,
    #             то просто будет выведено меньшее число записей.
    # ПРИМЕЧАНИЕ. Поскольку для каждого предприятия может быть введено более
    #             одной записи о виде его деятельности, то нужно учитывать
    #             следующее:
    #             - число выводимых записей может быть больше, чем
    #             предписывает переменная $num_last_recs;
    #             - выводятся записи, имеющие значение поля org_id, попадающее
    #             в диапазон от (max - $num_last_recs + 1) до max, поэтому
    #             если фактически последней (по времени) была введена запись
    #             для организации, уже представленной в этой таблице каким-то
    #             другим видом деятельности, но значение поля org_id для
    #             этой новой записи не попало в указанный диапазон, то данная
    #             запись выведена на экран НЕ БУДЕТ.
    # условие WHERE, ORDER BY и LIMIT для команды выборки
    # ПРИМЕЧАНИЕ. Этот длинный комментарий был написан, когда задача
    #             вывода последних записей решалась без использования
    #             предложения LIMIT (см. аналогичные SQL-операторы в других
    #             модулях, например, persons.pl).
    $condition = "WHERE oa.org_id = o.org_id AND " .
                       "oa.act_type_code = a.act_type_code " .
                 "ORDER BY oa.org_id DESC, a.act_type_sname " .
                 "LIMIT $num_last_recs";
  }
  # пользователь выбрал конкретную букву или другой символ
  elsif ( $letter )
  {
    # для русских букв может потребоваться особая предварительная обработка
    $letter = reveal_rus_letter( $letter );

    # воспользуемся возможностями локализации для перевода буквы, выбранной
    # пользователем, в нижний регистр
    $letter_lower = change_case( $letter, 'lower' );

    # условие WHERE, ORDER BY и LIMIT для команды выборки
    # если первый символ названия организации -- двойные кавычки, 
    # то не учитываем его
    # используем функцию lower(), чтобы аббревиатуры не нарушали порядок
    # сортировки (если первый символ в поле -- кавычки, то не учитываем его,
    # а берем значение поля, начиная со второго символа)
    $condition = "WHERE oa.org_id = o.org_id AND " .
                       "oa.act_type_code = a.act_type_code AND " .
                       "o.org_sname ~ '^($letter|\"$letter|" .
                                        "$letter_lower|\"$letter_lower)' " .
                 "ORDER BY CASE WHEN o.org_sname ~ '^\"' " .
                               "THEN lower( substr( o.org_sname, 2 ) ) " .
                               "ELSE lower( o.org_sname ) " .
                          "END, " .
                          "a.act_type_sname";
  }

  # выбираем все записи о видах деятельности (а также краткое наименование
  # организации и краткое наименование вида деятельности)
  $command = "SELECT oa.*, o.org_sname, a.act_type_sname " .
             "FROM ${db_schema}orgs_act oa, ${db_schema}orgs o, " .
                  "${db_schema}activity_types a " .
             $condition;

  $result = exec_select( $command );    # сделаем выборку из БД
  
  if ( $result )
  {
    # если это список записей, введенных в таблицу последними, то укажем это
    if ( $num_last_recs )
    {
      print "<h3>Записи, введенные в базу данных последними (" . 
            $num_last_recs . " шт.)</h3>\n";
    }

    $can_view = have_access( 'module' => $module, 'procedure' => 'VIEW', 
                             'user' => $user );
    $can_delete = have_access( 'module' => $module, 'procedure' => 'DELETE',
                               'user' => $user );

    # выведем информацию в виде таблицы
    print "<table class=\"list\">\n";
    print "<tr>\n";
    print "<th>Код организации</th>\n";
    print "<th>Краткое наименование организации</th>\n";
    print "<th>Вид деятельности</th>\n";
    print "<th>&nbsp;</th>\n" if ( $can_view || $can_delete );
    print "</tr>\n";

    # выводим все записи из полученной выборки
    while ( @row = $result->fetchrow )
    {
      # если включен флаг альтернативной раскраски строк в таблице
      if ( $CFG{ ALT_ROWS_IS_ON } )
      {
        $alt_row = ! $alt_row;
        print ( ( $alt_row ) ? "<tr class=\"alt_row\">\n" : "<tr>\n" );
      }
      else
      {
        print "<tr>\n";
      }

      # выводим уникальный идентификатор организации, ее краткое наименование
      # и вид деятельности
      print "<td class=\"center\">$row[ $result->fnumber( 'org_id' ) ]</td>\n";
      print "<td>$row[ $result->fnumber( 'org_sname' ) ]</td>\n";
      print "<td>$row[ $result->fnumber( 'act_type_sname' ) ]</td>\n";

      # типовая часть HTML-ссылки
      $href = ( $query->param( 'exp_imp' ) ? "exp_imp=1&" : "" ) .
              "org_id=" . $row[ $result->fnumber( 'org_id' ) ] .
              "&act_type_code=" . $row[ $result->fnumber( 'act_type_code' ) ];

      # просмотр данного вида деятельности данной организации в виде формы
      print "<td>" if ( $can_view || $can_delete );
      print qq{ <a class="command_link" href="$script_name/view?$href"} .
            qq{ target="_self">Просмотр</a> } . "\n" if $can_view;

      # удаление записи для данного вида деятельности данной организации
      print qq{ <a class="command_link" href="$script_name/delete?$href"} .
            qq{ onclick="$confirm_delete" } .
            qq{ target="_self">Удаление</a> } . "\n"  if $can_delete;

      print "</td>\n" if ( $can_view || $can_delete );
      print "</tr>\n";
    }
    print "</table>\n";
  }

  close_bottom();   # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# просмотр одной записи в виде формы
# -----------------------------------------------------------------------------
sub do_view
{
  my $org_id;             # уникальный идентификатор организации
  my $act_type_code;      # код вида деятельности
  my $command;            # строка команды для работы с БД

  $org_id        = $query->param( 'org_id' );
  $act_type_code = $query->param( 'act_type_code' );

  # выбираем одну запись о виде деятельности данной организации
  $command = "SELECT oa.*, o.org_fname " .
             "FROM ${db_schema}orgs_act oa, ${db_schema}orgs o " .
             "WHERE oa.org_id = '$org_id' AND " .
                   "oa.org_id = o.org_id AND " .
                   "oa.act_type_code = '$act_type_code'";

  # используем типовую процедуру
  view_rec( query => $query,
            create_top => \&create_top,
            make_form => \&make_form,
            action => $script_name,
            target => "_self",
            submit_name => "submit_update",
            submit_value => "Записать изменения в базу данных",
            command => $command,
            error => "В базе данных имеется более одной записи с " .
                     "идентификатором организации " . $org_id .
                     " и кодом вида деятельности " . $act_type_code,
            can_update => have_access( 'module' => $module, 
                                       'procedure' => 'UPDATE', 
                                       'user' => $user )
        );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# формирование строки-команды для выполнения добавления и корректировки записи
# -----------------------------------------------------------------------------
sub make_command
{
  my $operation = shift; # какая команда - вставка или корректировка?

  my $command;           # строка-команда

  # используем типовую процедуру
  # параметры: в том числе
  # - ссылка на массив имен полей этой таблицы БД, требующих специальной
  #   обработки (f_special);
  # - ссылка на функцию для обработки таких полей (func_special)
  $command = make_cmd( query => $query,
                       operation => $operation,
                       table => "orgs_act",
                       key => "org_id:org_id_begin, " .
                              "act_type_code:act_type_code_begin",
                       f_names => \@f_names,
                       f_special => undef,
                       func_special => undef,
                       user => $user
                     );

  return ( $command );
}

# -----------------------------------------------------------------------------
# создание формы для просмотра (корректировки) и добавления записей
# -----------------------------------------------------------------------------
sub make_form
{
  # параметры
  my $ref_row = shift;  # ссылка на массив, содержащий одну запись из выборки
  my $res = shift;      # результат выборки

  my $i;
  my %fields = ();  # хеш-массив с информацией о начальных значениях полей

  # получим две ссылки на массивы (они используются при формировании списка
  # видов деятельности организаций)
  my( $ref_values_acts, $ref_labels_acts ) =
    popup_activity_types_list( $db_schema );

  # если передан параметр - ссылка на массив значений полей одной записи
  # из выборки, ...
  if ( $ref_row ne undef )
  {
    # ... то сформируем хеш-массив, в котором...
    for $i ( 0 .. $res->nfields - 1 )
    {
      # ... каждому полю соответствует значение ключа, равное имени этого поля
      # (имя поля определим по его номеру - см. Pg.pm)
      $fields{ $res->fname( $i ) } = $$ref_row[ $i ];
    }
  }
  else                      # режим ввода новой записи в БД
  {
    # значения по умолчанию

    # уникальный идентификатор организации
    $fields{ 'org_id' }        = $CFG{ ORGS_ACT_ORG_ID };

    # код вида деятельности
    $fields{ 'act_type_code' } = $CFG{ ORGS_ACT_ACT_TYPE_CODE };

    # примечание
    $fields{ 'comment' }       = $CFG{ ORGS_ACT_COMMENT };
  }
  # -------------------------------------------------------------------

  # включим в текст HTML-документа обращение к исходному файлу с кодом функции
  # insert_str_into_field(), которая позволяет вставить фрагмент текста
  # в поле HTML-формы
  print <<END_OF_SCRIPT;
  <script language="JavaScript" type="text/javascript"
          src="/$CFG{ HOME_WEB_JS_DIR }/insert_text.js"></script>
END_OF_SCRIPT
  ;

  # создадим скрытые поля для "Уникального идентификатора организации"
  # и "Кода вида деятельности"
  # ПРИМЕЧАНИЕ. Идентификаторы скрытых полей имеют постфикс 'begin' для того,
  #             чтобы можно было обновлять значения этих полей, поскольку они
  #             являются ключевыми (см. функцию make_cmd в пакете E_ARCH.pm.
  #             Т.е. нам нужны и исходные значения этих полей, и их новые
  #             значения (которые, возможно, были изменены пользователем).
  print $query->hidden( -name => 'org_id_begin',
                        -default => $fields{ 'org_id' }
                      ), "\n";
  print $query->hidden( -name => 'act_type_code_begin',
                        -default => $fields{ 'act_type_code' }
                      ), "\n";

  # ретранслируем параметр exp_imp, если он был, для следующего вызова
  # этого скрипта (он нужен для определения схемы БД: exp_imp или public)
  print $query->hidden( -name => 'exp_imp' ), "\n";

  print "<table class=\"form\">\n";

  print "<tr>";
  print "<th>Код организации</th>\n";

  # сформируем текст функции на языке JavaScript, которая вызывает
  # модуль-справочник orgs.pl
  create_selection_func( func_name => 'select_org',
                         module_name => 'orgs.pl',
                         caller_name => $module,
                         window_name => 'orgs',
                         exp_imp => $query->param( 'exp_imp' ) );
  print "<td>",
        $query->textfield( -name => 'org_id',
                           -default => $fields{ 'org_id' },
                           -size => $CFG{ ORGS_ACT_ORG_ID_SIZE },
                           -maxlength => $CFG{ ORGS_ACT_ORG_ID_MAXLENGTH }
                         ),
        "&nbsp;&nbsp;",
        qq{ <a class="command_link" href="javascript:void( 0 )" onclick=} .
        qq{"select_org()">} . "Список</a>",
        "</td>\n";
  print "</tr>\n";

  print "<tr>";
  print "<th>Наименование организации</th>\n";
  # выведем наименование организации без возможности редактирования
  print "<td>",
        $query->textarea( -name => 'org_fname',
                          -default => $fields{ 'org_fname' },
                          -rows => $CFG{ ORGS_ACT_ORG_FNAME_ROWS },
                          -columns => $CFG{ ORGS_ACT_ORG_FNAME_COLS },
                          -readonly => 'readonly'
                        ),
        "</td>\n";
  print "</tr>\n";

  # для получения ссылки на хеш в параметре labels используем сложную
  # конструкцию, поскольку в функции popup_activity_types_list() формируется
  # не хеш, а массив - заготовка для хеша
  print "<tr>";
  print "<th>Вид деятельности</th>\n";
  print "<td>",
        $query->popup_menu( -name => 'act_type_code',
                            -default => $fields{ 'act_type_code' },
                            -values => $ref_values_acts,
                            -labels => { @{ $ref_labels_acts } }
                          ),
        "</td>\n";
  print "</tr>\n";
  
  # --------------------------------------------------------------------
  print "<tr>\n";
  print "<th>Комментарий</th>\n";
  print "<td>";

  # создадим ссылки (кнопки) для быстрой вставки фрагментов текста
  # в поле на экране
  create_hot_help( "document.forms[ 0 ].comment", "ORGS_ACT_COMMENT" ) 
    if $CFG{ HOT_HELP_IS_ON };

  print $query->textarea( -name => 'comment',
                          -default => $fields{ 'comment' },
                          -rows => $CFG{ ORGS_ACT_COMMENT_ROWS },
                          -columns => $CFG{ ORGS_ACT_COMMENT_COLS }
                        ),
        "</td>\n";
  print "</tr>\n";
  # --------------------------------------------------------------------

  print "</table>\n";
  return ( 0 );
}
