package E_ARCH;

# -----------------------------------------------------------------------------
# Система:  "Электронный архив"
# Модуль:   пакет стандартных процедур
# Автор:    Моргунов Е. П.
# Дата:     15.04.2012
# Версия:   0.6
# -----------------------------------------------------------------------------

use strict;
use warnings;

BEGIN
{
  use Exporter;
  our( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );

  $VERSION = 0.6;

  @ISA = qw( Exporter );

  # TODO. Выяснить, нужны ли знаки & перед именами процедур.
  # ПРИМЕЧАНИЕ. Некоторые процедуры этого пакета не экспортируем, т. к. они
  #             вызываются только из процедур пакета, например,
  #             process_referenced_tables(), process_dependent_tables(), 
  #             exec_cmd().
  @EXPORT = qw( &add_rec &can_work &change_case &close_bottom &close_top 
                &common_modes &create_assign_values_func &create_conn_str 
                &create_hot_help &create_selection_func &create_top_block
                &date_for_db &date_for_display &date_is_correct &del_rec
                &do_add &exec_connect_db &exec_select &exec_transaction
                &export_data &export_enabled &first_cap &first_letter
                &first_lower &get_available &get_bib_rec &get_next_key_value
                &get_ref_descr &get_ser_descr &get_user_name &have_access
                &http_html_headers &import_data &import_enabled
                &list_bib_recs_by_query &make_cmd &make_letters &open_bottom
                &open_top &popup_acq_ways_list &popup_activity_types_list
                &popup_cities_list &popup_conf_status_types_list
                &popup_conf_types_list &popup_countries_list 
                &popup_currencies_list &popup_det_char_types_list
                &popup_edition_types_list &popup_feature_groups_list
                &popup_gen_mater_types_list &popup_langs_list
                &popup_orgs_list &popup_pack_types_list
                &popup_phys_form_types_list &popup_process_types_list
                &popup_recs_sources_list &popup_ref_types_list
                &popup_roles_list &popup_spec_mater_groups_list
                &popup_spec_mater_types_list &popup_std_num_types_list
                &print_bib_record &print_debug_info &print_env &print_params
                &print_result &print_ser_descr &print_user_err_msgs
                &read_config &read_exp_config &reveal_rus_letter
                &screen_qts &update_rec &view_rec 
                $DEBUG %CFG %EXP_CFG $confirm_delete $confirm_export
                $confirm_import
              );

  %EXPORT_TAGS = ();

  # экспортируемые глобальные переменные, а также функции с необязательным
  # экспортированием
  # @EXPORT_OK = qw( $Var1 %Hash1 &func3 );
}

# our @EXPORT_OK;

# экспортируемые глобальные имена пакета
our( $DEBUG, %CFG, %EXP_CFG, $confirm_delete, $confirm_export, 
     $confirm_import );

# инициализируем глобальные переменные

# считываем параметры конфигурации в хеш
%CFG = read_config( "./cfg/e_arch.cfg" );

# считываем параметры конфигурации экспорта/импорта в хеш
%EXP_CFG = %{ read_exp_config( "./cfg/e_arch_exp.cfg" ) };

# фрагмент текста на языке JavaScript для запроса подтверждения удаления
# записи из таблицы БД
$confirm_delete = "return confirm( '" . ( $CFG{ CONFIRM_DELETE } ?
                                          $CFG{ CONFIRM_DELETE } :
                                          "Вы уверены?"
                                        ) . "' );";
# фрагмент текста на языке JavaScript для запроса подтверждения экспорта
# записи из таблицы БД
$confirm_export = "return confirm( '" . ( $CFG{ CONFIRM_EXPORT } ?
                                          $CFG{ CONFIRM_EXPORT } :
                                          "Вы уверены?"
                                        ) . "' );";
# фрагмент текста на языке JavaScript для запроса подтверждения импорта
# записи из схемы "экспорт/импорт" в основные таблицы БД
$confirm_import = "return confirm( '" . ( $CFG{ CONFIRM_IMPORT } ?
                                          $CFG{ CONFIRM_IMPORT } :
                                          "Вы уверены?"
                                        ) . "' );";
# флаг отладки
$DEBUG = debug_is_enabled();

use Pg;                          # для работы с PostgreSQL

# хеш-массив для накапливания SQL-команд, сформированных в процедуре экспорта
my %SQL_commands = ();


# -----------------------------------------------------------------------------
# непосредственное добавление записи в БД
# -----------------------------------------------------------------------------
sub add_rec
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            ссылка на функцию для формирования верхней части окна
  #              со списком "команд" для пользователя (create_top);
  #            ссылка на функцию для проверки значений, введенных в поля формы
  #              (check_param);
  #            ссылка на функцию для формирования строки команды для работы 
  #              с БД (make_command);
  #            текст сообщения для пользователя (user_msg);
  #            ссылка на функцию для вывода дополнительной информации 
  #              (print_add_info)
  
  my $query = $prms{ query }; # для удобства

  # имя окна браузера для вывода HTML-страницы
  my $target_win = $query->param( 'target_win' );
  
  $target_win = "_self" unless $target_win;

  my( $conn, $result );       # для работы с БД
  my $command;                # строка команды для добавления записи в таблицу

  # формируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => $target_win );

  open_top();                  # начинаем оформление верхней части окна
  &{ $prms{ create_top } }();  # формируем верхнюю часть окна со списком
                               # "команд" для пользователя
  close_top();                 # завершаем оформление верхней части окна

  open_bottom();               # начинаем оформление нижней части окна

  # выведем дополнительную информацию на экран
  &{ $prms{ print_add_info } }() if defined( $prms{ print_add_info } );

  # если проверка введенных значений прошла успешно, выполним добавление
  if ( &{ $prms{ check_param } }() )
  {
    # сформируем строку-команду для вставки записи
    $command = &{ $prms{ make_command } }( 'APPEND' );

    # DEBUG 
    print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

    $conn = exec_connect_db();          # подключаемся к БД
    $result = $conn->exec( $command );  # выполним команду вставки записи в БД

    # если произошла ошибка при вставке записей в базу данных
    if ( PGRES_COMMAND_OK ne $result->resultStatus )
    {
      # сообщение для пользователя
      print "<p class=\"error\">$CFG{ ERROR_INSERT }</p>\n";
      print STDERR $command . "\n";     # выводим строку команды в лог
      die $conn->errorMessage;
    }
    else
    {
      # если передан текст нестандартного сообщения, используем его
      print "<p class=\"info\">";
      print( ( $prms{ user_msg } ne undef ) ? $prms{ user_msg } :
             "Запись добавлена в базу данных" );
      print "</p>\n";
    }
  }

  close_bottom();      # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# определение полномочий данного пользователя на выполнение указанной
# процедуры данного модуля
# -----------------------------------------------------------------------------
sub can_work
{
  # параметры: имя пользователя, условные имена модуля и процедуры, CGI-объект
  my $user      = shift;
  my $module    = shift;
  my $procedure = shift;
  my $query     = shift;

  if ( ! have_access( 'module' => $module,
                      'procedure' => $procedure,
                      'user' => $user ) )
  {
    # формируем HTTP- и HTML-заголовки
    http_html_headers( query => $query, target => "_self" );

    print "<p class=\"info\">";
    print "У пользователя <span style=\"font-weight:bold\">$user</span> " .
          "нет полномочий на выполнение этой процедуры</p>\n";

    print $query->end_html();
  
    return ( 0 );
  }
  # есть полномочия - можно работать
  return ( 1 );
}

# -----------------------------------------------------------------------------
# перевод символьной строки в верхний или нижний регистр
# -----------------------------------------------------------------------------
sub change_case
{
  # параметры
  my $original_str = shift;   # оригинальная строка
  my $operation = shift;      # операция ('upper', 'UPPER', 'lower', 'LOWER')

  my $changed_str;            # обработанная строка

  # ошибка в параметре
  if ( lc( $operation ) ne 'lower' && lc( $operation ) ne 'upper' )
  {
    return $original_str;     # не делаем ничего
  }

  # считаем, что с другими кодировками на UNIX-серверах работать не придется
  if ( $CFG{ CHARSET } ne "KOI8-R" && $CFG{ CHARSET } ne "UTF-8" )
  {
    return $original_str;     # не делаем ничего
  }

  # если на сервере скрипты "Электронного архива" установлены (при этом
  # успешно!) в кодировке UTF-8, то параметры локализация пользователя, 
  # "из-под" которого запущен Apache, не играют роли (это может быть 
  # "ru_RU.UTF-8", а может быть и "C")
  if ( $CFG{ CHARSET } eq "UTF-8" )
  {
    use Encode;    
    use utf8;   # этого достаточно

    # придадим этой символьной строке флаг utf-8, если она его еще не имеет
    $original_str = decode( "UTF-8", ( $original_str ) ) 
      if ( ! utf8::is_utf8( $original_str ) );
    
    if ( lc( $operation ) eq 'lower' )
    {
      $changed_str = lc( $original_str );  # переведем строку в нижний регистр
    }
    else                                   # if ( lc( $operation ) eq 'upper' )
    {
      $changed_str = uc( $original_str );  # переведем строку в верхний регистр
    }

    return $changed_str;
  }

  # далее идет обработка для KOI8-R

  # воспользуемся возможностями локализации для перевода строки 
  # в нужный регистр

  # импортируем средства обработки локализационных параметров
  # из модуля POSIX
  use POSIX qw( locale_h );
    
  # сохраним текущее значение параметра LC_CTYPE, который "командует"
  # алфавитными символами
  # (оно определяется настройками, сделанными для той учетной записи,
  # "из-под" которой запущен web-сервер Apache, например, www или daemon --
  # см. файл httpd.conf)
  my $old_locale = setlocale( LC_CTYPE );

  if ( $old_locale ne "ru_RU.KOI8-R" )
  {
    # назначим русский язык в кодировке, определяемой параметром CHARSET
    # (KOI8-R или UTF-8)
    setlocale( LC_CTYPE, "ru_RU.KOI8-R" );
  }

  use locale;

  if ( lc( $operation ) eq 'lower' )
  {
    $changed_str = lc( $original_str );  # переведем строку в нижний регистр
  }
  else                                   # if ( lc( $operation ) eq 'upper' )
  {
    $changed_str = uc( $original_str );  # переведем строку в верхний регистр
  }
  no locale;

  # если не получилось сделать русскую локализацию, выполним преобразование
  # регистра русских букв "вручную" (при этом регистр латинских букв в этой
  # строке уже будет преобразован)
#  if ( setlocale( LC_CTYPE ) eq "C" || setlocale( LC_CTYPE ) eq "POSIX" ||
#       setlocale( LC_CTYPE ) eq "" )
  if ( setlocale( LC_CTYPE ) ne "ru_RU.KOI8-R" )
  {
    my %letters = ();
    my @rus_letters_big = split( /\s+/, $CFG{ STRING_LETTERS_RUS } );
    my @rus_letters_little = split( /\s+/, $CFG{ STRING_LETTERS_RUS_LITTLE } );
    my $new_letter;
    my $i;

    # сформируем перекодировочный хеш-массив    
    if ( lc( $operation ) eq 'lower' )
    {
      for( $i = 0; $i < scalar @rus_letters_big; $i++ )
      {
        # ключ хеша -- заглавная буква
        $letters{ $rus_letters_big[ $i ] } = $rus_letters_little[ $i ];
      }
    }
    else
    {
      for( $i = 0; $i < scalar @rus_letters_little; $i++ )
      {
        # ключ хеша -- строчная буква
        $letters{ $rus_letters_little[ $i ] } = $rus_letters_big[ $i ];
      }
    }

    # просмотрим всю строку 
    for ( $i = 0; $i < length( $changed_str ); $i++ )
    {
      # если в хеш-массиве найден текущий символ из строки, то мы заменяем
      # этот символ в строке новым символом
      $new_letter = $letters{ substr( $changed_str, $i, 1 ) };
      substr( $changed_str, $i, 1 ) = $new_letter if ( $new_letter );
    }
  }

  # восстановим исходное значение параметра LC_CTYPE
  setlocale( LC_CTYPE, $old_locale ) if ( $old_locale ne "ru_RU.KOI8-R" );

  return $changed_str;
}

# -----------------------------------------------------------------------------
# завершение оформления нижней части окна
# -----------------------------------------------------------------------------
sub close_bottom
{
  # выведем HTML-теги, если они были назначены в конфигурационном файле
  print "$CFG{ CLOSE_BOTTOM }\n";

  return ( 0 );
}

# -----------------------------------------------------------------------------
# завершение оформления верхней части окна
# -----------------------------------------------------------------------------
sub close_top
{
  # выведем HTML-теги, если они были назначены в конфигурационном файле
  print "$CFG{ CLOSE_TOP }\n";

  return ( 0 );
}

# -----------------------------------------------------------------------------
# типовые режимы работы
# -----------------------------------------------------------------------------
sub common_modes
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            условное имя модуля (module);
  #            имя пользователя, работающего с модулем (user);
  #            ПРИМЕЧАНИЕ. Имя функции - т.е. ссылка на функцию.
  #            имя функции для организации формы (make_form);
  #            имя функции для формирования строки-команды (make_command);
  #            имя функции для проверки параметров формы (check_param);
  #            имя функции для формирования верхнего блока в окне со списком
  #                "команд" для пользователя (create_top);
  #            имя функции для вывода списка записей в виде таблицы (do_query);
  #            имя функции для просмотра одной записей в виде формы (do_view);
  #            имя функции для добавления одной записи в БД (do_add);
  #            имя функции для удаления одной записи из БД (do_del);
  #            имя функции для поиска записей в БД (do_find);
  #            имя функции для непосредственного ввода записи (add_rec);
  #            имя функции для непосредственного обновления записи
  #                (update_rec);
  #            имя функции для вывода дополнительной информации при выполнении
  #                функций add_rec, update_rec (print_add_info);
  #            URL скрипта для обработки формы (action)

  my $query = $prms{ query };    # для удобства

  # имя окна браузера для вывода HTML-страницы
  my $target_win = $query->param( 'target_win' );
  $target_win = "_self" unless $target_win;

  # проверим, есть ли у пользователя право на вход в этот модуль
  if ( ! can_work( $prms{ user }, $prms{ module }, 'main', $query ) )
  {
    exit( 0 );
  }

  # первое условие -- для запуска скрипта из головного модуля;
  # второе условие -- для запуска скрипта "из самого себя" (например,
  # при выборе конкретной буквы в модуле "Персоналии");
  # третье условие -- использование модуля в качестве справочника;
  # четвертое условие -- для запуска скрипта из головного модуля с целью
  # просмотра БД (схемы) экспорта/импорта (число параметров должно быть
  # равно 1, при этом имя параметра должно быть 'exp_imp')
  
  # значительная часть модулей может использоваться в режиме справочника
  # для осуществления выбора одной записи из списка (например, для выбора
  # кокретной персоналии при вводе сведений об ответственности), в этом
  # случае при вызове скрипта используется параметр enable_select (см. тексты
  # модулей)
  if ( ( ! $query->path_info && ! $query->param ) ||
       $query->path_info =~ /^\/query$/ ||
       $query->path_info =~ /^\/select$/ ||
       ( ! $query->path_info && scalar $query->param() == 1 && 
         $query->param( 'exp_imp' )
       )
     )
  {
    # выбираем записи из БД по указанному критерию в виде списка с краткой
    # информацией
    &{ $prms{ do_query } }();
  }

  # выбираем одну запись из БД в виде формы с полной информацией
  elsif ( $query->path_info =~ /^\/view$/ &&
          have_access( 'module' => $prms{ module }, 'procedure' => 'VIEW',
                       'user' => $prms{ user } )
        )
  {
    &{ $prms{ do_view } }();
  }

  # добавление записи (организация формы для ввода данных)
  elsif ( $query->path_info =~ /^\/add$/ &&
          have_access( 'module' => $prms{ module }, 'procedure' => 'ADD',
                       'user' => $prms{ user } )
        )
  {
    &{ $prms{ do_add } }( query => $query,
                          create_top => $prms{ create_top },
                          make_form => $prms{ make_form },
                          action => $prms{ action },
                          target => $target_win,
                          submit_name => "submit_add",
                          submit_value => "Добавить"
                        );
  }

  # удаление записи
  elsif ( $query->path_info =~ /^\/delete$/ &&
          have_access( 'module' => $prms{ module }, 'procedure' => 'DELETE',
                       'user' => $prms{ user } )
        )
  {
    &{ $prms{ do_del } }();
  }

  # поиск записей по критерию
  elsif ( $query->path_info =~ /^\/find$/ )
  {
    &{ $prms{ do_find } }();
  }
  # экспортирование записи
  elsif ( $query->path_info =~ /^\/export$/ &&
          have_access( 'module' => $prms{ module }, 'procedure' => 'EXPORT',
                       'user' => $prms{ user } )
        ) 
  {
    &{ $prms{ do_export } }();
  }
  # импортирование записи
  elsif ( $query->path_info =~ /^\/import$/ &&
          have_access( 'module' => $prms{ module }, 'procedure' => 'IMPORT',
                       'user' => $prms{ user } )
        ) 
  {
    &{ $prms{ do_import } }();
  }


  # непосредственный ввод записи (с проверкой правильности ввода)
  if ( $query->param( 'submit_add' ) && 
       have_access( 'module' => $prms{ module }, 'procedure' => 'ADD',
                    'user' => $prms{ user } )
     )
  {
    &{ $prms{ add_rec } }( 'query' => $query, 
                           'create_top' => $prms{ create_top },
                           'check_param' => $prms{ check_param },
                           'make_command' => $prms{ make_command },
                           'print_add_info' => $prms{ print_add_info } );
  }

  # непосредственное обновление записи (с проверкой правильности ввода)
  elsif ( $query->param( 'submit_update' ) &&
          have_access( 'module' => $prms{ module }, 'procedure' => 'UPDATE',
                       'user' => $prms{ user } )
        )
  {
    &{ $prms{ update_rec } }( 'query' => $query, 
                              'create_top' => $prms{ create_top },
                              'check_param' => $prms{ check_param },
                              'make_command' => $prms{ make_command },
                              'print_add_info' => $prms{ print_add_info } );
  }
  return ( 0 );
}

# -----------------------------------------------------------------------------
# копирование записей из таблиц одной схемы БД в одноименные таблицы другой
# схемы БД
# -----------------------------------------------------------------------------
sub copy_data
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            ссылка на функцию для формирования верхней части окна
  #              со списком "команд" для пользователя (create_top);
  #            ссылка на массив ссылок на двухэлементные массивы,
  #              содержащие имя таблицы и соответствующую команду для нее
  #              (table_cmd_pairs);
  #            наименование исходной схемы БД (source_schema);
  #            наименование целевой схемы БД (target_schema)

  # Эта процедура используется как при экспорте, так и при импорте. Но при
  # экспорте копирование производится из схемы public в схему exp_imp,
  # а при импорте -- из схемы exp_imp в схему imp. В комментариях зачастую
  # используется терминология с позиции экспорта. При рассмотрении операций
  # импорта нужно делать соответствующие поправки в терминах. Это же касается
  # и имен переменных: они также получили свои названия с позиции экспорта.
  
  my $query = $prms{ query };                    # для удобства
  my $source_schema = $prms{ source_schema };    # для удобства
  my $target_schema = $prms{ target_schema };    # для удобства

  # имя окна браузера для вывода HTML-страницы
  my $target_win = $query->param( 'target_win' );

  my $conn;                  # дескриптор соединения с БД
  my $result;                # результат выполнения SQL-команды
  my @row;                   # для хранения одной записи из выборки
  my $table_cmd_pair;        # ссылка на массив из двух элементов
                             # (имя таблицы и команда для нее)
  my $command;               # строка команды для работы с БД
  my $exp_table;             # таблица, из которой экспортируются данные
  my %rec;                   # хеш-массив, содержащий значения полей текущей
                             # записи из выборки
  my $table;                 # таблица из общего списка таблиц БД
  my $i;
  my $cmd_type;              # тип SQL-команды (INSERT или UPDATE)
  my $where;                 # условие для проверки на дублирование
  my @key_fields;            # массив ключевых полей конкретной таблицы
  my $inserted_count = 0;    # число записей, добавленных в экспортную схему БД

  $target_win = "_blank" unless $target_win;

  # сформируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => $target_win );

  open_top();                  # начинаем оформление верхней части окна
  &{ $prms{ create_top } }();  # формируем верхнюю часть окна со списком
                               # "команд" для пользователя
  close_top();                 # завершаем оформление верхней части окна

  open_bottom();               # начинаем оформление нижней части окна

  # DEBUG 
  print_debug_info( "Сформированные SQL-команды" ) if $DEBUG;

  # обработаем все пары "имя таблицы -- команда для выборки из нее",
  # переданные этой процедуре
  foreach $table_cmd_pair ( @{ $prms{ table_cmd_pairs } } )
  {
    $exp_table = @{ $table_cmd_pair }[ 0 ];  # для удобства
    $command = @{ $table_cmd_pair }[ 1 ];    # для удобства

    # сделаем выборку из БД
    # (второй параметр -- строка пробелов, это нужно для того, чтобы
    # не выводилось сообщение в случае, когда записи не найдены)
    $result = exec_select( $command, "  " );
  
    if ( $result )
    {
      # обрабатываем все записи из полученной выборки
      while ( @row = $result->fetchrow )
      {
        my $fields = "";       # список имен полей (в виде строки)
        my $values = "";       # список значений полей (в виде строки)
        my $fname;             # имя поля
        my $value;             # значение поля

        %rec = ();             # "обнулим" хеш-массив, содержащий значения
                               # полей текущей записи из выборки

        # сформируем хеш-массив, содержащий значения полей текущей записи
        # из выборки

        # обработаем все поля выборки (т. е. все поля таблицы)
        for ( $i = 0; $i < scalar @row; $i++ )
        {
          # используем эти переменные для удобства
          $fname = $result->fname( $i );  # по номеру поля получим его имя
          $value = $row[ $i ];
        
          # формируем хеш-массив, содержащий значения полей текущей записи
          # из выборки (имя -- ключ в хеш-массиве)
          $rec{ $fname } = $value;
        }

        # -------
        # сформируем команды для вставки записей в ссылочные таблицы,
        # на которые ссылается таблица $exp_table (внешние ключи)
        process_referenced_tables( $exp_table, \%rec, $source_schema,
                                   $target_schema );

        # сформируем команды для вставки записей в зависимые таблицы,
        # которые ссылаются на таблицу $exp_table (внешние ключи в зависимых
        # таблицах)
        process_dependent_tables( $exp_table, \%rec, $source_schema,
                                  $target_schema );
        # -------

        # сформируем список имен полей и список значений полей для команды
        # INSERT INTO 
        foreach $fname ( keys %rec )
        {
          $value = $rec{ $fname };
        
          # включаем имя текущего поля в список имен полей
          $fields .= $fname . ",";

          # TODO. Нужно сделать обработку "нехороших" символов более
          #       основательно.
          $value =~ s/\'/\'\'/g;

          # формируем строку значений полей (поэтому нужны одинарные
          # кавычки!!!)
          # если значение параметра пустое, то записываем null, но в этом
          # случае одинарные кавычки НЕ НУЖНЫ
          # ПРИМЕЧАНИЕ. Хотя для числовых полей кавычки не требуются, 
          #             мы их ставим только из соображений единообразия 
          #             и простоты данной функции.
          $values .= $value ne '' ? "'$value'," : "null," ;
        }

        $fields =~ s/,$//;  # уберем последнюю запятую
        $values =~ s/,$//;  # уберем последнюю запятую

        # сформируем команду вставки записи в экспортную схему БД окончательно
        $command = "INSERT INTO $target_schema.$exp_table ( $fields ) " .
                               "VALUES ( $values )";

        # теперь сформируем условие WHERE, которое будет использоваться
        # при вводе экспортируемых записей в схему exp_imp для проверки
        # наличия такой записи, команду INSERT для ввода которой мы только что
        # сформировали (проверка на дублирование)
        
        # возьмем массив ключевых полей данной таблицы
        @key_fields = @{ $EXP_CFG{ TABLES }{ $exp_table }{ KEY_FIELDS } };

        $where = "";

        # обработаем все ключевые поля
        for ( $i = 0; $i < scalar @key_fields; $i++ )
        {
          $where .= $key_fields[ $i ] . " = '" . $rec{ $key_fields[ $i ] } .
                    "' AND ";
        }

        $where =~ s/\s*AND\s*$//;  # уберем лишнее 'AND'

        # добавим сформированную команду во временный хеш-массив -- накопитель

        # ключ -- команда INSERT, значение -- условие WHERE для проверки
        # на дублирование 
        $SQL_commands{ $exp_table }{ $command } = $where;

        # DEBUG 
        print_debug_info( $command ) if $DEBUG;  # печатаем строку команды
      }
    }
    else
    {
      ;  # TODO. Что в этом случае делать?
    }
  }
 
  # ---------------------------------------------------
  # теперь вставим/обновим записи в экспортную схему БД
  # ---------------------------------------------------

  $conn = exec_connect_db();           # подключаемся к БД
  exec_transaction( $conn, "BEGIN" );  # выполним операции в рамках транзакции

  # DEBUG 
  print_debug_info( "Фактически выполненные SQL-команды" ) if $DEBUG;

  # обрабатываем все таблицы именно в том порядке, в котором они определены
  # в SQL-файле создания БД (e_arch.sql), это позволяет соблюсти требования
  # внешних ключей
  foreach $table ( @{ $EXP_CFG{ TABLES_ORDER } } )
  {
    # если для таблицы нет ни одной команды
    next if ( ! exists $SQL_commands{ $table } );
    
    # тип команды
    # порядок должен быть именно таков: 'INSERT', 'UPDATE', т. к. ВСЕ команды
    # вставки записей должны быть выполнены до команд обновления, иначе
    # возможны коллизии с внешними ключами
    foreach $cmd_type ( ( 'INSERT', 'UPDATE' ) )
    {
      foreach $command ( keys %{ $SQL_commands{ $table } } )
      {
        # если тип команды совпадает с типом, выбранным во внешнем цикле
        if ( $command =~ /^${cmd_type}/ )
        {
          # будем подсчитывать число записей, добавленных 
          # в экспортную/импортную схему БД;
          # если проверка на дублирование показала наличие дублирующихся
          # записей, то процедура возвратит 0
          $inserted_count += exec_cmd( $conn, $target_schema, $table, 
                                       $cmd_type, $command,
                                       $SQL_commands{ $table }{ $command } );
        }
      }
    }
  }
  exec_transaction( $conn, "END" );   # конец транзакции

  # если добавлена хотя бы одна запись в экспортную/импортную схему БД
  if ( $inserted_count > 0 )
  {
    print "<p class=\"info\">";
    print( "Записи добавлены в базу данных " . 
           ( ( $prms{ target_schema } eq "exp_imp" ) ? "экспорта: " :
                                                       "импорта: " ) .
           "$inserted_count шт.</p>\n" );
  }
  else
  {
    print "<p class=\"info\">";
    print( "Эти сведения уже " . 
           ( ( $prms{ target_schema } eq "exp_imp" ) ? "экспортированы" :
                                                       "импортированы" ) .
           "</p>\n" );
  }
  
  close_bottom();      # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# формирование текста функции на языке JavaScript, которая выполняет
# присваивание значений полей из справочника полям в (на) главной форме,
# находящейся в ВЫЗЫВАЮЩЕМ модуле
# -----------------------------------------------------------------------------
sub create_assign_values_func
{
  # параметры
  my $entity_id_fname = shift;   # имя поля, являющегося идентификатором некой
                                 # сущности (ради этого поля все и затевается)
                                 # (например, код персоналии)
  my $entity_name_fname = shift; # имя поля, являющегося описанием некой
                                 # сущности (например, Ф. И. О. персоналии)
  my $add_info_fname = shift;    # имя поля, содержащего дополнительную
                                 # информацию (его может не быть)

  my $func_params = "entity_id, entity_name";

  if ( $add_info_fname ne undef )
  {
    $func_params .= ", add_info";
  }

  print <<END_OF_SCRIPT;
  <script language="JavaScript" type="text/javascript">
  <!--
  function assign_values( $func_params )
  {
    // присвоим значения идентификатора сущности и описания сущности
    // полям в ВЫЗЫВАЮЩЕМ окне
    // проверим, не заблокировано ли поле
    // ПРИМЕЧАНИЕ. Конечно, можно ввести значение и в заблокированное поле,
    //             но нам этого не нужно.
    if ( parent.opener.document.forms[ 0 ].$entity_id_fname.disabled == false )
    {
      parent.opener.document.forms[ 0 ].$entity_id_fname.value = entity_id;
      parent.opener.document.forms[ 0 ].$entity_name_fname.value = entity_name;
END_OF_SCRIPT
  ;

  if ( $add_info_fname )
  {
    # добавим код для заполнения еще одного поля в ВЫЗЫВАЮЩЕЙ форме
    print "parent.opener.document.forms[ 0 ].$add_info_fname.value = " .
          "add_info;";
  }

  print <<END_OF_SCRIPT;
      parent.opener.document.forms[ 0 ].$entity_id_fname.focus();
      parent.close();
    }
    else
    {
      window.alert( "Поле заблокировано. Ввод невозможен" );
    }
  }
  //-->
  </script>
END_OF_SCRIPT
  ;
}

# -----------------------------------------------------------------------------
# формирование строки параметров для соединения с базой данных
# -----------------------------------------------------------------------------
sub create_conn_str
{
  # ПРИМЕЧАНИЕ. Эта функция в будущем может претерпеть изменения, но в данный
  #             момент она очень проста. Ее главное назначение на данном
  #             этапе - "застолбить" место в вызывающих ее модулях с тем,
  #             чтобы все эти модули не требовали доработки при возможном
  #             изменении данной функции. Иначе, при формировании строки
  #             параметров для подключения к БД в виде переменной или
  #             литерала, пришлось бы вносить изменения непосредственно
  #             в модулях (например, в модуле "Роли" и т.д.).

  my $conn_str = '';

  # берем только имя БД из конфиг. файла, а также имя пользователя
  $conn_str = "dbname=" . $CFG{ DBNAME } . " user=" . get_user_name();

  return ( $conn_str );
}

# -----------------------------------------------------------------------------
# формирование исходного кода функции на языке JavaScript, которая разблокирует
# заблокированные поля HTML-формы
# -----------------------------------------------------------------------------
sub create_enable_elements_func
{
  # эта функция вызывается перед отправкой значений полей HTML-формы
  # web-серверу при нажатии кнопки типа submit
  # ПРИМЕЧАНИЕ. Заблокированные элементы (у которых атрибут disabled имеет
  #             значение true) НЕ отправляются web-серверу для обработки.
  #             У нас же в ряде модулей заблокированные поля имеют
  #             осмысленные значения, просто пользователь избавлен от их
  #             заполнения: поля заполняются автоматически, в зависиимости
  #             от значений, введенных пользователем в другие поля.
  
  print <<END_OF_SCRIPT;
  <script language="JavaScript" type="text/javascript">
  <!--
  // функция для активизирования полей HTML-формы, которые имели статус
  // disabled (поля с таким атрибутом не передаются скрипту для обработки,
  // а нас это не устраивает)
  function enable_elements()
  {
    var i;
    // перебираем все элементы формы
    for ( i = 0; i < document.forms[ 0 ].elements.length; i++ )
    {
      // если элемент был заблокирован ...
      if ( document.forms[ 0 ].elements[ i ].disabled == true )
      {
        // ... сбрасываем установленный флаг блокировки
        document.forms[ 0 ].elements[ i ].disabled = false;
      }
    }
  }
  //-->
  </script>
END_OF_SCRIPT
  ;
}

# -----------------------------------------------------------------------------
# формирование ссылок (или кнопок) для быстрой вставки фрагментов текста
# в поле на экране
# -----------------------------------------------------------------------------
sub create_hot_help
{
  # параметры

  # имя поля (в HTML-документе), для которого создаются ссылки (кнопки) -- 
  # формат полный, например, document.forms[ 0 ].bib_rec_full
  # ПРИМЕЧАНИЕ. По моему предположению, передача полного имени позволит
  #             упростить исходный код этой функции и повысит гибкость ее
  #             применения.
  my $field_name = shift;

  # первая часть наименования параметров, предназначенных для формирования
  # "быстрых" подсказок (например, BIB_RECS_BIB_REC_FULL)
  # этот параметр выполняет, можно сказать, привязку к конкретному полю
  # таблицы БД
  my $prefix = shift;  

  # тип операции, которая выполняется с фрагментом текста: это либо вставка
  # фрагмента в поле, либо замена значения этого поля целиком
  my $operation = shift;

  # дополнительный JavaScript-код, который выполняется при нажатии на кнопку
  # (при выборе ссылки)
  my $additional_code = shift;
  
  # по умолчанию принимается операция ВСТАВКИ фрагмента текста в поле 
  # HTML-формы
  $operation = "INSERT" if ( $operation eq undef );

  # по умолчанию нет никакого дополнительного JavaScript-кода
  $additional_code = '' if ( $additional_code eq undef );
  
  # первым этапом данной процедуры является формирование хеша %hot_help_info,
  # имеющего следующую структуру

  # { 1 }->[ [ 'LINK', 'текст ссылки' ],
  #          [
  #            [ 1, 'фрагмент 1' ], [ 2, 'фрагмент 2' ], ...
  #          ]
  #        ]
  # { 2 }->[ [ 'BTN', 'надпись на кнопке' ],
  #          [
  #            [ 1, 'фрагмент 1' ], [ 2, 'фрагмент 2' ], ...
  #          ]
  #        ]
  # ....

  # в этой структуре массивы типа [ 'LINK', 'текст ссылки' ] формируются
  # на основе параметров ..._HELP_(LINK|BTN)_TITLE, а двухмерные массивы типа
  # [ [ 1, 'фрагмент 1' ], [ 2, 'фрагмент 2' ], ... ] формируются на основе
  # параметров ..._HELP_VALUE (массивы фрагментов полезной информации
  # должны быть отсортированы по порядковым номерам этих фрагментов,
  # т. е. в том порядке, в котором они были записаны пользователем
  # в конфигурационном файле)
  # ключами хеш-массива являются порядковые номера "быстрых" подсказок
  # (вставок) (в том порядке, в котором они представлены в конфиг. файле)

  my %hot_help_info = ();
  my $key;
  
  # имя поля (без включения в него всей иерархии объектов HTML-документа)
  # (используется для формирования имени функции на языке JavaScript)
  my( $short_field_name ) = $field_name =~ /.+\.(.+)$/;
  
  # значение переменной, к которому применена функция CGI::escapeHTML
  my $esc_val;      # escaped_value
  
  # обрабатываем весь хеш-массив конфигурационных параметров, полученных
  # из конфиг. файла, и формируем набор подсказок для ДАННОГО ПОЛЯ
  foreach $key ( keys %CFG )
  {
    # поскольку в конце имени параметра есть цифры, которые добавляются на
    # этапе обработки конфиг. файла, учтем это сейчас
    if ( $key =~ /^${prefix}_HELP_(LINK|BTN)_TITLE(\d+)$/ )
    {
      # если ключа с номером, записанным в переменную $2, еще нет в хеше, ...
      if ( ! exists $hot_help_info{ $2 } )
      {
        # ... то создадим такой ключ и сформируем соответствующий ему массив
        # (см. структуру массива выше)
        $hot_help_info{ $2 } = [ [ $1, $CFG{ $key } ], [] ];
      }
      # если такой ключ уже есть в хеше (он мог там появиться при обработке
      # параметра ..._HELP_VALUE), ...
      else 
      {
        # ... то сформируем субмассив с индексом 0 (см. структуру массива выше)
        ${ $hot_help_info{ $2 } }[ 0 ] = [ $1, $CFG{ $key } ];
      }
    }
    # если это фрагмент текста, предназначенный для вставки в поле
    # на экране, ...
    elsif ( $key =~ /^${prefix}_HELP_VALUE(\d+)_(\d+)$/ )
    {
      # ... то сформируем всю структуру соответствующего двухмерного массива,
      # если ее еще нет, и поместим в нее фрагмент текста $CFG{ $key },
      # предназначенный для вставки в поле на экране, вместе с номером $2
      # этого фрагмента (не забываем, что все такие фрагменты имеют номера, 
      # которые присваиваются в процессе обработки конфиг. файла)
      if ( ! exists $hot_help_info{ $1 } )
      {
        $hot_help_info{ $1 } = [ [], [] ];
        push( @{ $hot_help_info{ $1 }[ 1 ] }, [ $2, $CFG{ $key } ] );
      }
      # ... если такая структура уже есть, ...
      else
      {
        # ... то просто поместим в нее фрагмент текста $CFG{ $key } вместе
        # с его номером
        push( @{ $hot_help_info{ $1 }[ 1 ] }, [ $2, $CFG{ $key } ] );
      }
    }
  }

  # теперь формируем ссылки и кнопки, т. е. делаем главную работу
  
  # обработку подготовленного хеша будем проводить в порядке отсортирооованных
  # ключей, т. е. чисел 1, 2, 3 и т. д.
  # при этом принудительно сортируем ЧИСЛЕННО, а не ЛЕКСИЧЕСКИ
  foreach $key ( sort { $a <=> $b } keys %hot_help_info )
  {
    # сначала в каждом "гнезде" хеша отсортируем фрагменты текста, которые и 
    # являются "полезной" нагрузкой, по порядковым номерам этих фрагментов

    my @tmp;
    my @sorted;
  
    # двухмерный массив, содержащий собственно тексты "быстрых" вставок
    # (т. е. параметры ..._HELP_VALUE)
    @tmp = @{ $hot_help_info{ $key }[ 1 ] };

    # сортируем этот массив по возрастанию порядковых номеров, которые
    # содержатся в элементах с индексами 0 каждого субмассива
    # ([ [ 1, 'фрагмент 1' ], [ 2, 'фрагмент 2' ], ... ])
    @sorted = sort { $$a[ 0 ] <=> $$b[ 0 ] } @tmp;

    # записываем обратно в хеш ссылку на отсортированный массив
    $hot_help_info{ $key }[ 1 ] = [ @sorted ];

    # DEBUG
    #  print $key, $hot_help_info{ $key }[ 0 ][ 0 ],
    #              $hot_help_info{ $key }[ 0 ][ 1 ], "\n";
    #  foreach ( @{ $hot_help_info{ $key }[ 1 ] } )
    #  {
    #    print $_->[ 0 ], $_->[ 1 ], "\n";
    #  }

    # если подсказка содержит только ОДИН фрагмент (на этот факт указывает
    # длина массива, равная 1), ...
    if ( scalar @{ $hot_help_info{ $key }[ 1 ] } == 1 )
    {
      # экранируем кавычки и другие "неудобные" символы, которые могут
      # содержаться в том фрагменте текста, который будет вставляться в поле
      # (см. комментарий в модуле obj_groups_descrs.pl)
      # выполним добавочную обработку значения переменной, т. к. того, что
      # делает функция escapeHTML(), недостаточно
      $esc_val = $hot_help_info{ $key }[ 1 ][ 0 ][ 1 ];
      $esc_val =~ s/\'/\\\'/g;
      $esc_val = CGI::escapeHTML( $esc_val );

      # если это HTML-ссылка
      if ( $hot_help_info{ $key }[ 0 ][ 0 ] eq 'LINK' )
      {
        # ... то сформируем HTML-ссылку
        if ( $operation eq "INSERT" )     # вставка фрагмента текста в поле
        {
          print qq{ <a href="javascript:void( 0 )" class="hot_help_link" 
                    onclick=
                    "insert_str_into_field( $field_name, '$esc_val' )">} .
                    $hot_help_info{ $key }[ 0 ][ 1 ] . "</a>\n";
        }
        elsif ( $operation eq "REPLACE" )  # полная перезапись значения поля
        {
          # атрибуту NAME присваиваем такое же значение, какое выводим
          # на экран в качестве текста ссылки. Это вынужденная мера,
          # т. к. найти способ, позволяющий обратиться к тексту ссылки,
          # используя JavaScript, мне не удалось. Однако необходимость
          # в использовании текста ссылки имеется. Например, при заполнении
          # поля "Код персоналии" в модуле "Сведения об ответственности"
          # было бы логично не только присваивать значение коду персоналии,
          # но также и записывать текст ссылки (т. е. фамилию, имя и отчество
          # этой персоналии) в соответсвующее поле для наглядности, поскольку
          # при выборе персоналии из справочника именно так и делается.
          # Параметр $additional_code может содержать примерно такой код
          # на языке JavaScript:
          #         "var str; if (this.value) str = this.value;
          #                   else str = this.name;
          #         document.forms[ 0 ].pers_name.value = str; "
          # Это позволит использовать также и атрибут VALUE, если он имеется
          # (как в теге <input type = "button">)
          print "<a href=\"javascript:void( 0 )\" 
                    name=\"$hot_help_info{ $key }[ 0 ][ 1 ]\" 
                    class=\"hot_help_link\" 
                    onclick=
                    \"if ( $field_name.disabled == false )
                    { $field_name.value = '$esc_val'; 
                      $additional_code;
                      $field_name.focus();
                    }
                    else
                    { 
                      window.alert( 'Поле заблокировано. Ввод невозможен' );
                    }  
                    \">" . $hot_help_info{ $key }[ 0 ][ 1 ] . "</a>\n";
        }
      }
      # если это HTML-кнопка
      # ПРИМЕЧАНИЕ. Несколько причудливое использование оператора qq{} вызвано
      #             желанием "помочь" редактору joe в его стремлении корректно
      #             расцвечивать исходный текст.
      elsif ( $hot_help_info{ $key }[ 0 ][ 0 ] eq 'BTN' )
      {
        # ... то сформируем HTML-кнопку
        if ( $operation eq "INSERT" )     # вставка фрагмента текста в поле
        {
          print qq{ <input type="button" } .
                qq{ class="hot_help_btn" } .
                qq{ value="} . 
                  CGI::escapeHTML( $hot_help_info{ $key }[ 0 ][ 1 ] ) .
                qq{"} .
                qq{ onclick="insert_str_into_field( $field_name, 
                                                    '$esc_val' )" />} . "\n";
        }
        elsif ( $operation eq "REPLACE" )  # полная перезапись значения поля
        {
          print qq{ <input type="button" } .
                qq{ class="hot_help_btn" } .
                qq{ value="} . 
                  CGI::escapeHTML( $hot_help_info{ $key }[ 0 ][ 1 ] ) .
                qq{"} .
                qq{ onclick=
                    "if ( $field_name.disabled == false )
                    \{ $field_name.value = '$esc_val'; 
                       $additional_code;
                       $field_name.focus();
                    \}
                     else
                    \{
                      window.alert( 'Поле заблокировано. Ввод невозможен' );
                    \}
                    "/>} . "\n";
        }
      }      
    }
    # если эта подсказка содержит более ОДНОГО фрагмента (на этот факт
    # указывает длина массива, превышающая 1), ...
    elsif ( scalar @{ $hot_help_info{ $key }[ 1 ] } > 1 )
    {
      # ... то сформируем JavaScript-код для создания нового окна, в которое
      # будет выводиться список "быстрых" вставок, и сформируем текст
      # функции на языке JavaScript
      
      # поскольку однотипные функции могут быть созданы (в общем случае)
      # для более чем одного окна с "быстрыми" вставками, то будем нумеровать
      # эти функции в соответствии с порядковым номером $key, т. е.
      # open_hot_help_window1(), open_hot_help_window2() и т. д.

      # поскольку набор "быстрых" подсказок может быть создан для более чем
      # одного поля HTML-формы, а нумерация с помощью $key ведется в пределах
      # каждого конкретного поля, то включим в имя функции еще и имя поля,
      # для работы с которым эта функция предназначена
      
      # включим в текст формируемого HTML-документа обращение к файлу 
      # insert_text.js, содержащему исходный код функции
      # insert_str_into_field(), которая позволяет вставить фрагмент текста
      # в поле HTML-формы
      
      # ПРИМЕЧАНИЕ. Оператор "+" -- оператор конкатенации в языке JavaScript.
      #             Используем этот оператор здесь для сокращения длины
      #             строчек исходного кода (предел -- 80 символов).

      # help_win.document.write( "<TITLE>$hot_help_info{ $key }[ 0 ][ 1 ]" +
      #                          "</TITLE>" );
      # экранируем кавычки и другие "неудобные" символы, которые могут
      # содержаться в том фрагменте текста, который будет являться
      # заголовком
      $esc_val = CGI::escapeHTML( $hot_help_info{ $key }[ 0 ][ 1 ] );
      
      print <<END_OF_SCRIPT;
      <script language="JavaScript" type="text/javascript">
      <!--
      function open_hot_help_window_${short_field_name}_${key}()
      {
        var help_win = window.open( "", "help_window",
                                    "$CFG{ HOT_HELP_WINDOW_PARAMS }" );
        help_win.document.open();
        help_win.document.write( "<html>" );
        help_win.document.write( "<head>" );
        help_win.document.write( "<link rel=\\\"stylesheet\\\" " +
                                 "type=\\\"text/css\\\" " +
                                 "href=\\\"/$CFG{ HOME_WEB_CSS_DIR }" +
                                 "/$CFG{ CSS }\\\" />" );
        help_win.document.write( "<title>$esc_val</title>" );
        help_win.document.write( "</head>" );
        help_win.document.write( "<body class=\\\"hot_help_body\\\">" );
        help_win.document.write( "<script language=\\\"JavaScript\\\" " +
                                 "type=\\\"text/javascript\\\" " +
                                 "src=\\\"/$CFG{ HOME_WEB_JS_DIR }" + 
                                 "/insert_text.js\\\">" +
                                 "</script>" );
END_OF_SCRIPT
      ;

      # для каждого фрагмента текста, предназначенного для "быстрой"
      # вставки, сформируем HTML-ссылку, которая будет выводиться в этом окне
      foreach ( @{ $hot_help_info{ $key }[ 1 ] } )
      {
        # экранируем кавычки и другие "неудобные" символы, которые могут
        # содержаться в том фрагменте текста, который будет вставляться в поле
        # (см. комментарий в модуле obj_groups_descrs.pl)
        # выполним добавочную обработку значения переменной, т. к. того, что
        # делает функция escapeHTML(), недостаточно
        $esc_val = $_->[ 1 ];
        # TODO. Закомментировал эти две строки, т. к. они не нужны и даже
        #       вредны. Необходимо разбираться более основательно!
        # $esc_val =~ s/\'/\\\'/g;
        # $esc_val =~ s/\"/\\\"/g;
        $esc_val = CGI::escapeHTML( $esc_val );

        # поскольку переменная $field_name содержит имя поля в документе,
        # содержащемся в ВЫЗЫВАЮЩЕМ окне, то добавим еще и "opener.";
        # окно будем закрывать после выбора конкретной "быстрой" вставки,
        # поэтому необходимо добавить self.close();
        # ПРИМЕЧАНИЕ. Обилие экранирующих символов "\" вызвано тем, что
        #             мы на языке Perl формируем оператор языка JavaScript,
        #             который, в конечном итоге, формирует теги языка HTML.
        #             Получается своеобразная матрешка.
        # TODO. В том случае, когда в составе фрагмента текста есть
        #       символ "'" (одинарная кавычка), представленная здесь
        #       программная конструкция не работает.
        my $command = "<a href=\\\"javascript:void( 0 )\\\" " .
                      "class=\\\"hot_help_link_list\\\" onclick=" .
                      "\\\"insert_str_into_field( opener.$field_name, " .
                                                 "'$esc_val' ); " .
                      "self.close()\\\">" .
                      "$esc_val</a><br />";

        print qq{ help_win.document.write( "$command" ); } . "\n";
      }

      print <<END_OF_SCRIPT;
        help_win.document.write( "</body>" );
        help_win.document.write( "</html>" );
        help_win.document.close();
      }
      //-->
      </script>
END_OF_SCRIPT
      ;

      # если эта подсказка вызывается по HTML-ссылке, ...
      if ( $hot_help_info{ $key }[ 0 ][ 0 ] eq 'LINK' )
      {
        # ... то сформируем HTML-ссылку
        print "<a href=\"javascript:void( 0 )\" " .
              "class=\"hot_help_link\" onclick=" .
              "\"open_hot_help_window_${short_field_name}_${key}()\">" .
              $hot_help_info{ $key }[ 0 ][ 1 ] . "</a>\n";
      }
      # а если для вызова подсказки предусмотрена кнопка, ...
      elsif ( $hot_help_info{ $key }[ 0 ][ 0 ] eq 'BTN' )
      {
        # ... то сформируем HTML-кнопку
        print "<input type=\"button\" " .
              qq{ class="hot_help_btn" } .
              " value=\"" . 
                CGI::escapeHTML( $hot_help_info{ $key }[ 0 ][ 1 ] ) .
              "\"" .
              " onclick=
              \"open_hot_help_window_${short_field_name}_${key}()\"/>" . "\n";
      }
    }
    # если эта подсказка не содержит НИ ОДНОГО фрагмента (на этот факт
    # указывает длина массива, равная 0), то сообщим об этом пользователю
    # (есть параметр ..._TITLE, но для него нет ни одного параметра ..._VALUE
    # в конфиг. файле)
    else       # scalar @{ $hot_help_info{ $key }[ 1 ] } == 0
    {
      # если эта подсказка вызывается по HTML-ссылке, ...
      if ( $hot_help_info{ $key }[ 0 ][ 0 ] eq 'LINK' )
      {
        # ... то сформируем HTML-ссылку
        print "<a href=\"javascript:void( 0 )\" " .
              "class=\"hot_help_link\" onclick=" .
              "\"javascript:alert('Нет списка вариантов')\">" .
              $hot_help_info{ $key }[ 0 ][ 1 ] . "</a>\n";
      }
      # а если для вызова подсказки предусмотрена кнопка, ...
      elsif ( $hot_help_info{ $key }[ 0 ][ 0 ] eq 'BTN' )
      {
        # ... то сформируем HTML-кнопку
        print "<input type=\"button\" " .
              "class=\"hot_help_btn\" " .
              "value=\"$hot_help_info{ $key }[ 0 ][ 1 ]\" " .
              "onclick = \"javascript:alert('Нет списка вариантов')\"/>" .
              "\n";
      }
    }
  }

  # если в хеше есть элементы, значит, была сформирована хотя бы одна 
  # HTML-ссылка или кнопка, и в HTML-документ необходимо добавить
  # тег <br />, чтобы эти кнопки (ссылки) располагались НАД полем для ввода
  # текста
  # ПРИМЕЧАНИЕ. Есть ли более красивый способ определения непустоты хеша?
  if ( scalar keys %hot_help_info >= 1 )
  {
    print "<br />\n";
  }
  
  return;
}

# -----------------------------------------------------------------------------
# формирование ссылки для возврата на главную страницу "Электронного архива"
# -----------------------------------------------------------------------------
sub create_main_page_link
{
  # ограничители {} в операторе qq заменены на '', чтобы в редакторе Joe
  # не было проблем с цветовой поддержкой синтаксиса языка Perl
  print qq'<a id="main_link" href="/$CFG{ HOME_WEB_DIR }/e_arch.pl" 
             target="_top">Главная страница: $CFG{ TITLE }</a>\n';
}

# -----------------------------------------------------------------------------
# формирование текста функции на языке JavaScript, которая формирует
# окно для вызова модуля-справочника и вызывает модуль-справочник
# -----------------------------------------------------------------------------
sub create_selection_func
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры:
  # имя функции на языке JavaScript (func_name);
  # имя вызываемого модуля (module_name);
  # имя вызывающего модуля (caller_name);
  # имя создаваемого окна (для JavaScript) (window_name);
  # параметры для создания окна (window_params);
  # признак работы со схемой "экспорт/импорт" БД (exp_imp)

  # для удобства создадим скалярные переменные
  my $func_name = $prms{ func_name };
  my $module_name = $prms{ module_name };
  my $caller_name = $prms{ caller_name };
  my $window_name = $prms{ window_name };
  my $window_params = $prms{ window_params };
  my $exp_imp = $prms{ exp_imp };
  
  if ( $window_params eq undef )
  {
    $window_params = $CFG{ SELECTION_WINDOW_PARAMS };
  }
  
  # добавлен параметр enable_select=1
  # добавлен параметр exp_imp=$exp_imp
  print <<END_OF_SCRIPT;
  <script language="JavaScript" type="text/javascript">
  <!--
  function ${func_name}()
  {
    window.open( '/$CFG{ HOME_WEB_DIR }/$module_name/select' +
                 '?enable_select=1&caller_name=$caller_name' +
                 '&exp_imp=$exp_imp',
                 '$window_name',
                 '$window_params' );
  }
  //-->
  </script>
END_OF_SCRIPT
  ;
}

# -----------------------------------------------------------------------------
# формирование верхнего блока в окне со списком "команд" для пользователя
# -----------------------------------------------------------------------------
sub create_top_block
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            условное имя модуля (module);
  #            заголовок модуля (module_title);
  #            имя пользователя, работающего с модулем (user);
  #            признак необходимости создания ссылок для каждой буквы
  #            русского и латинского алфавитов, а также дополнительных
  #            ссылок (make_letters);
  #            число последних введенных записей, которые требуется
  #            выводить на экран (num_last_recs);
  #            признак формирования полного верхнего блока (full_top)
  #            (по умолчанию -- 'yes', чтобы сформировать сокращенный вариант
  #            верхнего блока, нужно дать значение 'no')

  my $query = $prms{ query };    # для удобства
  my $script_name;               # имя скрипта (включая путь), из которого
                                 # вызвана эта процедура
  my $add_params = '';           # дополнительные параметры

  $script_name = $query->script_name;  # для удобства

  # по умолчанию -- 'yes', т. е. полный блок
  $prms{ full_top } = 'yes' if ! $prms{ full_top };

  # будем выводить ссылку на главную страницу и описание базы данных
  # в таблице, чтобы они располагались на одной строке
  # TODO. Найти более приличное решение.
  if ( ! $query->param( 'enable_select' ) || $CFG{ DBDESCR_DISPLAY_IS_ON } )
  {
    print "<table id=\"main_link_table\">\n";
    print "<tr>\n";
    print "<td id=\"td_main_link\">\n";

    # будем создавать ссылку для перемещения на главную страницу только
    # при условии, что данный модуль вызван НЕ в режиме справочника
    if ( ! $query->param( 'enable_select' ) )
    {
      create_main_page_link();
    }
    print "</td>\n";

    print "<td id=\"td_dbdescr\">\n";
    # выведем описание базы данных, если это предусмотрено спец. флагом
    print "$CFG{ DBDESCR }\n" if ( $CFG{ DBDESCR_DISPLAY_IS_ON } );

    # если работаем со схемой БД "экспорт/импорт", то выведем также отметку
    # о конкретном состоянии системы -- экспорт или импорт
    if ( $query->param( 'exp_imp' ) )
    {
      print "&nbsp;" . "(экспорт)\n" if export_enabled();
      print "&nbsp;" . "(импорт)\n" if import_enabled();
    }
    print "</td>\n";

    print "</tr>\n";
    print "</table>\n";
  }
  
  # выведем заголовок модуля
  print "<h2 class=\"module_title\">$prms{ module_title }</h2>\n";

  # при формировании сокращенного верхнего блока на этом и завершаем процедуру
  if ( $prms{ full_top } eq 'no' )
  {
    return ( 0 );
  }
  
  # при использовании данного модуля в режиме справочника будут существовать
  # параметры enable_select и caller_name (имя вызывающего модуля)
  if ( $query->param( 'enable_select' ) )
  {
    $add_params = "enable_select=1&caller_name=" .
                  $query->param( 'caller_name' );
  }

  if ( $query->param( 'exp_imp' ) )
  {
    # если значение переменной $add_params уже непустое
    $add_params .= "&" if ( $add_params );
    $add_params .= "exp_imp=1";
  }
  
  # при работе с модулем EXPORT (exp_imp.pl)
  if ( $prms{ module } eq 'EXPORT' )
  {
    if ( have_access( 'module' => $prms{ module }, 'procedure' => 'START',
                      'user' => $prms{ user } ) )
    {
      print qq{ <a class="command_link" href="$script_name/export?start=1} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Начать экспорт</a>\n };
    }

    # если экспорт не был инициализирован, то смотреть нечего
    if ( export_enabled() )
    {
      print qq{ <a class="command_link"} .
            qq{ href="/$CFG\{ HOME_WEB_DIR \}/e_arch.pl?exp_imp=1} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Экспортируемые данные</a>\n };
    }

    # можно экспортировать все данные из всех таблиц, только если экспорт
    # был инициализирован
    if ( export_enabled() &&
         have_access( 'module' => $prms{ module }, 'procedure' => 'EXPORT_ALL',
                      'user' => $prms{ user } ) )
    {
      print qq{ <a class="command_link" } .
            qq{href="$script_name/export?export_all=1} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Экспортировать всю базу данных</a>\n };
    }

    # завершать экспорт можно, только если он был инициализирован
    if ( export_enabled() &&
         have_access( 'module' => $prms{ module }, 'procedure' => 'FINISH',
                      'user' => $prms{ user } ) )
    {
      print qq{ <a class="command_link" href="$script_name/export?finish=1} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Завершить экспорт</a>\n };
    }
    return ( 0 );  
  }

  # при работе с модулем IMPORT (exp_imp.pl)
  if ( $prms{ module } eq 'IMPORT' )
  {
    if ( have_access( 'module' => $prms{ module }, 'procedure' => 'START',
                      'user' => $prms{ user } ) )
    {
      print qq{ <a class="command_link" href="$script_name/import?start=1} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Начать импорт</a>\n };
    }

    # если импорт не был инициализирован, то смотреть нечего
    if ( import_enabled() )
    {
      print qq{ <a class="command_link"} .
            qq{ href="/$CFG\{ HOME_WEB_DIR \}/e_arch.pl?exp_imp=1} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Импортируемые данные</a>\n };
    }

    # завершать импорт можно, только если он был инициализирован
    if ( import_enabled() &&
         have_access( 'module' => $prms{ module }, 'procedure' => 'FINISH',
                      'user' => $prms{ user } ) )
    {
      print qq{ <a class="command_link" href="$script_name/import?finish=1} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Завершить импорт</a>\n };
    }
    return ( 0 );  
  }

  # для всех остальных модулей, кроме экспорта/импорта

  if ( $prms{ make_letters } eq 'yes' )
  {
    # создадим ссылки для каждой буквы русского и латинского алфавитов,
    # а также дополнительные ссылки
    # добавим в начале строки параметров символ "&", т. к. в функции 
    # make_letters() будет сформирован один параметр, перед которым поставлен
    # символ "?"
    make_letters( $script_name, 
                  ( $add_params ) ? "&" . $add_params : '',
                  $prms{ num_last_recs }
                );
  }
  else
  {
    # ссылка для вывода данных в виде общего списка (например, списка городов)
    print qq{ <a class="command_link" href="$script_name/query} .
          ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
          qq{ target="_self">Список</a>\n };
  }

  # если этот модуль вызван в режиме справочника, и при этом он вызван
  # "сам из себя", то не разрешим операцию добавления записей
  # ПРИМЕЧАНИЕ. Например, модуль "Города" может вызываться "сам из себя"
  #             при вводе кода города, являющегося началом цепочки.
  # не разрешаем добавление записей и при работе со схемой БД "экспорт/импорт"
  if ( ! ( $query->param( 'enable_select' ) &&
           $query->param( 'caller_name') eq $prms{ module }
         ) &&
       ! $query->param( 'exp_imp' )
     )
  {
    if ( have_access( 'module' => $prms{ module }, 'procedure' => 'ADD', 
                      'user' => $prms{ user } ) )
    {
      print qq{ <a class="command_link" href="$script_name/add} .
            ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
            qq{ target="_self">Добавить запись</a>\n };
    }
  }  

  print qq{ <a class="command_link" href="$script_name/find} .
        ( ( $add_params ) ? "?$add_params" : '' ) . "\"" .
        qq{ target="_self">Найти</a>\n };

  return ( 0 );
}

# -----------------------------------------------------------------------------
# формирование даты в формате ГГГГ-ММ-ДД для записи ее в базу данных PostgreSQL
# -----------------------------------------------------------------------------
sub date_for_db
{
  my $date_in = shift; # параметр - дата в исходном формате ("экранном")
  my $epoch = shift;   # параметр - "эпоха" 
                       # (нужна, когда год выражен двумя цифрами)

  my $date_out;        # дата в преобразованном формате
  my( $day, $mon, $year );

  # если дата уже находится в формате базы данных, ...
  if ( $date_in =~ /^(\d\d\d\d)-(\d\d)-(\d\d)$/ )
  {
    return ( $date_in );  # ... то просто возвращаем ее же без изменений
  }
  # если значение даты не определено, ...
  elsif ( $date_in eq undef )
  {
    return ( $date_in );  # ... то просто возвращаем ее же без изменений
  }

  # разделим строку даты на группы - день, месяц и год
  # (учтем, что разделителями могут быть символы ".-/", а также что год
  # может выражаться двумя или четырьмя цифрами)
  ( $day, $mon, $year ) = $date_in =~
                          /^(\d{1,2})[\.\/-](\d{1,2})[\.\/-]((\d\d){1,2})$/;

  # только если год задан двумя цифрами, используем "эпоху"
  if ( $year =~ /^\d\d$/ )
  {
    # если эпоха не указана, ...
    if ( $epoch eq undef )
    {
      $epoch = 20  # ... в качестве рубежа эпох возьмем 1920 год
    }
    else
    {
      # берем две последние цифры года эпохи (так что параметр можно задавать
      # как двумя, так и четырьмя цифрами, например, 20 или 1920)
      ( $epoch ) = $epoch =~ /(\d\d)$/; 
    }
    $year = ( $year < $epoch ) ? $year + 2000 : $year + 1900;
  }
  
  # дополним значения для дня и месяца нулями, если нужно
  $date_out = sprintf( "%4d-%02d-%02d", $year, $mon, $day );

  return ( $date_out );
}

# -----------------------------------------------------------------------------
# формирование даты в формате ДД-ММ-ГГГГ для отображения ее на экране
# -----------------------------------------------------------------------------
sub date_for_display
{
  my $date_in = shift; # параметр - дата в исходном формате ("ГГГГ-ММ-ДД")

  my $date_out;        # дата в преобразованном формате
  my( $day, $mon, $year );

  # TODO
  # Добавить еще один параметр для задания формата, в котором требуется
  # выводить дату. Тогда формат ДД-ММ-ГГГГ будет форматом по умолчанию.

  # если дата пустая, то возвратим пустую строку
  if ( $date_in eq undef || $date_in eq '' )
  {
    return ( '' );
  }

  # разделим строку даты на группы - день, месяц и год
  ( $year, $mon, $day ) = $date_in =~ /^(\d\d\d\d)-(\d\d)-(\d\d)$/;
  
  # дополним значения для дня и месяца нулями, если нужно
  $date_out = sprintf( "%02d-%02d-%4d", $day, $mon, $year );

  return ( $date_out );
}

# -----------------------------------------------------------------------------
# проверка правильности значения даты
# -----------------------------------------------------------------------------
sub date_is_correct
{
  # ПРИМЕЧАНИЕ. Проверяемая дата должна быть в формате ДД-ММ-ГГ(ГГ).

  my $date = shift;    # параметр - дата в исходном формате ("экранном")
  my $epoch = shift;   # параметр - "эпоха" 
                       # (нужна, когда год выражен двумя цифрами)

  my( $day, $month, $year );

  # если значение даты не определено, ...
  if ( $date eq undef )
  {
    return ( 0 );  # неверное значение даты
  }

  # если формат даты неверный, ...
  # (учтем, что разделителями могут быть символы ".-/", а также что год
  # может выражаться двумя или четырьмя цифрами)
  if ( $date !~ /^(\d{1,2})[\.\/-](\d{1,2})[\.\/-]((\d\d){1,2})$/ )
  {
    return ( 0 );  # неверное значение даты
  }

  # разделим строку даты на группы - день, месяц и год
  ( $day, $month, $year ) = $date =~
                            /^(\d{1,2})[\.\/-](\d{1,2})[\.\/-]((\d\d){1,2})$/;

  # только если год задан двумя цифрами, используем "эпоху"
  if ( $year =~ /^\d\d$/ )
  {
    # если эпоха не указана, ...
    if ( $epoch eq undef )
    {
      $epoch = 20  # ... в качестве рубежа эпох возьмем 1920 год
    }
    else
    {
      # берем две последние цифры года эпохи (так что параметр можно задавать
      # как двумя, так и четырьмя цифрами, например, 20 или 1920)
      ( $epoch ) = $epoch =~ /(\d\d)$/; 
    }
    $year = ( $year < $epoch ) ? $year + 2000 : $year + 1900;
  }
  
  # проверим теперь значение даты на правильность
  if ( $month < 1 || $month > 12 )
  {
    return ( 0 );  # неверное значение даты
  }

  # дополним месяц нулем (для последующей обработки функцией grep)
  $month = sprintf( "%02d", $month );
  
  if ( $day == 0 )
  {
    return ( 0 );  # неверное значение даты
  }
  else
  {
    if ( grep( /^$month$/, ( '01', '03', '05', '07', '08', '10', '12' ) ) > 0 )
    {
      if ( $day > 31 )
      {
        return ( 0 );  # неверное значение даты
      }
    }
    elsif ( grep( /^$month$/, ( '04', '06', '09', '11' ) ) > 0 )
    {
      if ( $day > 30 )
      {
        return ( 0 );  # неверное значение даты
      }
    }
    elsif ( $month eq '02' )
    {
      # если год високосный
      # TODO   Выяснить правила определения високосного года. Если не ошибаюсь,
      #        есть еще одно условие - кратность 400.
      if ( $year % 4 == 0 && $day > 29 )
      {
        return ( 0 );  # неверное значение даты
      }
      elsif ( $year % 4 != 0 && $day > 28 )
      {
        return ( 0 );  # неверное значение даты
      }
    }
  }

  return ( 1 );        # верное значение даты
}

# -----------------------------------------------------------------------------
# проверка необходимости включения режима отладки, в котором будет выводиться
# дополнительная служебная информация
# -----------------------------------------------------------------------------
sub debug_is_enabled
{
  # для включения этого режима необходимо выполнение одного (любого)
  # из двух условий:
  # - флаг DEBUG_IS_ON в конфиг. файле имеет значение 1 (включен);
  # - имя (логин) пользователя, который работает с программой, представлено
  #   в списке имен пользователей, задаваемых параметром DEBUG_USERS
  #   в конфиг. файле

  my $user = get_user_name();  # текущий пользователь
  my @debug_users;             # список "отладочных" пользователей
  my $debug = 0;               # по умолчанию режим отладки выключен

  if ( $CFG{ DEBUG_IS_ON } )
  {
    $debug = 1;         # режим отладки включить!
  }
  else
  {
    if ( $CFG{ DEBUG_USERS } )
    {
      $CFG{ DEBUG_USERS } =~ s/\s*$//;  # удалим пробелы в конце строки

      # список разделяется запятыми (возможно, еще и с пробелами) или
      # просто пробелами
      $CFG{ DEBUG_USERS } =~ s/,/ /g;   # заменим запятые на пробелы

      # теперь разделим строку на фрагменты 
      @debug_users = split( /\s+/, $CFG{ DEBUG_USERS } );

      # ищем имя пользователя в массиве "отладочных" пользователей
      $debug = grep( /^$user$/, @debug_users ) ? 1 : 0;
    }
  }

  return ( $debug );
}

# -----------------------------------------------------------------------------
# удаление записи из базы данных
# -----------------------------------------------------------------------------
sub del_rec
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            ссылка на функцию для формирования верхнего блока в окне
  #              со списком "команд" для пользователя (create_top);
  #            целевое окно на экране (target);
  #            ссылка на функцию для вывода дополнительной информации 
  #              (print_add_info)
  #            строка команды для удаления записи из БД (command)

  my $query = $prms{ query };
  my $conn;                       # дескриптор соединения с БД
  my $result;                     # результат выполнения SQL-команды

  # формируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => $prms{ target } );

  open_top();          # начинаем оформление верхней части окна
  &{ $prms{ create_top } }();  # формируем верхнюю часть окна со списком
                       # "команд" для пользователя
  close_top();         # завершаем оформление верхней части окна

  open_bottom();       # начинаем оформление нижней части окна

  # выведем дополнительную информацию на экран
  &{ $prms{ print_add_info } }() if defined( $prms{ print_add_info } );

  $conn = exec_connect_db();   # подключаемся к БД

  # DEBUG 
  print_debug_info( $prms{ command } ) if $DEBUG;  # печатаем строку команды

  # теперь выполняем удаление из БД
  $result = $conn->exec( $prms{ command } );

  # если произошла ошибка при удалении записей из базы данных
  if ( PGRES_COMMAND_OK ne $result->resultStatus )
  {
    # сообщение для пользователя
    print "<p class=\"error\">$CFG{ ERROR_DELETE }</p>\n";
    print STDERR $prms{ command } . "\n";     # выводим строку команды в лог
    die $conn->errorMessage;
  }

  # проверим число фактически удаленных записей
  if ( $result->cmdTuples == 1 )
  {
    print "<p class=\"info\">";
    print "Запись удалена из базы данных</p>\n";
  }
  elsif ( $result->cmdTuples == 0 )
  {
    print "<p class=\"info\">";
    print "Запись из базы данных НЕ удалена</p>\n";
  }
  else          # ( $result->cmdTuples > 1 )
  {
    print "<p class=\"error\">";
    print "Из базы данных удалены " . $result->cmdTuples .
          " записей. Это ошибка! Обратитесь к программисту</p>\n";
  }

  close_bottom();      # завершаем оформление нижней части окна
  print $query->end_html();  
  return ( 0 );
}

# -----------------------------------------------------------------------------
# организация формы для ввода новой записи
# -----------------------------------------------------------------------------
sub do_add
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            имя функции для формирования верхнего блока в окне со списком
  #              "команд" для пользователя (create_top);
  #            имя функции для организации формы (make_form);
  #            URL скрипта для обработки формы (action);
  #            целевое окно на экране (target);
  #            имя кнопки submit (submit_name);
  #            надпись на кнопке submit (submit_value)

  # ПРИМЕЧАНИЕ. Если необходимо создать более одной кнопки, то параметры
  #             submit_name и submit_value должны представлять собой
  #             ссылки на массивы.

  my $query = $prms{ query };

  my $i;

  # формируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => $prms{ target } );

  open_top();          # начинаем оформление верхней части окна
  &{ $prms{ create_top } }();  # формируем верхнюю часть окна со списком
                       # "команд" для пользователя
  close_top();         # завершаем оформление верхней части окна

  open_bottom();       # начинаем оформление нижней части окна

  # поскольку по умолчанию форма обрабатывается тем же URL-ом, которым она
  # была сформирована, то явно указываем URL скрипта для обработки данных,
  # собранных в полях формы, т.к. иначе останется PATH_INFO = 'add' от
  # предыдущего вызова скрипта, во время которого формируется форма, и этот
  # PATH_INFO будет обработан еще раз, чего уже не требуется
  print $query->start_form( -action => $prms{ action },
                            -target => $prms{ target }
                          ), "\n";

  # сформируем исходный код функции на языке JavaScript, которая разблокирует
  # заблокированные поля HTML-формы (если таковые имеются) -- иначе их 
  # значения не будут отправлены web-серверу
  create_enable_elements_func();

  # создадим форму для ввода данных
  &{ $prms{ make_form } }();

  # кнопку submit вынесем за пределы функции make_form() ради ее универсальности

  # если передано более одной кнопки, то сформируем их все
  # ПРИМЕЧАНИЕ. В массивах $prms{ submit_name } и $prms{ submit_value }
  #             должно быть одинаковое число элементов. Проверку соблюдения
  #             этого условия не делаем: считаем, что программист не ошибется.
  if ( ref( $prms{ submit_name } ) eq 'ARRAY' )
  {
    for( $i = 0; $i < scalar @{ $prms{ submit_name } }; $i++ )
    {
      print $query->submit( -name => ${ $prms{ submit_name } }[ $i ],
                            -value => ${ $prms{ submit_value } }[ $i ],
                            -class => 'submit',
                            -onclick => "enable_elements()"
                          ), "&nbsp;\n";
    }
  }
  else                # кнопка всего одна
  {
    print $query->submit( -name => $prms{ submit_name },
                          -value => $prms{ submit_value },
                          -class => 'submit',
                          -onclick => "enable_elements()" ), "\n";
  }

  print $query->end_form();

  close_bottom();   # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# непосредственное выполнение SQL-команды вставки/обновления записи в БД
# (схема "экспорт/импорт" или "импорт")
# -----------------------------------------------------------------------------
sub exec_cmd
{
  # параметры процедуры
  my $conn = shift;             # дескриптор соединения с БД
  my $target_schema = shift;    # наименование целевой схемы БД
  my $table = shift;            # имя таблицы
  my $cmd_type = shift;         # тип SQL-команды (INSERT или UPDATE)
  my $command = shift;          # строка SQL-команды
  my $where = shift;            # условие WHERE, которое служит для проверки
                                # наличия экспортируемой записи в схеме
                                # "экспорт/импорт"

  my $result;                   # результат выполнения SQL-команды

  # чтобы в вызывающей процедуре можно было подсчитывать общее число
  # добавленных записей будем делать так: если запись добавлять не нужно,
  # то возвратим 0, если запись добавлена -- 1

  # если условие WHERE передано в качестве параметра, то выполним
  # проверку на дублирование (можно было бы и просто выполнять команду
  # $command, но тогда в случае дублирования значения первичного ключа СУБД
  # выдаст устрашающее сообщение пользователю на английском языке)
  if ( $where )
  {
    # выбираем записи
    $result = 
      $conn->exec( "SELECT 'x' FROM $target_schema.$table WHERE $where" );

    # если произошла ошибка при выборке из базы данных
    if ( PGRES_TUPLES_OK ne $result->resultStatus )
    {
      # сообщение для пользователя
      print "<p class=\"error\">$CFG{ ERROR_SELECT }</p>\n";
      print STDERR $command . "\n";           # выводим строку команды в лог
      die $conn->errorMessage;
    }

    # выполнять вставку новой записи не нужно: она уже есть в схеме "эксп/имп"
    # TODO. Подумать: надо ли это сообщать пользователю и как это сделать?
    # TODO. Может быть, удалять все команды для подчиненных таблиц, коли
    #       запись в главной таблице дублируется? Проверять их на дублирование
    #       нет смысла -- они будут гарантированно дублироваться. А может быть,
    #       проверять на дублирование еще на этапе экспортирования отдельной
    #       записи, например, биб. описания?
    return 0 if ( $result->ntuples > 0 );
  }
  
  # DEBUG 
  print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

  # выполним команду вставки/обновления записи в БД (схема "экспорт/импорт")
  $result = $conn->exec( $command );

  # если произошла ошибка при вставке/обновлении записей в БД
  if ( PGRES_COMMAND_OK ne $result->resultStatus )
  {
    # сообщение для пользователя
    print "<p class=\"error\">" .
          ( ( $cmd_type eq 'INSERT' ) ? $CFG{ ERROR_INSERT } :
                                        $CFG{ ERROR_UPDATE } ) . "</p>\n";
    print STDERR $command . "\n";             # выводим строку команды в лог
    die $conn->errorMessage;
  }
  # ПРИМЕЧАНИЕ. Оставим пока что этот фрагмент.
  #  else
  #  {
  #    print "<p class=\"info\">";
  #    print( "Запись добавлена в экспортную базу данных (таблица " .
  #           "\"Общий список объектов библиографического описания\")</p>\n" );
  #  }
  
  # подсчитываем только введенные записи, обновленные (UPDATE) -- нет
  return ( $cmd_type eq 'INSERT' ) ? 1 : 0;
}

# -----------------------------------------------------------------------------
# выполнение подключения к серверу базы данных
# -----------------------------------------------------------------------------
sub exec_connect_db
{
  # параметр -- строка параметров для подключения
  my $conn_str = shift;
  
  my $conn;        # дескриптор соединения с БД

  # если параметр не передан, сформируем строку параметров для подключения к БД
  $conn_str = create_conn_str() if ( $conn_str eq undef );
  
  $conn = Pg::connectdb( $conn_str );
  
  die $CFG{ ERROR_CONNECT } . $conn->errorMessage
    unless PGRES_CONNECTION_OK eq $conn->status;

  return $conn;
}

# -----------------------------------------------------------------------------
# выполнение выборки из базы данных
# -----------------------------------------------------------------------------
sub exec_select
{
  # параметры
  my $command = shift;   # строка SQL-команды
  my $msg     = shift;   # текст сообщения, выводимого при отсутствии записей
  my $conn    = shift;   # дескриптор соединения с БД

  my $result;            # результат выполнения выборки

  # если параметр с текстом сообщения не передан, назначим текст по умолчанию
  $msg = "Записей, соответствующих указанному критерию, нет в базе данных"
    if ( $msg eq undef );

  # DEBUG 
  print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

  if ( ! $conn )
  {
    $conn = exec_connect_db();
  }
  # выбираем записи
  $result = $conn->exec( $command );

  # если произошла ошибка при выборке из базы данных
  if ( PGRES_TUPLES_OK ne $result->resultStatus )
  {
    # сообщение для пользователя
    print "<p class=\"error\">$CFG{ ERROR_SELECT }</p>\n";
    print STDERR $command . "\n";           # выводим строку команды в лог
    die $conn->errorMessage;
  }

  if ( $result->ntuples == 0 )              # не нашлось ни одной строки
  {
    # в ряде случаев нам не нужно никакого сообщения (например, в функции
    # get_available()), поэтому в качестве параметра будет передана строка
    # пробелов " ", выводить которую на экран не нужно
    print "<p class=\"info\">$msg</p>\n" if ( $msg !~ /^\s+$/ );

    return ( undef );
  }

  return ( $result );
}  

# -----------------------------------------------------------------------------
# выполнение SQL-команды обработки транзакции
# -----------------------------------------------------------------------------
sub exec_transaction
{
  # параметр
  my $conn = shift;          # дескриптор соединения с БД
  my $oper = shift;          # операция (BEGIN, END, ROLLBACK)

  my $result;                # результат выполнения SQL-команды
  
  if ( $oper ne "BEGIN" && $oper ne "END" && $oper ne "ROLLBACK" )
  {
    # сообщение для пользователя
    print "<p class=\"error\">Неверный тип операции: $oper</p>\n";
    # выводим строку команды в лог
    print STDERR "Неверный тип операции: $oper\n";
    die;
  }

  $result = $conn->exec( $oper );

  # текст сообщения об ошибке зависит от вида операции
  die $CFG{ 'ERROR_' . $oper } . $conn->errorMessage
    unless PGRES_COMMAND_OK eq $result->resultStatus;

  return;
}

# -----------------------------------------------------------------------------
# экспортирование записей из таблиц БД
# -----------------------------------------------------------------------------
sub export_data
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            ссылка на функцию для формирования верхней части окна
  #              со списком "команд" для пользователя (create_top);
  #            ссылка на массив ссылок на двухэлементные массивы,
  #              содержащие имя таблицы и соответствующую команду для нее
  #              (table_cmd_pairs)

  # добавим наименования исходной и целевой схем БД
  $prms{ source_schema } = 'public';
  $prms{ target_schema } = 'exp_imp';

  # эта процедура будет одной и той же как для экспорта, так и для импорта
  # (меняются лишь наименования исходной и целевой схем БД)
  copy_data( %prms );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# проверка нахождения системы в состоянии "экспортирование записей"
# -----------------------------------------------------------------------------
sub export_enabled
{
  # если файл export существует, а файл import не существует
  # (функция stat() возвращает список параметров файла; если файла нет,
  # то список имеет нулевую длину)
  if ( scalar stat( "./exp_imp/export" ) > 0 && 
       scalar stat( "./exp_imp/import" ) == 0
     )
  {
    return ( 1 );    # экспорт "включен"
  }

  return ( 0 );      # экспорт не "включен"
}

# -----------------------------------------------------------------------------
# замена первой буквы в строке на заглавную
# -----------------------------------------------------------------------------
sub first_cap
{
  # ПРИМЕЧАНИЕ. Эта функция - интерфейс к функции first_letter(), которую
  #             можно использовать и непосредственно, если есть желание.

  return first_letter( 'to_upper', shift );
}

# -----------------------------------------------------------------------------
# замена первой буквы в строке на заглавную или строчную
# -----------------------------------------------------------------------------
sub first_letter
{
  # ПРИМЕЧАНИЕ. Можно было использовать встроенные функции Perl - ucfirst(),
  #             lcfirst(), по крайней мере, для латинских букв, но если 
  #             не настроена система локализации в операционной системе
  #             (LC_CTYPE и т.д.), то с русскими буквами будут проблемы.
  #             Правда, в Perl'е есть директива use locale. Короче говоря,
  #             эта функция может быть переработана или упразднена - 
  #             жизнь покажет.

  # параметры: 
  # режим работы - to_lower или to_upper;
  # строка, в которой нужно перевести первую букву в верхний регистр
  my $mode = shift;
  my $string = shift;

  # строки-алфавиты
  # ПРИМЕЧАНИЕ. Символы "ь" и "ъ" поставлены в конце - не по алфавиту.
  my $lower_abc = "abcdefghijklmnopqrstuvwxyz" .
                  "абвгдеёжзийклмнопрстуфхцчшщыэюяьъ";
  my $upper_abc = "ABCDEFGHIJKLMNOPQRSTUVWXYZ" .
                  "АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЫЭЮЯЬЪ";

  my $first = substr( $string, 0, 1 );  # первая буква в исходной строке

  # позиция первой буквы из исходной строки в строке-алфавите строчных
  # (маленьких) или прописных (больших) букв
  my $index;

  # если исходная строка не передана или ее длина - нулевая, завершаем работу
  if ( length( $string ) == 0 || $string eq undef )
  {
    return undef;
  }

  # найдем позицию исходной буквы в строке-алфавите

  # переводим в верхний регистр, значит...
  if ( $mode eq 'to_upper' )
  {
    # ... нужно искать среди строчных
    $index = index( $lower_abc, $first );
  }
  # в нижний регистр - ...
  elsif ( $mode eq 'to_lower' )
  {
    # ... среди прописных
    $index = index( $upper_abc, $first );
  }
  
  # если такой буквы в нашей строке-алфавите нет, то просто возвращаем
  # исходную строку без изменений
  if ( $index < 0 )
  {
    return ( $string );
  }

  # возьмем теперь букву, стоящую в такой же позиции в "зеркальной"
  # строке-алфавите

  # переводим в верхний регистр, значит...
  if ( $mode eq 'to_upper' )
  {
    $first = substr( $upper_abc, $index, 1 );
  }
  # в нижний регистр - ...
  elsif ( $mode eq 'to_lower' )
  {
    $first = substr( $lower_abc, $index, 1 );
  }

  # заменим первую букву в строке
  # ПРИМЕЧАНИЕ. Используется способность функции substr() работать в качестве
  #             значения lvalue (т.е. фактически переменной, в которую можно
  #             записать значение, что мы и делаем). См. также документацию
  #             на функцию substr().
  substr( $string, 0, 1 ) = $first;

  return ( $string );
}

# -----------------------------------------------------------------------------
# замена первой буквы в строке на строчную
# -----------------------------------------------------------------------------
sub first_lower
{
  # ПРИМЕЧАНИЕ. Эта функция - интерфейс к функции first_letter(), которую
  #             можно использовать и непосредственно, если есть желание.

  return first_letter( 'to_lower', shift );
}

# -----------------------------------------------------------------------------
# получение списка физических форм, в которых представлены экземпляры объекта
# биб. описания, имеющиеся в наличии у персоналии с идентификатором, указанным
# в конфиг. файле
# -----------------------------------------------------------------------------
sub get_available
{
  # параметры процедуры
  my $obj_id = shift;       # Уникальный идентификатор объекта
                            # библиографического описания
  my $db_schema = shift;    # схема БД -- exp_imp или public
                            # (если exp_imp, то параметр включает и точку,
                            # разделяющую имя схемы и имя таблицы;
                            # если public, то параметр -- пустая строка "")
  
  my $result;               # для работы с БД
  my $command;              # строка команды для выборки из таблицы
  my @row;                  # для хранения одной записи из выборки

  my @phys_forms = ();      # список с обработанными результатами выборки
  my $owner_pers_id;        # интересующий нас идентификатор владельца

  $owner_pers_id = $CFG{ BIB_RECS_OWNER_PERS_ID };
  
  if ( $owner_pers_id eq undef )  # в конфиг. файле параметр не указан
  {
    # назначим 1, исходя из предположения, что самую важную персоналию,
    # т. е. себя, пользователь этого программного средства введет
    # с идентификатором 1
    $owner_pers_id = 1;
  }

  # будем не только выбирать наименования физ. форм, но и кол-во записей
  # для каждого наименования
  $command = "SELECT pft.phys_form_sname, count( pft.phys_form_sname ) " .
             "FROM ${db_schema}stor_objs so, " .
                  "${db_schema}phys_form_types pft " .
             "WHERE so.obj_id = '$obj_id' AND " .
                   "so.owner_pers_id = $owner_pers_id AND " .
                   "so.phys_form_code = pft.phys_form_code " .
             "GROUP BY pft.phys_form_sname";

  # сделаем выборку из БД
  # при этом в случае отсутствия искомых записей в БД никакого сообщения
  # выводить не будем, поэтому параметр -- " "
  $result = exec_select( $command, " " );
  
  if ( $result )
  {
    # выбираем все записи из полученной выборки
    while ( @row = $result->fetchrow )
    {
      # записей для конкретного наименования физ. формы больше одной
      if ( $row[ 1 ] > 1 )
      {
        # помещаем в массив не только наименование физ. формы, но и кол-во
        # записей для этой формы
        push( @phys_forms, "$row[ 0 ] ($row[ 1 ])" );
      }
      else
      {
        # помещаем в массив только наименование
        push( @phys_forms, $row[ 0 ] );
      }
    }
  }
  return ( @phys_forms );
}  

# -----------------------------------------------------------------------------
# получение биб. описания из таблицы БД
# -----------------------------------------------------------------------------
sub get_bib_rec
{
  # параметры процедуры
  my $obj_id = shift;       # уникальный идентификатор объекта биб. описания
  my $bib_rec_num = shift;  # номер библиогр. записи для данного объекта
  my $db_schema = shift;    # схема БД -- exp_imp или public
                            # (если exp_imp, то параметр включает и точку,
                            # разделяющую имя схемы и имя таблицы;
                            # если public, то параметр -- пустая строка "")
  
  my $result;               # для работы с БД
  my $command;              # строка команды для выборки из таблицы
  my @row;                  # для хранения одной записи из выборки
  my $bib_rec;              # биб. описание
  
  $command = "SELECT CASE WHEN bib_rec_full IS NOT NULL " .
                         "THEN bib_rec_full " .
                         "ELSE bib_rec_short " .
                    "END AS bib_rec " .
             "FROM ${db_schema}bib_recs " .
             "WHERE obj_id = $obj_id AND " .
                   "bib_rec_num = $bib_rec_num";

  # сделаем выборку из БД
  $result = exec_select( $command );
  
  if ( $result )
  {
    # берем единственную запись из полученной выборки
    @row = $result->fetchrow;
    $bib_rec = $row[ $result->fnumber( 'bib_rec' ) ];

    # будем заменять двойной дефис, которым мы имитируем тире при вводе
    # данных, символом тире &mdash;
    # см. TODO в функции list_bib_recs_by_query() модуля E_ARCH.pm.
    $bib_rec =~ s/--/&mdash;/g;

    return ( $bib_rec );
  }
  return "";
}

# -----------------------------------------------------------------------------
# получение очередного значения ключевого поля таблицы БД
# -----------------------------------------------------------------------------
sub get_next_key_value
{
  # параметры
  my $table = shift;              # имя таблицы БД
  my $key_name = shift;           # имя ключевого поля в этой таблице
  my $where_clause = shift;       # предложение WHERE (оно может быть полезно,
                                  # когда первичный ключ в таблице -- 
                                  # составной, например, в таблице Stor_objs)

  my $key_value;                  # значение ключевого поля

  my( $conn, $result );           # для работы с БД
  my @row;                        # для хранения одной записи из выборки
  my $command;                    # строка команды для работы с БД

  # выбираем максимальное значение ключевого поля из таблицы $table
  $command = "SELECT max( $key_name ) FROM $table";
  $command .= " WHERE " . $where_clause if ( $where_clause );

  # TODO. Подумать над использованием функции exec_select().

  # DEBUG 
  print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

  $conn = exec_connect_db();            # подключаемся к БД
  $result = $conn->exec( $command );    # выполняем выборку

  # если произошла ошибка при выборке из базы данных
  if ( PGRES_TUPLES_OK ne $result->resultStatus )
  {
    # сообщение для пользователя
    print "<p class=\"error\">$CFG{ ERROR_SELECT }</p>\n";
    print STDERR $command . "\n";             # выводим строку команды в лог
    die $conn->errorMessage;
  }

  if ( $result->ntuples == 0 )
  {
    print "<p class=\"error\">";
    print "Получить значение ключевого поля из таблицы $table " .
          "не удалось</p>\n";
    die;
  }
  else
  {
    # возьмем запись из полученной выборки
    @row = $result->fetchrow();

    # берем максимальное значение ключевого поля и увеличиваем его на 1
    $key_value = $row[ 0 ] + 1;
  }
  return ( $key_value );  # предложим пользователю это значение ключа 
}

# -----------------------------------------------------------------------------
# получение описания справочного материала из таблицы БД
# -----------------------------------------------------------------------------
sub get_ref_descr
{
  # параметры процедуры
  my $obj_id = shift;       # уникальный идентификатор объекта биб. описания
  my $bib_rec_num = shift;  # номер библиогр. записи для данного объекта
  my $ref_num = shift;      # номер справочного материала в пределах объекта
  my $db_schema = shift;    # схема БД -- exp_imp или public
                            # (если exp_imp, то параметр включает и точку,
                            # разделяющую имя схемы и имя таблицы;
                            # если public, то параметр -- пустая строка "")
  
  my $result;               # для работы с БД
  my $command;              # строка команды для выборки из таблицы
  my @row;                  # для хранения одной записи из выборки
  my $ref_descr;            # описание справочного материала
  
  $command = "SELECT ref_descr " .
             "FROM ${db_schema}Refs_descrs " .
             "WHERE obj_id = $obj_id AND " .
                   "bib_rec_num = $bib_rec_num AND " .
                   "ref_num = $ref_num";

  # сделаем выборку из БД
  $result = exec_select( $command );
  
  if ( $result )
  {
    # берем единственную запись из полученной выборки
    @row = $result->fetchrow;
    $ref_descr = $row[ $result->fnumber( 'ref_descr' ) ];

    # будем заменять двойной дефис, которым мы имитируем тире при вводе
    # данных, символом тире &mdash;
    $ref_descr =~ s/--/&mdash;/g;

    return ( $ref_descr );
  }
  return "";
}

# -----------------------------------------------------------------------------
# получение описания серии/подсерии из таблицы БД
# -----------------------------------------------------------------------------
sub get_ser_descr
{
  # параметры процедуры
  my $series_id = shift;     # уникальный идентификатор серии/подсерии
  my $ser_descr_num = shift; # номер описания серии/подсерии
  my $db_schema = shift;     # схема БД -- exp_imp или public
                             # (если exp_imp, то параметр включает и точку,
                             # разделяющую имя схемы и имя таблицы;
                             # если public, то параметр -- пустая строка "")
  
  my $result;                # для работы с БД
  my $command;               # строка команды для выборки из таблицы
  my @row;                   # для хранения одной записи из выборки
  my $ser_descr;             # описание серии/подсерии
  
  $command = "SELECT ser_descr " .
             "FROM ${db_schema}Ser_descrs " .
             "WHERE series_id = $series_id AND " .
                   "ser_descr_num = $ser_descr_num";

  # сделаем выборку из БД
  $result = exec_select( $command );
  
  if ( $result )
  {
    # берем единственную запись из полученной выборки
    @row = $result->fetchrow;
    $ser_descr = $row[ $result->fnumber( 'ser_descr' ) ];

    # будем заменять двойной дефис, которым мы имитируем тире при вводе
    # данных, символом тире &mdash;
    $ser_descr =~ s/--/&mdash;/g;

    return ( $ser_descr );
  }
  return "";
}

# -----------------------------------------------------------------------------
# получение имени пользователя, работающего с "Электронным архивом"
# -----------------------------------------------------------------------------
sub get_user_name
{
  # в настоящее время используем только один способ - хеш %ENV,
  # а функция создана на перспективу
  my $user_name = $ENV{ REMOTE_USER };

  return ( $user_name );
}

# -----------------------------------------------------------------------------
# проверка полномочий данного пользователя на выполнение конкретной процедуры
# указанного модуля
# -----------------------------------------------------------------------------
sub have_access
{
  # параметры - имя пользователя и условные наименования модуля и процедуры:
  # user, module, procedure (это ключи хеша);
  # параметры именованные, они передаются парами, например:
  # USER => 'admin', MODULE => 'students', PROCEDURE => 'add'

  my %params;
  my @tmp = @_;  # скопируем массив параметров во временный массив
  my $i;

  my( $conn, $result );         # для работы с БД
  my @row;                      # для хранения одной записи из выборки
  my $command;                  # строка команды для работы с БД

  my %access = ();              # хеш для хранения информации о правах доступа

  # переведем все параметры в верхний регистр
  # ПРИМЕЧАНИЕ. Система аутентификации будет нечувствительной к регистру
  #             символов.
  for ( $i = 0; $i < scalar @tmp; $i++ )
  {
    $tmp[ $i ] = uc( $tmp[ $i ] );
  }

  # ПРИМЕЧАНИЕ. Такой способ обработки параметров - именованные параметры - 
  #             используем ради пробы.
  %params = ( @tmp ); 

  $conn = exec_connect_db();    # подключаемся к БД

  # сначала ищем запись в таблице "Пользователи" для данного пользователя
  $command = "SELECT * FROM users " .
             "WHERE upper( user_name ) = '$params{ USER }'";
  # DEBUG 
  # если раскомментировать эту строку, то будет сообщение от web-сервера
  # о неверно сформированном http-заголовке (и это совершенно логично,
  # т.к. на данном этапе заголовок еще не сформирован в какой-либо другой
  # функции)
  # ПРИМЕЧАНИЕ. Это замечание касается и всех дальнейших сообщений для
  #             пользователя, поэтому их тоже пока закомментируем, а там
  #             видно будет.
  # print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

  $result = $conn->exec( $command );

  # если произошла ошибка при выборке из базы данных
  if ( PGRES_TUPLES_OK ne $result->resultStatus )
  {
    # сообщение для пользователя
    # print "<p class=\"error\">$CFG{ ERROR_SELECT }</p>\n";
    print STDERR $command . "\n";               # выводим строку команды в лог
    die $conn->errorMessage;
  }

  # если такая запись не найдена, то возвращаем 0 - доступ не разрешен
  # ПРИМЕЧАНИЕ. Не проверяем случай, когда записей больше одной. Такого
  #             не должно быть: следит сама СУБД по ограничению целостности.
  if ( $result->ntuples == 0 )
  {
    return ( 0 );
  }

  @row = $result->fetchrow();  # берем запись из выборки

  # проверим значение флага разрешения доступа
  if ( $row[ $result->fnumber( 'user_active' ) ] eq 'f' )
  {
    return ( 0 );              # запрещен доступ
  }

  # поскольку данный пользователь существует и ему не перекрыт "кислород",
  # выберем все записи для данного пользователя из таблицы "Права доступа"
  $command = "SELECT upper( module_name ) as module_name, " .
                    "upper( proc_name ) as proc_name, oper_active " .
             "FROM access " .
             "WHERE upper( user_name ) = '$params{ USER }' " .
             "ORDER BY 1, 2";
  # DEBUG 
  # (см. ПРИМЕЧАНИЕ в комментарии выше)
  # print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

  $result = $conn->exec( $command );

  # если произошла ошибка при выборке из базы данных
  if ( PGRES_TUPLES_OK ne $result->resultStatus )
  {
    # сообщение для пользователя
    # print "<p class=\"error\">$CFG{ ERROR_SELECT }</p>\n";
    print STDERR $command . "\n";             # выводим строку команды в лог
    die $conn->errorMessage;
  }

  # если такие записи не найдены, то возвращаем 0 - доступ не разрешен
  if ( $result->ntuples == 0 )
  {
    return ( 0 );   # доступ не разрешен
  }

  # берем записи из выборки...
  while ( @row = $result->fetchrow() )
  {
    # ...и формируем двухуровневый хеш:
    # имя_модуля => имя_процедуры => флаг_доступа
    $access{ $row[ $result->fnumber( 'module_name' ) ] }
           { $row[ $result->fnumber( 'proc_name' ) ] } = 
           $row[ $result->fnumber( 'oper_active' ) ];
  }

  # ПРИМЕЧАНИЕ. Политика при назначении прав доступа используется такая:
  #             локальное решение имеет приоритет над глобальным, т.е. если
  #             для конкретной процедуры конкретного модуля указано, что ее
  #             выполнение запрещено, а для условного модуля с именем 'ALL'
  #             указано, что его выполнение разрешено, то доступа к этой
  #             процедуре данный пользователь получить не должен.

  # сначала проверим значение флага разрешения доступа именно для данной
  # процедуры указанного модуля
  if ( exists $access{ $params{ MODULE } }{ $params{ PROCEDURE } } )
  {
    # флаг установлен
    if ( $access{ $params{ MODULE } }{ $params{ PROCEDURE } } eq 't' )
    {
      return ( 1 );     # доступ разрешен
    }
    # флаг сброшен
    else
    {
      return ( 0 );     # доступ не разрешен
    }
  }

  # теперь проверим значение флага разрешения доступа именно для данной
  # процедуры условного модуля 'ALL' (это имя означает - ВСЕ модули)
  # ПРИМЕЧАНИЕ. В данном случае воздейстие оказывается на одноименные 
  #             процедуры ВСЕХ модулей. Это может быть полезно, когда 
  #             необходимо запретить, например, удаление во всех модулях.
  if ( exists $access{ ALL }{ $params{ PROCEDURE } } )
  {
    # флаг установлен
    if ( $access{ ALL }{ $params{ PROCEDURE } } eq 't' )
    {
      return ( 1 );     # доступ разрешен
    }
    # флаг сброшен
    else
    {
      return ( 0 );     # доступ не разрешен
    }
  }

  # затем проверим значение флага разрешения доступа для условной
  # процедуры 'ALL' указанного модуля (эта процедура означает ВСЕ процедуры
  # данного модуля)
  if ( exists $access{ $params{ MODULE } }{ ALL } )
  {
    # флаг установлен
    if ( $access{ $params{ MODULE } }{ ALL } eq 't' )
    {
      return ( 1 );     # доступ разрешен
    }
    # флаг сброшен
    else
    {
      return ( 0 );     # доступ не разрешен
    }
  }

  # наконец проверим значение флага разрешения доступа для условного модуля
  # 'ALL' и условной процедуры 'ALL' (это означает ВСЕ модули ВСЕХ процедур)
  if ( exists $access{ ALL }{ ALL } )
  {
    # флаг установлен
    if ( $access{ ALL }{ ALL } eq 't' )
    {
      return ( 1 );     # доступ разрешен
    }
    # флаг сброшен
    else
    {
      return ( 0 );     # доступ не разрешен
    }
  }

  # -----------------------------------------------------------------------
  # ОСТАВИМ этот фрагмент: это прежнее решение задачи с использованием
  # трех последовательных выборок из таблицы Access. Этот фрагмент может
  # еще пригодиться
  # -----------------------------------------------------------------------
#  # сначала ищем запись именно для данной процедуры указанного модуля
#  $command = "SELECT 'x' " .
#             "FROM access " .
#             "WHERE upper( user_name ) = '$params{ USER }' and " .
#                   "upper( module_name ) = '$params{ MODULE }' and " .
#                   "upper( proc_name ) = '$params{ PROCEDURE }'";
#
#  # DEBUG
#  # print STDERR "$command<BR>\n";
#
#  $result = $conn->exec( $command );
#  die $conn->errorMessage unless PGRES_TUPLES_OK eq $result->resultStatus;
#
#  # если такая запись найдена, то возвращаем "успех" - доступ разрешен
#  # ПРИМЕЧАНИЕ. Не проверяем случай, когда записей больше одной. Такого
#  #             не должно быть: следит сама СУБД по ограничению целостности.
#  if ( $result->ntuples == 1 )
#  {
#    return ( 1 );
#  }
#  
#  # если же такая запись не найдена, проверим, может быть права даны на весь
#  # модуль
#  # ПРИМЕЧАНИЕ. Модули и процедуры не должны иметь имена 'ALL', поскольку
#  #             это слово используется как условное значение.
#  $command = "SELECT 'x' " .
#             "FROM access " .
#             "WHERE upper( user_name ) = '$params{ USER }' and " .
#                   "upper( module_name ) = '$params{ MODULE }' and " .
#                   "upper( proc_name ) = 'ALL'";
#
#  # DEBUG
#  # print STDERR "$command<BR>\n";
#
#  $result = $conn->exec( $command );
#  die $conn->errorMessage unless PGRES_TUPLES_OK eq $result->resultStatus;
#
#  # если такая запись найдена, то возвращаем "успех" - доступ разрешен
#  # ПРИМЕЧАНИЕ. Не проверяем случай, когда записей больше одной. Такого
#  #             не должно быть: следит сама СУБД по ограничению целостности.
#  if ( $result->ntuples == 1 )
#  {
#    return ( 1 );
#  }
#  
#  # если же такая запись не найдена, проверим, может быть права даны на все
#  # модули
#  $command = "SELECT 'x' " .
#             "FROM access " .
#             "WHERE upper( user_name ) = '$params{ USER }' and " .
#                   "upper( module_name ) = 'ALL' and " .
#                   "upper( proc_name ) = 'ALL'";
#
#  # DEBUG
#  # print STDERR "$command<BR>\n";
#
#  $result = $conn->exec( $command );
#  die $conn->errorMessage unless PGRES_TUPLES_OK eq $result->resultStatus;
#
#  # если такая запись найдена, то возвращаем "успех" - доступ разрешен
#  # ПРИМЕЧАНИЕ. Не проверяем случай, когда записей больше одной. Такого
#  #             не должно быть: следит сама СУБД по ограничению целостности.
#  if ( $result->ntuples == 1 )
#  {
#    return ( 1 );
#  }
# -------------------------------------------------------------------------

  # доступ не разрешен
  return ( 0 );
}

# -----------------------------------------------------------------------------
# формирование заголовков HTTP и HTML
# -----------------------------------------------------------------------------
sub http_html_headers
{
  # параметры - именованные
  # параметр - ссылка на CGI-объект должен быть передан функции обязательно
  # (его имя - query)

  # создадим хеш с параметрами по умолчанию
  # если функции переданы фактические параметры, то изменим соответствующие
  # значения в хеше
  my %prms = ( target => "_self",
               charset => lc( $CFG{ CHARSET } ),
               Content_Language => "ru_RU",
               title => $CFG{ TITLE },
               author => $CFG{ AUTHOR_EMAIL },
               type => "text/html",
               @_
             );

  # TODO. Параметр target, видимо, не нужен, т. к. его нет у метода
  #       header (см. описание пакета CGI). Пусть пока останется, т. к.
  #       вреда от него нет.
  print $prms{ query }->header( -type => $prms{ type },
                                -target => $prms{ target },
                                -charset => $prms{ charset }
                              );
  # сформируем тег META в заголовке
  print $prms{ query }->start_html( 
          -title => $prms{ title },
          -author => $prms{ author },
          -style => { 'src' => "/$CFG{ HOME_WEB_CSS_DIR }/$CFG{ CSS }" },
          -lang => "$prms{ Content_Language }",
          -head => "<meta http-equiv='Content-Type' content='$prms{ type };" .
                   "charset=$prms{ charset }' />",
          -class => "body"
        );
  return;
}

# -----------------------------------------------------------------------------
# импортирование записей из таблиц БД
# -----------------------------------------------------------------------------
sub import_data
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            ссылка на функцию для формирования верхней части окна
  #              со списком "команд" для пользователя (create_top);
  #            ссылка на массив ссылок на двухэлементные массивы,
  #              содержащие имя таблицы и соответствующую команду для нее
  #              (table_cmd_pairs)

  # добавим наименования исходной и целевой схем БД
  $prms{ source_schema } = 'exp_imp';
  $prms{ target_schema } = 'imp';

  # эта процедура будет одной и той же как для экспорта, так и для импорта
  # (меняются лишь наименования исходной и целевой схем БД)
  copy_data( %prms );

  return ( 0 );
}

# -----------------------------------------------------------------------------
# проверка нахождения системы в состоянии "импортирование записей"
# -----------------------------------------------------------------------------
sub import_enabled
{
  # если файл import существует, а файл export не существует
  # (функция stat() возвращает список параметров файла; если файла нет,
  # то список имеет нулевую длину)
  if ( scalar stat( "./exp_imp/import" ) > 0 && 
       scalar stat( "./exp_imp/export" ) == 0
     )
  {
    return ( 1 );    # импорт "включен"
  }

  return ( 0 );      # импорт не "включен"
}

# -----------------------------------------------------------------------------
# вывод биб. описаний всех объектов, выбранных по запросу
# -----------------------------------------------------------------------------
sub list_bib_recs_by_query
{
  # параметры
  my $query = shift;              # CGI-объект
  my $command = shift;            # строка команды для работы с БД
  my $headline = shift;           # заголовок списка

  my( $result, $i );              # для работы с БД
  my @row;                        # для хранения одной записи из выборки

  my @avail_objs;                 # список физ. форм, в которых присутствуют
                                  # наличные экземпляры объекта биб. описания,
                                  # хранимые у персоналии, имеющей
                                  # идентификатор, указанный в конфиг. файле

  my $can_view = 0;      # имеет ли пользователь право на просмотр записи 
  my $can_delete = 0;    # в виде HTML-формы и удаление записи

  my $can_export = 0;    # имеет ли пользователь право на экспортирование...
  my $can_import = 0;    # ...импортирование записи

  my $alt_row = 1;       # признак того, что текущую строку таблицы нужно
                         # выводить другим цветом
  my $href;              # типовая часть HTML-ссылки

  # схема БД (для экспорта/импорта)
  my $db_schema = $query->param( 'exp_imp' ) ? "exp_imp." : "";

  print "$headline\n";                 # выведем заголовок списка

  $result = exec_select( $command );   # сделаем выборку из БД
  
  if ( $result )
  {
    # в качестве имени модуля во всех случаях будет именно 'BIB_RECS',
    # а не кодовое имя того модуля, из которого вызывается эта процедура
    # (она может вызываться, например, из модуля persons.pl; при вызове
    # из модуля bib_recs.pl имеет место совпадение)
    $can_view = have_access( 'module' => 'BIB_RECS', 'procedure' => 'VIEW', 
                             'user' => get_user_name() );
    $can_delete = have_access( 'module' => 'BIB_RECS', 'procedure' => 'DELETE',
                               'user' => get_user_name() );

    # работаем со схемой БД "экспорт/импорт", поэтому экспорт не имеет смысла
    if ( $query->param( 'exp_imp' ) )
    {
      $can_import = import_enabled() && 
                    have_access( 'module' => 'BIB_RECS',
                                 'procedure' => 'IMPORT',
                                 'user' => get_user_name() );
    }
    else      # работаем со схемой public -- можем экспортировать данные
    {
      $can_export = export_enabled() && 
                    have_access( 'module' => 'BIB_RECS',
                                 'procedure' => 'EXPORT',
                                 'user' => get_user_name() );
    }

    # выведем информацию в виде таблицы
    print "<table class=\"list\">\n";
    print "<tr>\n";
    print "<th>Номер п/п</th>\n";
    print "<th>Идентификатор объекта и номер биб. записи</th>\n";
    print "<th>Библиографическое описание</th>\n";
    print "<th>Наличие</th>\n";
    print "<th>&nbsp;</th>\n" if ( $can_view || $can_delete || $can_export ||
                                   $can_import );
    print "</tr>\n";

    # выводим все записи из полученной выборки
    while ( @row = $result->fetchrow )
    {
      # если включен флаг альтернативной раскраски строк в таблице
      if ( $CFG{ ALT_ROWS_IS_ON } )
      {
        $alt_row = ! $alt_row;
        print ( ( $alt_row ) ? "<tr class=\"alt_row\">\n" : "<tr>\n" );
      }
      else
      {
        print "<tr>\n";
      }

      # выводим порядковый номер, уник. код объекта биб. описания
      # и номер биб. записи, биб. описание
      $i++;                      # порядковый номер
      print "<td class=\"center\">$i</td>\n";
      print "<td class=\"center\">" .
            $row[ $result->fnumber( 'obj_id' ) ] . " (".
            $row[ $result->fnumber( 'bib_rec_num' ) ] . ")",
            "</td>\n";

      # будем заменять двойной дефис, которым мы имитируем тире при вводе
      # данных, символом тире &mdash;
      # TODO. Нужно найти более общее решение для выполнения преобразований
      #       хранимых данных при их выводе. Может быть, в этом конкретном
      #       случае -- имитация тире с помощью двух дефисов -- нужно
      #       поискать способ ввода в БД сразу символа тире, а не каких-либо
      #       символов-заменителей.
      my $bib_rec = $row[ $result->fnumber( 'bib_rec' ) ];
      $bib_rec =~ s/--/&mdash;/g;
      print "<td>$bib_rec</td>\n";

      # наличие экземпляров данного объекта у владельца, идентификатор
      # которого указан в конфиг. файле
      print "<td>\n";
      @avail_objs = get_available( $row[ $result->fnumber( 'obj_id' ) ],
                                   $db_schema );
      # выведем все найденные экземпляры (точнее, физ. формы, в которых эти
      # экземпляры присутствуют) в одной ячейке
      foreach ( @avail_objs )
      {
        print $_ . "<br />\n";
      }
      print "</td>\n";

      # типовая часть HTML-ссылки
      $href = ( $query->param( 'exp_imp' ) ? "exp_imp=1&" : "" ) .
              "obj_id=" . $row[ $result->fnumber( 'obj_id' ) ] .
              "&bib_rec_num=" . $row[ $result->fnumber( 'bib_rec_num' ) ];

      # просмотр одной записи в виде HTML-формы (в новом окне)
      print "<td>" if ( $can_view || $can_delete || $can_export ||
                        $can_import );
      print qq{<a class="command_link" } .
            qq{href="/$CFG\{ HOME_WEB_DIR \}/bib_recs.pl/view?$href} .
            qq{&target_win=_self"} .
            qq{ target="_blank">Просмотр</a>} . "\n" if $can_view;

      # удаление записи 
      print qq{<a class="command_link" } .
            qq{href="/$CFG\{ HOME_WEB_DIR \}/bib_recs.pl/delete?$href} .
            qq{&target_win=_self"} .
            qq{ onclick="$confirm_delete"} .
            qq{ target="_self">Удаление</a>} . "\n" if $can_delete;

      # экспортирование записи 
      print qq{<a class="command_link" } .
            qq{href="/$CFG\{ HOME_WEB_DIR \}/bib_recs.pl/export?$href} .
            qq{&target_win=_self"} .
            qq{ onclick="$confirm_export"} .
            qq{ target="_blank">Экспорт</a>} . "\n" if $can_export;

      # импортирование записи 
      print qq{<a class="command_link" } .
            qq{href="/$CFG\{ HOME_WEB_DIR \}/bib_recs.pl/import?$href} .
            qq{&target_win=_self"} .
            qq{ onclick="$confirm_import"} .
            qq{ target="_blank">Импорт</a>} . "\n" if $can_import;

      print "</td>" if ( $can_view || $can_delete || $can_export ||
                         $can_import );
      print "</tr>\n";
    }
    print "</table>\n";
  }

  return ( 0 );
}

# -----------------------------------------------------------------------------
# формирование строки-команды для выполнения добавления и корректировки записи
# -----------------------------------------------------------------------------
sub make_cmd
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            вид операции - вставка или корректировка? (operation);
  #            имя таблицы базы данных (table);
  #            имена ключевых полей, представленные в виде единой строки,
  #              в которой поля разделены запятыми (key).
  #              В том случае, если имена полей в таблице БД не совпадают
  #              с именами параметров Web-формы, каждому полю таблицы БД
  #              ставится в соответствие имя поля Web-формы. Эти два имени
  #              разделяются одним из символов: '/', '\', ':', '='. Строка
  #              в общем случае имеет вид: "field1=abcd, field2, field3:xyz";
  #            ссылка на массив имен полей обрабатываемой таблицы БД (f_names);
  #            ссылка на массив имен полей этой таблицы БД, требующих
  #              специальной обработки (f_special);
  #            ссылка на функцию для обработки таких полей (func_special);
  #            имя пользователя, выполняющего операцию (user)

  my $query = $prms{ query }; # эта переменная - для удобства

  my $command;           # строка формируемой команды
  my $fields = "";       # строка - список полей
  my $values = "";       # строка - список значений полей
  my $fname_value = "";  # набор пар - имя поля и его значение
  my $tmp;               # для временного хранения значения поля
  my $fname;             # имя поля обрабатываемой таблицы БД
                         # (из массива f_names)
  my $key_value;         # значение ключевого поля
  my @keys_tmp;          # временный массив имен ключевых полей
  my @keys;              # "рабочий" массив имен ключевых полей
  my $db_schema;         # схема БД (для экспорта/импорта)
  
  # параметр $prms{ key } требует предварительной обработки
  #   удалим все пробелы, если они есть, и разорвем единую строку
  #   на отдельные поля
  $prms{ key } =~ s/\s//g;
  @keys_tmp = split( /,/, $prms{ key } );

  # сформируем двумерный массив имен ключевых полей из временного массива
  foreach ( @keys_tmp )
  {
    # если для этого поля таблицы БД указано имя поля Web-формы
    if ( /[\/:=\\]/ )       # могут быть различные символы-разделители
    {
      # разрываем строку на две части (считаем, что символ-разделитель
      # в строке окажется только ОДИН) и записываем ссылку на полученный
      # двухэлементный массив в массив имен ключевых полей (получаем
      # двумерный массив)
      push( @keys, [ split( /[\/:=\\]/ ) ] );
    }
    # если для этого поля таблицы БД НЕ указано имя поля Web-формы, то они
    # совпадают
    else
    {
      push( @keys, [ $_, $_ ] );  # оба элемента в субмассиве одинаковые
    }
  }

  # обработаем весь список полей таблицы $prms{ table } и сформируем
  # строку-команду для вставки записи в БД или для обновления
  foreach $fname ( @{ $prms{ f_names } } )  # т.к. это ссылка на массив
  {
    # если поле требует специальной обработки
    # ПРИМЕЧАНИЕ. Если параметр f_special в функцию вообще не передан,
    #             то эта проверка все равно работает корректно и сбоя
    #             быть не должно.
    if ( grep( /^$fname$/, @{ $prms{ f_special } } ) > 0 )
    {
      # специальная функция получает параметры: имя поля и вид операции
      $tmp = &{ $prms{ func_special } }( $fname, $prms{ operation } );
    }
    # значения всех остальных полей берем без изменений из полей формы
    else
    {
      # имена полей таблицы $prms{ table } и параметров формы - совпадают
      $tmp = $query->param( $fname );
    }

    # выполним добавочную обработку значений полей
    $tmp =~ s/^\s*//;        # уберем лидирующие...
    $tmp =~ s/\s*$//;        # ... и замыкающие пробелы

    # начиная с версии 9.1, по умолчанию экранирование с помощью обратного
    # слэша не работает (см. конфигурационный параметр СУБД PostgreSQL
    # standard_conforming_strings), поэтому экранировать символы (") и (\)
    # не нужно, а символ (') необходимо удваивать
    # TODO. Нужно сделать обработку "нехороших" символов более основательно.
    $tmp =~ s/\'/\'\'/g;

    # формируем две части строки-команды для вставки записи в БД:
    # первая - строка-список имен полей, вторая - строка-список значений полей
    if ( $prms{ operation } eq 'APPEND' )
    {    
      # включаем имя текущего поля в список имен полей
      $fields .= $fname . ",";

      # формируем строку значений полей (поэтому нужны одинарные кавычки!!!)
      # если значение параметра пустое, то записываем null, но в этом
      # случае одинарные кавычки НЕ НУЖНЫ
      # ПРИМЕЧАНИЕ. Хотя для числовых полей кавычки не требуются, мы их ставим
      #             только из соображений единообразия и простоты данной
      #             функции.
      $values .= $tmp ne '' ? "'$tmp'," : "null," ;
    }
    elsif ( $prms{ operation } eq 'UPDATE' )
    {
      # формируем пару "имя_поля + значение" и добавляем ее к общей строке
      # ПРИМЕЧАНИЕ. Насчет одинарных кавычек см. выше.
      $fname_value .= $tmp ne '' ? "$fname = '$tmp'," : "$fname = null,";
    }
  }

  if ( $prms{ operation } eq 'APPEND' )
  {
    # пока не удалять этот фрагмент
    # $fields =~ s/,$//;  # уберем последнюю запятую
    # $values =~ s/,$//;  # уберем последнюю запятую

    # добавим имя поля, в котором фиксируется пользователь, выполнивший
    # добавление записи в БД, а также имя этого пользователя
    $fields .= 'who_chg'; 
    $values .= "'$prms{ user }'";

    # сформируем команду окончательно  
    $command = "INSERT INTO $prms{ table } ( $fields ) VALUES ( $values )";
  }
  elsif ( $prms{ operation } eq 'UPDATE' )
  {
    # пока не удалять этот фрагмент
    # $fname_value =~ s/,$//;  # уберем последнюю запятую

    # добавим информацию о имени пользователя, который выполнил
    # обновление записи в БД, а также запишем время обновления записи
    $fname_value .= "who_chg = '$prms{ user }', when_chg = CURRENT_TIMESTAMP";

    # в имя схемы экспорта/импорта включим и точку, отделяющую имя таблицы
    # от имени схемы; при отсутствии имени схемы в SQL-команде не окажется
    # этой точки, что нам и нужно
    $db_schema = $query->param( 'exp_imp' ) ? "exp_imp." : "";
  
    # сформируем начало команды
    $command = "UPDATE ${db_schema}$prms{ table } SET $fname_value " .
               "WHERE ";

    # обработаем все ключевые поля
    foreach ( @keys )
    {
      # возьмем значение для ключевого поля таблицы БД из поля Web-формы
      $key_value = $query->param( $$_[ 1 ] );

      # формируем команду
      $command .= " $$_[ 0 ] = '$key_value' AND ";
    }

    # сформируем команду окончательно: удалим лишнюю логическую операцию
    # в конце строки-команды (на всякий случай учтем и наличие пробелов
    # после последнего 'AND')
    $command =~ s/AND\s*$//;
  }
  return ( $command );
}

# -----------------------------------------------------------------------------
# создание ссылок для каждой буквы русского и латинского алфавитов
# -----------------------------------------------------------------------------
sub make_letters
{
  # параметры
  my $script_name = shift;   # имя скрипта
  my $add_params = shift;    # переменная, содержащая дополнительные параметры,
                             # передаваемые скрипту в командной строке
                             # (например, при использовании модуля в режиме
                             # справочника)
  my $num_last_recs = shift; # число последних записей, введенных в таблицу,
                             # которые нужно выводить при обращении
                             # по специальной ссылке
  
  my @letters;               # массив отдельных букв
  my $letter;                # одна буква
  my $letter_num = 1;        # порядковый номер русской буквы

  # на всякий случай сделаем эти проверки (хотя в вызывающем модуле
  # параметры должны быть сформированы уже в готовом виде)
  if ( $add_params )
  {
    $add_params =~ s/^\?//;  # убрать символ "?" в начале строки параметров
    $add_params = "&" . $add_params if ( $add_params !~ /^&/ );
  }
  else
  {
    $add_params = '';
  }

  # если в конфиг. файле предусмотрен параметр для числа последних записей,
  # введенных в таблицу БД
  # ПРИМЕЧАНИЕ. Пока что не делаем проверку на предмет допустимости значения
  #             параметра (например, /^\d+$/). Пусть пользователь будет
  #             внимательнее при вводе значений параметров.
  # TODO. Надо бы сделать централизованную проверку всех параметров, которые
  #       допускают ограниченное множество значений, при считывании конфиг.
  #       файла.
  if ( $num_last_recs )
  {
    # создаем специальную ссылку
    # в качестве PATH_INFO назначаем query
    print qq{ <a class="command_link" href="$script_name/query} .
          qq{?num_last_recs=$num_last_recs$add_params" } .
          qq{ target="_self">Последние записи</a>\n };

    # отделим эту ссылку от других ссылок
    print "&nbsp;&nbsp;&nbsp;&nbsp;\n";
  }
  
  # разделим "русскую" строку-алфавит на отдельные буквы
  # (символ-разделитель -- пробел)
  @letters = split( /\s+/, $CFG{ STRING_LETTERS_RUS } );
  
  # создаем ссылку для каждой буквы русского алфавита
  # воспользуемся функцией CGI::escape()
  foreach $letter ( @letters )
  {
    print qq{ <a class="command_link" href="$script_name/query} .
          qq{?letter=} . ( $CFG{ HIDE_RUS_LETTERS } ? "_" . $letter_num :
                           CGI::escape( $letter ) ) .
          qq{$add_params" } .
          qq{ target="_self">$letter</a>\n};

    $letter_num++;
  }
  print "<br />\n";
  
  # разделим "латинскую" строку-алфавит на отдельные буквы  
  @letters = split( /\s+/, $CFG{ STRING_LETTERS_LAT } );
  
  # создаем ссылку для каждой буквы латинского алфавита
  # на всякий случай также воспользуемся функцией CGI::escape()
  foreach $letter ( @letters )
  {
    print qq{ <a class="command_link" href="$script_name/query} .
          qq{?letter=} . CGI::escape( $letter ) . qq{$add_params" } .
          qq{ target="_self">$letter</a>\n};
  }
  print "&nbsp;&nbsp;&nbsp;&nbsp;\n";   # отделим неалфавитные символы
  
  # разделим строку неалфавитных символов на отдельные символы
  @letters = split( /\s+/, $CFG{ STRING_SYMBOLS } );

  # создаем ссылку для каждого неалфавитного символа
  # воспользуемся функцией CGI::escape()
  foreach $letter ( @letters )
  {
    # TODO Не получается корректно обрабатывать кавычки.
    # $letter =~ s/\"/\\\"/;    # "заэкранируем" кавычки обоих типов
    # $letter =~ s/\'/\\\'/;
    # $letter = CGI::escape( $letter );
    print qq{ <a class="command_link" href="$script_name/query} .
          qq{?letter=} . CGI::escape( $letter ) . qq{$add_params" } .
          qq{ target="_self">$letter</a>\n};
  }
  print "<br />\n";

  return ( 0 );
}

# -----------------------------------------------------------------------------
# начало оформления нижней части окна
# -----------------------------------------------------------------------------
sub open_bottom
{
  # выведем HTML-теги, если они были назначены в конфигурационном файле
  print "$CFG{ OPEN_BOTTOM }\n";

  return ( 0 );
}

# -----------------------------------------------------------------------------
# начало оформления верхней части окна
# -----------------------------------------------------------------------------
sub open_top
{
  # выведем HTML-теги, если они были назначены в конфигурационном файле
  print "$CFG{ OPEN_TOP }\n";

  return ( 0 );
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для предоставления пользователю возможности
# выбора значения из списка
# -----------------------------------------------------------------------------
sub make_list_for_popup
{
  # ПРИМЕЧАНИЕ. Эта функция усложнена только ради того, чтобы добиться
  #             упорядочения наименований, выводимых в меню (popup menu).
  #             Поэтому формируеются отдельные массивы для параметров 
  #             values и labels, хотя в принципе можно обойтись одним хешем
  #             для параметра values. Но тогда наименования в меню
  #             были бы неупорядочены.

  # параметр функции
  my $command = shift;   # строка команды для работы с БД

  # в этой функции "значениями" (values) будут значения ключевого поля
  # таблицы БД, а те наименования, которые соответствуют этим значениям, будут
  # называться labels. Эта терминология соответствует параметрам popup menu

  my @values = ();    # значения (первичный ключ) - параметр values
  my @labels = ();    # надписи-строчки меню (наименования) - параметр labels

  my $result;         # для работы с БД
  my @row;            # для хранения одной записи из выборки

  $result = exec_select( $command );    # сделаем выборку из БД
  
  if ( $result )
  {
    # всю выборку преобразуем в массив, из которого будет сформирован элемент
    # popup_menu
    while ( @row = $result->fetchrow )
    {
      # ПРИМЕЧАНИЕ. В записи, представленной в массиве @row, всего ДВА поля:
      #             первое - значение ключевого поля, второе - значение
      #             поля-наименования. За соблюдение этого порядка отвечает
      #             вызывающая функция.

      # массив, составленный из значений ключевого поля таблицы БД
      # (соответствует параметру values в popup_menu)
      push( @values, $row[ 0 ] );  # это поле номер ноль

      # массив-заготовка для хеша - в этот массив помещаем и значения ключевого
      # поля, и значения поля-наименования
      # (массив соответствует параметру labels в popup_menu)
      push( @labels, $row[ 0 ], $row[ 1 ] );
    }
  }

  return ( \@values, \@labels );    # возвращаем список ссылок на массивы
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора канала поступления из списка
# -----------------------------------------------------------------------------
sub popup_acq_ways_list
{
  # параметр
  my $db_schema = shift;    # схема БД -- exp_imp или public
                            # (если exp_imp, то параметр включает и точку,
                            # разделяющую имя схемы и имя таблицы;
                            # если public, то параметр -- пустая строка "")

  my $command;              # строка команды для работы с БД

  # выбираем все записи о каналах поступления
  $command = "SELECT acq_way_code, acq_way_sname " .
             "FROM ${db_schema}acq_ways " .
             "ORDER BY acq_way_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида деятельности организации из списка
# -----------------------------------------------------------------------------
sub popup_activity_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах деятельности организаций
  $command = "SELECT act_type_code, act_type_fname " .
             "FROM ${db_schema}activity_types " .
             "ORDER BY act_type_fname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора города из списка
# -----------------------------------------------------------------------------
sub popup_cities_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о городах (выведем также в скобках краткое
  # наименование страны)
  $command = "SELECT c.city_code, " .
                    "c.city_fname || " .
                      "' (' || cc.country_sname || ')' AS city " .
             "FROM ${db_schema}cities c, ${db_schema}countries cc " .
             "WHERE c.country_code = cc.country_code " .
             "ORDER BY city";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида статуса мероприятий из списка
# -----------------------------------------------------------------------------
sub popup_conf_status_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах статуса мероприятий
  $command = "SELECT conf_status_code, conf_status_sname " .
             "FROM ${db_schema}conf_status_types " .
             "ORDER BY conf_status_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида мероприятий из списка
# -----------------------------------------------------------------------------
sub popup_conf_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах мероприятий
  $command = "SELECT conf_type_code, conf_type_sname " .
             "FROM ${db_schema}conf_types " .
             "ORDER BY conf_type_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора страны из списка
# -----------------------------------------------------------------------------
sub popup_countries_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о странах
  $command = "SELECT country_code, country_sname " .
             "FROM ${db_schema}countries " .
             "ORDER BY country_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора валюты из списка
# -----------------------------------------------------------------------------
sub popup_currencies_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о валютах
  $command = "SELECT currency_code, currency_fname " .
             "FROM ${db_schema}currencies " .
             "ORDER BY currency_fname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида характеристики объекта из списка
# -----------------------------------------------------------------------------
sub popup_det_char_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах характеристик
  $command = "SELECT det_char_code, det_char_sname " .
             "FROM ${db_schema}det_char_types " .
             "ORDER BY det_char_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида тиража из списка
# -----------------------------------------------------------------------------
sub popup_edition_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах тиражей
  $command = "SELECT edition_code, edition_name " .
             "FROM ${db_schema}edition_types " .
             "ORDER BY edition_code";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора группы признаков объектов
# библиографического описания из списка
# -----------------------------------------------------------------------------
sub popup_feature_groups_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о группах признаков
  $command = "SELECT feature_group_code, feature_group_name " .
             "FROM ${db_schema}feature_groups " .
             "ORDER BY feature_group_name";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора кода общего обозначения материала
# из списка
# -----------------------------------------------------------------------------
sub popup_gen_mater_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о кодах общего обозначения материала
  $command = "SELECT gen_mat_code, gen_mat_name " .
             "FROM ${db_schema}gen_mater_types " .
             "ORDER BY gen_mat_name";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора языка из списка
# -----------------------------------------------------------------------------
sub popup_langs_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о языках
  $command = "SELECT lang_code, lang_fname " .
             "FROM ${db_schema}langs " .
             "ORDER BY lang_fname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора организации из списка
# -----------------------------------------------------------------------------
sub popup_orgs_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи об организациях
  $command = "SELECT org_id, org_sname " .
             "FROM ${db_schema}orgs " .
             "ORDER BY org_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида упаковки из списка
# -----------------------------------------------------------------------------
sub popup_pack_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах упаковки
  $command = "SELECT pack_code, pack_fname " .
             "FROM ${db_schema}pack_types " .
             "ORDER BY pack_fname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида физической формы из списка
# -----------------------------------------------------------------------------
sub popup_phys_form_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах физической формы
  $command = "SELECT phys_form_code, phys_form_fname " .
             "FROM ${db_schema}phys_form_types " .
             "ORDER BY phys_form_fname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида языковой обработки из списка
# -----------------------------------------------------------------------------
sub popup_process_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах языковой обработки
  $command = "SELECT process_code, process_fname " .
             "FROM ${db_schema}process_types " .
             "ORDER BY process_fname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора кода источника библиографического
# описания из списка
# -----------------------------------------------------------------------------
sub popup_recs_sources_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах источников библиографического описания
  $command = "SELECT source_code, source_name " .
             "FROM ${db_schema}recs_sources " .
             "ORDER BY source_name";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида справочного материала из списка
# -----------------------------------------------------------------------------
sub popup_ref_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах справочных материалов
  $command = "SELECT ref_type_code, ref_type_sname " .
             "FROM ${db_schema}ref_types " .
             "ORDER BY ref_type_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора роли из списка
# -----------------------------------------------------------------------------
sub popup_roles_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах ролей
  $command = "SELECT role_code, role_sname " .
             "FROM ${db_schema}roles " .
             "ORDER BY role_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора группы специфических обозначений
# материала из списка
# -----------------------------------------------------------------------------
sub popup_spec_mater_groups_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о группах специфических обозначений материала
  $command = "SELECT spec_mat_group_code, spec_mat_group_fname " .
             "FROM ${db_schema}spec_mater_groups " .
             "ORDER BY spec_mat_group_fname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида специфического обозначения
# материала из списка
# -----------------------------------------------------------------------------
sub popup_spec_mater_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах специфического обозначения материала
  $command = "SELECT t.spec_mat_code, t.spec_mat_sname || ' (' || " .
                    "g.spec_mat_group_sname || ')' " .
             "FROM ${db_schema}spec_mater_types t, " .
                  "${db_schema}spec_mater_groups g " .
             "WHERE t.spec_mat_group_code = g.spec_mat_group_code " .
             "ORDER BY g.spec_mat_group_sname, t.spec_mat_sname";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# формирование массивов, которые служат в качестве параметров values и labels
# при создании popup menu для выбора вида стандартного номера (ISBN, ISSN
# и др.) из списка
# -----------------------------------------------------------------------------
sub popup_std_num_types_list
{
  # параметр
  my $db_schema = shift;    # схема БД

  my $command;              # строка команды для работы с БД

  # выбираем все записи о видах стандартных номеров
  $command = "SELECT std_num_code, std_num_name " .
             "FROM ${db_schema}std_num_types " .
             "ORDER BY std_num_name";

  return ( make_list_for_popup( $command ) );  # типовая процедура
}

# -----------------------------------------------------------------------------
# вывод биб. описания и заголовка подчиненного модуля, соответствующего
# конкретному элементу биб. описания
# -----------------------------------------------------------------------------
sub print_bib_record
{
  # параметры
  my $query = shift;          # CGI-объект
  my $headline = shift;       # заголовок модуля, соответствующего элементу
                              # биб. описания
  my $calling_module = shift; # имя модуля, из которого вызвана процедура
    
  # сформируем параметры для передачи скрипту -- эти параметры мы попросту
  # ретранслируем к следующему запуску этого же скрипта
  # (выводить весь текст будем в окно "_self")
  my $href = "exp_imp=" . $query->param( 'exp_imp' ) .
             "&obj_id=" . $query->param( 'obj_id' ) .
             "&bib_rec_num=" . $query->param( 'bib_rec_num' ) .
             "&bib_rec=" . CGI::escape( $query->param( 'bib_rec' ) ) .
             "&target_win=_self";

  my $script_name = $query->script_name;

  my $bib_rec;           # биб. описание
  my $ref_descr;         # описание справочного материала
  
  # для модуля "Содержание справочных материалов объектов библиографического
  # описания" сделаем дополнительную обработку
  if ( $calling_module eq "REFS_CONTENTS" )
  {
    $href .= "&ref_num=" . $query->param( 'ref_num' )
      if ( $query->param( 'ref_num' ) );

    $href .= "&ref_descr=" . CGI::escape( $query->param( 'ref_descr' ) )
      if ( $query->param( 'ref_descr' ) );
  }
  
  # выведем уникальный идентификатор объекта биб. описания и номер библиогр.
  # записи для данного объекта
  print "<p class=\"bib_rec\">";
  print "Идентификатор объекта библиографического описания: " . 
        $query->param( 'obj_id' ) . "\n";
  print "&nbsp;&nbsp;\n";

  # TODO. Нужно во всех модулях, соответствующих областям биб. описания,
  #       в которых не требуется этот параметр, все-таки его создавать.
  #       В настоящее время в таких модулях он не обрабатывается, поэтому
  #       в следующем операторе print вместо этого номера может быть "пусто".
  print "Номер библиографической записи для данного объекта: " .
        $query->param( 'bib_rec_num' ) . "</p>\n";

  # если имеются проблемы с русскими буквами в HTML-ссылках
  if ( $CFG{ HIDE_RUS_LETTERS } )
  {
    # если параметр 'bib_rec_num' не передан, назначим пока что 0
    # (см. TODO выше)
    $bib_rec = get_bib_rec( $query->param( 'obj_id' ), 
                            $query->param( 'bib_rec_num' ) ?
                              $query->param( 'bib_rec_num' ) : 0,
                            $query->param( 'exp_imp' ) ? "exp_imp." : "" );
  }
  else
  {
    $bib_rec = $query->param( 'bib_rec' );
  }

  # выведем биб. описание
  print "<p class=\"bib_rec\">$bib_rec</p>\n";
  
  # выведем заголовок модуля
  print "<h2 class=\"module_title\">$headline</h2>\n";

  # для модуля "Содержание справочных материалов объектов библиографического
  # описания" выведем описание справочного материала
  if ( $calling_module eq "REFS_CONTENTS" )
  {
    # если имеются проблемы с русскими буквами в HTML-ссылках
    if ( $CFG{ HIDE_RUS_LETTERS } )
    {
      $ref_descr = get_ref_descr( $query->param( 'obj_id' ), 
                                  $query->param( 'bib_rec_num' ),
                                  $query->param( 'ref_num' ),
                                  $query->param( 'exp_imp' ) ? "exp_imp." :
                                  "" );
    }
    else
    {
      $ref_descr = $query->param( 'ref_descr' );
    }
    print "<p class=\"bib_rec\">$ref_descr</p>\n";
  }

  # создадим также ссылку для вывода списка записей
  # эта ссылка дает точно такой же результат, что и ссылка в модуле 
  # "Биб. описания", по которой вызывается подчиненный модуль, соответствующий
  # конкретному элементу биб. описания (например, "Место издания");
  # наличие этой ссылки избавляет от необходимости выходить в модуль 
  # "Биб. описания" с целью обновления, к примеру, списка мест издания после
  # удаления записи об одном из мест издания
  print qq{<a class="command_link" href="$script_name/query?$href"} .
        qq{ target="_self">Список</a>\n};

  # для модуля "Содержание справочных материалов объектов библиографического
  # описания" выведем ссылку для организации поиска
  if ( $calling_module eq "REFS_CONTENTS" )
  {
    print qq{<a class="command_link" href="$script_name/find?$href" } .
          qq{ target="_self">Поиск</a>\n};
  }

  return ( 0 );
}

# -----------------------------------------------------------------------------
# универсальная процедура печати отладочной информации
# -----------------------------------------------------------------------------
sub print_debug_info
{
  my $msg = shift;    # параметр -- текст сообщения (возможно, что будет массив)
  
  print "<p class=\"debug_info\">\n";
  
  if ( ref( $msg ) eq 'ARRAY' )
  {
    foreach ( @{ $msg } )
    {
      print $_;
    }
  }
  else
  {
    print $msg;
  }
  
  print "</p>\n";
  
  return ( 0 );
}

# -----------------------------------------------------------------------------
# универсальная процедура печати переменных окружения (среды)
# -----------------------------------------------------------------------------
sub print_env
{
  my( $var, $val );

  foreach $var ( sort( keys( %ENV ) ) ) 
  {
    $val = $ENV{ $var };
    print "${ var }=\"${ val }\"<br />\n";
  }
}

# -----------------------------------------------------------------------------
# универсальная процедура печати параметров 
# -----------------------------------------------------------------------------
sub print_params
{
  my $query = shift;    # параметр - CGI-объект

  foreach ( $query->param )
  {
    print $_, " ", $query->param( $_ ), "<br />\n";
  }
}

# -----------------------------------------------------------------------------
# универсальная процедура печати выборки из БД
# -----------------------------------------------------------------------------
sub print_result
{
  # параметр - объект $result, полученный после операции выборки из БД
  my $result = shift;

  my( $i, $j );

  foreach ( $i = 0; $i < $result->ntuples; $i++ )
  {
    foreach ( $j = 0; $j < $result->nfields; $j++ )
    {
      print $result->getvalue( $i, $j ) . " ";
    }
    print "<br />\n";
  }
}

# -----------------------------------------------------------------------------
# вывод описания серии/подсерии и заголовка подчиненного модуля, 
# соответствующего конкретному элементу описания серии/подсерии
# -----------------------------------------------------------------------------
sub print_ser_descr
{
  # параметры
  my $query = shift;     # CGI-объект
  my $headline = shift;  # заголовок модуля, соответствующего элементу
                         # описания серии/подсерии
 
  # сформируем параметры для передачи скрипту -- эти параметры мы попросту
  # ретранслируем к следующему запуску этого же скрипта
  # (выводить весь текст будем в окно "_self")
  my $href = "exp_imp=" . $query->param( 'exp_imp' ) .
             "&series_id=" . $query->param( 'series_id' ) .
             "&ser_descr_num=" . $query->param( 'ser_descr_num' ) .
             "&ser_descr=" . CGI::escape( $query->param( 'ser_descr' ) ) .
             "&target_win=_self";

  my $script_name = $query->script_name;
  my $ser_descr;         # описание серии/подсерии

  # выведем уникальный идентификатор серии/подсерии и номер описания
  # для данной серии/подсерии
  print "<p class=\"bib_rec\">";
  print "Идентификатор серии/подсерии: " . $query->param( 'series_id' ) . "\n";
  print "&nbsp;&nbsp;\n";
  print "Номер описания серии/подсерии: " .
        $query->param( 'ser_descr_num' ) . "</p>\n";

  # если имеются проблемы с русскими буквами в HTML-ссылках
  if ( $CFG{ HIDE_RUS_LETTERS } )
  {
    $ser_descr = get_ser_descr( $query->param( 'series_id' ), 
                                $query->param( 'ser_descr_num' ),
                                $query->param( 'exp_imp' ) ? "exp_imp." : "" );
  }
  else
  {
    $ser_descr = $query->param( 'ser_descr' );
  }

  # выведем описание серии/подсерии
  print "<p class=\"bib_rec\">$ser_descr</p>\n";
  
  # выведем заголовок модуля
  print "<h2 class=\"module_title\">$headline</h2>\n";

  # создадим также ссылку для вывода списка записей
  # эта ссылка дает точно такой же результат, что и ссылка в модуле 
  # "Описания серий/подсерий", по которой вызывается подчиненный модуль,
  # соответствующий конкретному элементу описания серии/подсерии (например, 
  # "Заглавия серий/подсерий");
  # наличие этой ссылки избавляет от необходимости выходить в модуль 
  # "Описания серий/подсерий" с целью обновления списка заглавий
  # после, например, удаления записи об одном из заглавий
  print qq{<a class="command_link" href="$script_name/query?$href"} .
        qq{ target="_self">Список</a>\n};

  return ( 0 );
}

# -----------------------------------------------------------------------------
# вывод сообщений об ошибках пользователя
# -----------------------------------------------------------------------------
sub print_user_err_msgs
{
  # параметр - ссылка на массив сообщений об ошибках
  my $arr_msgs_ref = shift;
  
  foreach ( @{ $arr_msgs_ref } )
  {
    print "<p class=\"user_error\">$_</p>\n";
  }

  return;
}

# -----------------------------------------------------------------------------
# формирование команд вставки записей в таблицы, являющиеся зависимыми
# от указанной таблицы
# -----------------------------------------------------------------------------
sub process_dependent_tables
{
  # параметры:
  my $table = shift;          # имя обрабатываемой таблицы (у которой могут
                              # быть зависимые таблицы)
  my $record_ref = shift;     # ссылка на хеш-массив, содержащий значения полей
                              # одной записи из таблицы $table
  my $source_schema = shift;  # наименование исходной схемы БД
  my $target_schema = shift;  # наименование целевой схемы БД

  my @f_key_fields;        # массив ключевых полей внешнего ключа
                           # зависимой таблицы
  my @ref_fields;          # массив соответствующих полей главной таблицы
  my $dep_table;           # зависимая таблица
  my @key_fields;          # массив ключевых полей
  my $command;             # строка команды для работы с БД  
  my $result;              # для работы с БД
  my @row;                 # для хранения одной записи из выборки
  my $f_key_name;          # имя внешнего ключа -- ключ хеш-массива
  my %rec = ();            # хеш-массив, содержащий значения полей текущей
                           # записи из выборки  
  my $i;
  my $where;               # условие для проверки на дублирование

  # DEBUG
  # print "Вызов процедуры process_dependent_tables для таблицы " .
  #       "$table<br />\n";

  # если у таблицы $table нет зависимых таблиц, то на этом завершаем работу
  # ПРИМЕЧАНИЕ. Наверное, можно было эту проверку вынести и за пределы данной
  #             процедуры. Но тогда вызов процедуры был бы более громоздким,
  #             с предварительной проверкой. Но с другой стороны, не было бы
  #             лишнего вызова процедуры, когда отсутствуют зависимые таблицы
  #             (а они чаще отсутствуют, чем присутствуют). Что делать?
  if ( ! exists $EXP_CFG{ TABLES }{ $table }{ DEPENDENT_TABLES } )
  {
    # DEBUG
    # print "Возврат из процедуры process_dependent_tables " .
    #       "для таблицы $table -- зависимых таблиц нет<br />\n";

    return;
  }

  # для всех зависимых таблиц таблицы $table
  foreach $dep_table ( @{ $EXP_CFG{ TABLES }{ $table }{ DEPENDENT_TABLES } } )
  {
    # если зависимую таблицу экспортировать не нужно -- к началу цикла
    next if $EXP_CFG{ TABLES }{ $dep_table }{ TABLE_EXPORT } eq 'disabled';

    # выбирать записи из зависимой таблицы будем не по полям первичного
    # ключа этой самой зависимой таблицы, а по следующему правилу:
    # найдем внешний ключ зависимой таблицы, который ссылается на таблицу
    # $table и служит для связи этих таблиц, возьмем из его описания имена
    # соответственных полей обеих таблиц и сформируем условие для выборки 
    # записей из зависимой таблицы

    # для всех внешних ключей таблицы $dep_table
    # сортировка позволяет учесть наличие суффикса 1 или 2 у ряда ключей
    foreach $f_key_name ( sort keys %{ $EXP_CFG{ TABLES }{ $dep_table }
                                               { FOREIGN_KEYS } } )
    {
      # возьмем параметры внешнего ключа из хеш-массива (в принципе, можно
      # работать и с хеш-массивом, но это приведет к слишком громоздким
      # конструкциям)
      if ( $table eq $EXP_CFG{ TABLES }{ $dep_table }{ FOREIGN_KEYS }
                             { $f_key_name }{ REF_TABLE } )
      {
        @f_key_fields = @{ $EXP_CFG{ TABLES }{ $dep_table }{ FOREIGN_KEYS }
                                   { $f_key_name }{ F_KEY_FIELDS }
                         };

        @ref_fields = @{ $EXP_CFG{ TABLES }{ $dep_table }{ FOREIGN_KEYS }
                                 { $f_key_name }{ REF_FIELDS }
                       };
        # ВАЖНО! Если два внешних ключа ссылаются на одну таблицу
        #        (например, это имеет место для таблицы Obj_containers),
        #        то ключ, предназначенный для связи подчиненной таблицы с
        #        главной таблицей, должен идти первым в конфиг. файле
        #        экспорта. Тогда второй ключ просто не будет обработан
        #        благодаря наличию оператора last, что нам и нужно.
        last;      # сразу выходим из цикла перебора внешних ключей
      }
    }
    
    # сначала сформируем строку-команду для выполнения выборки из зависимой
    # таблицы $dep_table
    $command = "SELECT * FROM $source_schema.$dep_table WHERE ";

    # обработаем все ключевые поля внешнего ключа зависимой таблицы
    for ( $i = 0; $i < scalar @f_key_fields; $i++ )
    {
      # формируем команду, при этом значения для ключевых полей в главной
      # таблице берем из хеша, переданного этой процедуре в качестве параметра
      # ПРИМЕЧАНИЕ. Поля с одинаковыми индексами в массивах @ref_fields и 
      #             @f_key_fields соответствуют друг другу.
      $command .= " " . $f_key_fields[ $i ] . " = '" .
                  $$record_ref{ $ref_fields[ $i ] } . "' AND ";
    }

    # завершим команду: удалим лишнюю логическую операцию в конце 
    # строки-команды (на всякий случай учтем и наличие пробелов до и после 
    # последнего 'AND')
    $command =~ s/\s*AND\s*$//;

    # сделаем выборку из БД
    # (второй параметр -- строка пробелов, это нужно для того, чтобы
    # не выводилось сообщение в случае, когда записи не найдены)
    $result = exec_select( $command, "  " );
  
    if ( $result )
    {
      # обрабатываем все записи из полученной выборки
      while ( @row = $result->fetchrow )
      {
        my $fields = "";       # список имен полей (в виде строки)
        my $values = "";       # список значений полей (в виде строки)
        my $fname;             # имя поля
        my $value;             # значение поля

        %rec = ();

        # обработаем все поля выборки (т. е. все поля таблицы)
        for ( $i = 0; $i < scalar @row; $i++ )
        {
          # используем эти переменные для удобства
          # по номеру поля получим его имя и используем это имя
          # в качестве ключа хеш-массива
          $fname = $result->fname( $i );
          $value = $row[ $i ];
        
          # формируем хеш-массив, содержащий значения полей текущей записи
          # из выборки
          $rec{ $fname } = $value;

          # включаем имя текущего поля в список имен полей
          $fields .= $fname . ",";

          # TODO. Нужно сделать обработку "нехороших" символов более
          #       основательно.
          $value =~ s/\'/\'\'/g;

          # формируем строку значений полей (поэтому нужны одинарные
          # кавычки!!!)
          # если значение параметра пустое, то записываем null, но в этом
          # случае одинарные кавычки НЕ НУЖНЫ
          # ПРИМЕЧАНИЕ. Хотя для числовых полей кавычки не требуются, 
          #             мы их ставим только из соображений единообразия 
          #             и простоты данной функции.
          $values .= $value ne '' ? "'$value'," : "null," ;
        }

        $fields =~ s/,$//;  # уберем последнюю запятую
        $values =~ s/,$//;  # уберем последнюю запятую

        # сформируем команду вставки записи в экспортную схему БД окончательно
        $command = "INSERT INTO $target_schema.$dep_table ( $fields ) " .
                               "VALUES ( $values )";

        # теперь сформируем условие WHERE, которое будет использоваться
        # при вводе экспортируемых записей в схему exp_imp для проверки
        # наличия такой записи, команду INSERT для ввода которой мы только что
        # сформировали (проверка на дублирование)
        # TODO. Подумать, нельзя ли избежать проверки на дублирование записей
        #       из подчиненных таблиц. Не достаточно ли проверки на
        #       дублирование только записей из главной таблицы?
        # ВАЖНО. Проверки на дублирование избежать, видимо, нельзя по следующей
        #        причине. Для каждого объекта биб. описания возможно наличие
        #        более одного описания в таблице Bib_recs. При этом часть
        #        подчиненных таблиц, соответствующих областям биб. описания,
        #        связаны с таблицей Bib_recs по ключу obj_id + bib_rec_num, 
        #        а часть -- с таблицей Bib_objs по ключу obj_id.
        #        Поэтому при экспортировании второго (или более) описания,
        #        если первое описание уже было экспортировано, записи, 
        #        связанные с Bib_objs, уже будут находиться в экспортных 
        #        таблицах. Возникнет ошибка дублирования, о которой сообщит
        #        СУБД, если не сделать проверку на дублирование.
        
        # возьмем массив ключевых полей зависимой таблицы
        @key_fields = @{ $EXP_CFG{ TABLES }{ $dep_table }{ KEY_FIELDS } };

        $where = "";

        # обработаем все ключевые поля
        for ( $i = 0; $i < scalar @key_fields; $i++ )
        {
          $where .= $key_fields[ $i ] . " = '" . $rec{ $key_fields[ $i ] } .
                    "' AND ";
        }

        $where =~ s/\s*AND\s*$//;  # уберем лишнее 'AND'

        # добавим сформированную команду во временный хеш-массив -- накопитель

        # ключ -- команда INSERT, значение -- условие WHERE для проверки
        # на дублирование 
        $SQL_commands{ $dep_table }{ $command } = $where;

        # DEBUG 
        print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

        # сформируем команды для вставки записей в ссылочные таблицы,
        # на которые ссылается таблица $dep_table (внешние ключи)
        process_referenced_tables( $dep_table, \%rec, $source_schema,
                                   $target_schema );

        # сформируем команды для вставки записей в зависимые таблицы,
        # которые ссылаются уже на таблицу $dep_table (внешние ключи 
        # в зависимых таблицах)
        process_dependent_tables( $dep_table, \%rec, $source_schema,
                                  $target_schema );
      }
    }
    else
    {
      ;  # TODO. Что в этом случае делать?
    }
  }
  # DEBUG
  # print "Возврат из процедуры process_dependent_tables " .
  #       "для таблицы $table<br />\n";

  return;
}

# -----------------------------------------------------------------------------
# формирование команд вставки записей в таблицы, являющиеся ссылочными
# для указанной таблицы
# -----------------------------------------------------------------------------
sub process_referenced_tables
{
  # параметры:
  my $table = shift;          # имя обрабатываемой таблицы
  my $record_ref = shift;     # ссылка на хеш-массив, содержащий значения полей
                              # одной записи из таблицы $table
  my $source_schema = shift;  # наименование исходной схемы БД
  my $target_schema = shift;  # наименование целевой схемы БД

  my @f_key_fields;        # массив полей внешнего ключа
  my @ref_fields;          # массив соответствующих полей ссылочной таблицы
  my $ref_table;           # ссылочная таблица
  my @key_fields;          # массив ключевых полей
  my $command;             # строка команды для работы с БД  
  my $result;              # для работы с БД
  my @row;                 # для хранения одной записи из выборки
  my $f_key_name;          # имя внешнего ключа -- ключ хеш-массива
  my %rec = ();            # хеш-массив, содержащий значения полей текущей
                           # записи из выборки  
  my $i;
  my $where;               # условие для проверки на дублирование

  # DEBUG
  # print "Вызов процедуры process_referenced_tables " .
  #       "для таблицы $table<br />\n";

  # если у таблицы $table нет внешних ключей, то на этом рекурсия заканчивается
  if ( ! exists $EXP_CFG{ TABLES }{ $table }{ FOREIGN_KEYS } )
  {
    # DEBUG
    # print "Возврат из процедуры process_referenced_tables " .
    #       "для таблицы $table -- ссылочных таблиц нет<br />\n";

    return;
  }

  # для всех внешних ключей таблицы $table
  foreach $f_key_name ( keys %{ $EXP_CFG{ TABLES }{ $table }
                                        { FOREIGN_KEYS } } )
  {
    # если ссылочную таблицу, на которую ссылается этот внешний ключ,
    # не нужно обрабатывать, то идем к началу цикла
    next if grep( /^$f_key_name$/, 
                  @{ $EXP_CFG{ TABLES }{ $table }{ FOREIGN_KEYS_EXCLUDE } } )
            > 0;

    %rec = ();

    # возьмем параметры внешнего ключа из хеш-массива (в принципе, можно
    # работать и с хеш-массивом, но это приведет к слишком громоздким
    # конструкциям)
    $ref_table = $EXP_CFG{ TABLES }{ $table }{ FOREIGN_KEYS }
                         { $f_key_name }{ REF_TABLE };

    @f_key_fields = @{ $EXP_CFG{ TABLES }{ $table }{ FOREIGN_KEYS }
                               { $f_key_name }{ F_KEY_FIELDS }
                     };
    @ref_fields = @{ $EXP_CFG{ TABLES }{ $table }{ FOREIGN_KEYS }
                             { $f_key_name }{ REF_FIELDS }
                   };

    # если значения полей внешнего ключа равны NULL (undef), то для этого
    # внешнего ключа не нужно выбирать записи из ссылочной таблицы
    # (такая ситуация возможна при ссылке таблицы самой на себя, например,
    # в таблице Gen_mater_types поле gen_mat_code_orig ссылается на поле
    # gen_mat_code)
    # ПРИМЕЧАНИЕ. Будем считать, что если первое ключевое поле имеет
    #             значение NULL (undef), то и остальные поля будут иметь
    #             такое же значение. В системе "Электронный архив" 
    #             не используются внешние ключи, у которых лишь часть полей
    #             нулевые (NULL).
    next if ( $$record_ref{ $f_key_fields[ 0 ] } eq undef );
    
    # сначала сформируем строку-команду для выполнения выборки из ссылочной
    # таблицы $ref_table
    $command = "SELECT * FROM $source_schema.$ref_table WHERE ";

    # обработаем все ключевые поля ссылочной таблицы
    for ( $i = 0; $i < scalar @ref_fields; $i++ )
    {
      # формируем команду, при этом значения для ключевых полей в ссылочной
      # таблице берем из хеша, переданного этой процедуре в качестве параметра
      # ПРИМЕЧАНИЕ. Поля с одинаковыми индексами в массивах @ref_fields и 
      #             @f_key_fields соответствуют друг другу.
      $command .= " " . $ref_fields[ $i ] . " = '" .
                  $$record_ref{ $f_key_fields[ $i ] } . "' AND ";
    }

    # завершим команду: удалим лишнюю логическую операцию в конце 
    # строки-команды (на всякий случай учтем и наличие пробелов до и после 
    # последнего 'AND')
    $command =~ s/\s*AND\s*$//;

    # сделаем выборку из БД
    # (второй параметр -- строка пробелов, это нужно для того, чтобы
    # не выводилось сообщение в случае, когда записи не найдены)
    $result = exec_select( $command, "  " );
  
    if ( $result )
    {
      # если таблица ссылается сама на себя
      # ВАЖНО! Учитываем, что таблица может ссылаться сама на себя более
      #        одного раза (например, таблица Orgs).
      if ( $table eq $ref_table )
      {
        # сформируем начало команды UPDATE, которая будет в схеме 
        # экспорта/импорта воссоздавать те же отношения между ссылающейся
        # и ссылочной записями, которые есть в схеме public
        # ВАЖНО! Обновление производим в таблице схемы экспорта/импорта.
        $command = "UPDATE $target_schema.$table SET ";

        # обработаем все поля внешнего ключа ССЫЛАЮЩЕЙСЯ таблицы
        for ( $i = 0; $i < scalar @f_key_fields; $i++ )
        {
          # формируем пару "имя_поля + значение" и добавляем ее к общей строке
          $command .= $f_key_fields[ $i ] . " = '" .
                      $$record_ref{ $f_key_fields[ $i ] } . "', ";

          # "обнулим" значение поля в записи таблицы $table,
          # это поле будет заполнено при выполнении операции UPDATE
          # ПРИМЕЧАНИЕ. Этот ход необходим, т. к. внешний ключ в принципе
          #             может ссылаться на ключевые значения, которые БОЛЬШЕ
          #             тех, что содержаться в полях внешнего ключа. 
          #             Например, в таблице Persons возможна такая ситуация:
          #             в конкретной записи значение поля pers_id равно 10,
          #             а значение поля pers_id_orig равно 11, т.е. более
          #             "старая" запись ссылается на более "новую", получается,
          #             условно говоря, ссылка вперед. Команда INSERT с таким
          #             сочетанием значений полей pers_id и pers_id_orig
          #             не будет выполнена, если только до нее не выполнить
          #             команду INSERT с pers_id = 11. Упорядочить команды
          #             INSERT таким образом, чтобы не нарушались требования
          #             внешних ключей, сложнее, чем обнулять значения
          #             полей внешнего ключа при формировании команды INSERT
          #             и дополнительно сформировать команду UPDATE, которая
          #             восстановит эти значения.
          $$record_ref{ $f_key_fields[ $i ] } = undef;
        }
        
        $command =~ s/,\s*$//;  # уберем последнюю запятую

        @key_fields = @{ $EXP_CFG{ TABLES }{ $table }{ KEY_FIELDS } };

        # завершаем формирование команды
        $command .= " WHERE ";
        
        # обработаем все поля первичного ключа ССЫЛАЮЩЕЙСЯ таблицы
        # (работаем с набором значений полей, который был передан в эту
        # функцию в качестве параметра $record_ref)
        for ( $i = 0; $i < scalar @key_fields; $i++ )
        {
          $command .= $key_fields[ $i ] . " = '" .
                      $$record_ref{ $key_fields[ $i ] } . "' AND ";
        }

        $command =~ s/\s*AND\s*$//;

        # запишем сформированную команду в хеш-массив, при этом в данном
        # случае полезную нагрузку несет только сам ключ, поэтому -- undef;
        # принцип работы хеш-массива позволяет нам автоматически избежать
        # включения в хеш дублирующихся команд: поскольку строка команды
        # является ключом, то сам Perl заботится о том, чтобы не было
        # дублирующихся ключей
        $SQL_commands{ $table }{ $command } = undef;

        # DEBUG 
        print_debug_info( $command ) if $DEBUG;  # печатаем строку команды
      }

      # обрабатываем запись из полученной выборки
      # ПРИМЕЧАНИЕ. Запись всегда будет только ОДНА?
      @row = $result->fetchrow;

      my $fields = "";       # список имен полей (в виде строки)
      my $values = "";       # список значений полей (в виде строки)

      my $fname;
      my $value;

      # сформируем хеш-массив, содержащий значения полей текущей записи
      # из выборки, сделанной из таблицы $ref_table
      for ( $i = 0; $i < scalar @row; $i++ )
      {
        $rec{ $result->fname( $i ) } = $row[ $i ];  # ключ хеша -- имя поля
      }

      # сформируем команды для вставки записей в ссылочные таблицы, на которые
      # ссылается теперь уже таблица $ref_table
      # ВАЖНО! Команду "INSERT INTO exp_imp.$ref_table ..." формируем
      #        уже после вызова функции process_referenced_tables().
      #        Это делается потому, что в этой функции могут быть обнулены
      #        (undef) поля внешнего ключа, если таблица ссылается сама
      #        на себя. И команда INSERT должна быть сформирована с учетом
      #        этих обнулений.
      process_referenced_tables( $ref_table, \%rec, $source_schema,
                                 $target_schema );

      # сформируем команды для вставки записей в зависимые таблицы,
      # которые ссылаются уже на таблицу $ref_table (внешние ключи 
      # в зависимых таблицах)
      process_dependent_tables( $ref_table, \%rec, $source_schema,
                                $target_schema );
      
      # сформируем список имен полей и список значений полей для команды
      # INSERT INTO 
      foreach $fname ( keys %rec )
      {
        # используем эти переменные для удобства
        # по номеру поля получим его имя и используем это имя
        # в качестве ключа хеш-массива
        # $fname = $result->fname( $i );
        $value = $rec{ $fname };
        
        # включаем имя текущего поля в список имен полей
        $fields .= $fname . ",";

        # TODO. Нужно сделать обработку "нехороших" символов более
        #       основательно.
        $value =~ s/\'/\'\'/g;

        # формируем строку значений полей (поэтому нужны одинарные кавычки!!!)
        # если значение параметра пустое, то записываем null, но в этом
        # случае одинарные кавычки НЕ НУЖНЫ
        # ПРИМЕЧАНИЕ. Хотя для числовых полей кавычки не требуются, 
        #             мы их ставим только из соображений единообразия 
        #             и простоты данной функции.
        $values .= $value ne '' ? "'$value'," : "null," ;
      }

      $fields =~ s/,$//;  # уберем последнюю запятую
      $values =~ s/,$//;  # уберем последнюю запятую

      # сформируем команду вставки записи в экспортную схему БД окончательно  
      $command = "INSERT INTO $target_schema.$ref_table ( $fields ) " .
                             "VALUES ( $values )";

      # теперь сформируем условие WHERE, которое будет использоваться
      # при вводе экспортируемых записей в схему exp_imp для проверки
      # наличия такой записи, команду INSERT для ввода которой мы только что
      # сформировали (проверка на дублирование)
        
      # возьмем массив ключевых полей ССЫЛОЧНОЙ таблицы
      @key_fields = @{ $EXP_CFG{ TABLES }{ $ref_table }{ KEY_FIELDS } };

      $where = "";

      # обработаем все ключевые поля
      for ( $i = 0; $i < scalar @key_fields; $i++ )
      {
        $where .= $key_fields[ $i ] . " = '" . $rec{ $key_fields[ $i ] } .
                  "' AND ";
      }

      $where =~ s/\s*AND\s*$//;

      # ключ -- команда INSERT, значение -- условие WHERE для проверки
      # на дублирование 
      $SQL_commands{ $ref_table }{ $command } = $where;

      # DEBUG 
      print_debug_info( $command ) if $DEBUG;  # печатаем строку команды
    }
    else
    {
      ;  # что в этом случае делать?
    }
  }
  
  # DEBUG
  # print "Возврат из процедуры process_referenced_tables " .
  #       "для таблицы $table<br />\n";

  return;
}

# -----------------------------------------------------------------------------
# считывание файла конфигурации
# -----------------------------------------------------------------------------
sub read_config
{
  # параметр - путь к конфигурационному файлу
  my $config_file = shift;

  # массив для временного хранения имен и значений параметров конфигурации
  my @configuration = ();

  # имя и значение параметра
  my( $param_name, $param_value );

  # порядковый номер ссылки (кнопки) для вызова "быстрой" вставки текста;
  # нумерация ведется в пределах конкретного поля HTML-формы (для одного поля
  # может быть предусмотрено более одной "быстрой" вставки текста)
  my $hot_help_index;

  # порядковый номер содержательной части, той, которая вставляется в поле
  # формы, когда пользователь "кликает" эту ссылку (или кнопку);
  # нумерация ведется в пределах одной "быстрой" вставки текста (возможны
  # не только одинарные вставки, но и вызов нового окна браузера, в котором
  # отображается список фрагментов текста, из которого пользователь может
  # выбрать нужный фрагмент и "кликом" кнопки мыши вставить этот фрагмент
  # в поле HTML-формы)
  my $help_value_index;

  # начальная часть имени параметра (для параметров, привязанных к полям
  # базы данных, состоит из имени программного модуля и имени поля)
  my $module_field = "";          # запомненное значение
  my $current_module_field = "";  # значение в текущей строке конфиг. файла
    
  # открываем файл ...
  open( CONFIG, "< $config_file" ) or 
      die "Не удалось открыть файл $config_file. Ошибка: $!\n";

  # ... и читаем его построчно
  while( <CONFIG> )
  {
    chomp;          # уберем символ конца строки

    # отбрасываем пустые строки и строки, состоящие из пробелов и 
    # символов табуляции
    next if /^\s*$/;

    # комментарии должны начинаться символом "#" в первой позиции
    next if /^#/;

    # поскольку параметры в качестве своего значения могут иметь пустую
    # строку, представить которую в конфигурационном файле сложно
    # (а обременять пользователя какими-либо специальными приемами, типа
    # использования символа "\", не хотелось бы), то будем считать, что если
    # на строке находится только имя параметра (возможно, после него следуют
    # пробелы и символы табуляции), то его значением и будет пустая строка
    if ( /^(\S+)\s*$/ )
    {
      $param_name = $1;
      $param_value = '';
    }
    else
    {
      # замыкающие пробелы, если они есть, не берем
      # TODO. А если замыкающие пробелы все-таки нужны пользователю?
      #       Это может быть удобно при использовании системы быстрой вставки
      #       фрагмента текста в поле HTML-формы, чтобы избавить пользователя
      #       от необходимости вставлять пробел между фрагментами текста,
      #       используя клавиатуру.
      s/\s*$//;
      
      # делим строку на две части: первая часть - это наименование параметра,
      # она состоит из символов до первого пробела; вторая часть строки - 
      # это значение параметра, оно включает в себя всю остальную часть строки
      ( $param_name, $param_value ) = $_ =~ /^(\S+)\s+(.+)$/;
    }

    # если встретился первый из пары параметров, описывающих ссылку (кнопку)
    # для быстрой вставки фрагмента текста в поле HTML-формы, то проверим,
    # относится ли эта пара параметров к тому же полю, что и предыдущая
    # (если она уже была обработана)
    if ( $param_name =~ /HELP_(LINK|BTN)_TITLE$/ )
    {
      # возьмем первую часть имени параметра -- имя модуля и имя поля
      ( $current_module_field ) = $param_name =~ 
                                  /^(.+)_HELP_(LINK|BTN)_TITLE$/;
      # если параметр относится к тому же полю
      if ( $current_module_field eq $module_field )
      {
        $hot_help_index++;      # увеличим счетчик "быстрых" вставок
      }
      else                      # поле -- другое
      {
        # теперь текущим стало новое поле
        $module_field = $current_module_field;

        $hot_help_index = 1;    # для каждого поля -- своя нумерация
                                # "быстрых" вставок
      }
      # как только встретился параметр ...HELP_(LINK|BTN)_TITLE, мы должны
      # начинать отсчет параметров ...HELP_VALUE с начала, поскольку нумерация
      # самих фрагментов для "быстрой" вставки производится в пределах каждой
      # "быстрой" вставки
      $help_value_index = 1;

      # добавим к имени параметра порядковый номер, который изменяется
      # в пределах поля
      $param_name .= $hot_help_index;
    }
    # если встретился второй из пары параметров, описывающих ссылку (кнопку)
    # для быстрой вставки фрагмента текста в поле HTML-формы
    elsif ( $param_name =~ /HELP_VALUE$/ )
    {
      # добавим к имени параметра порядковый номер "быстрой" вставки, который
      # изменяется в пределах поля, и порядковый номер фрагмента текста
      $param_name .= $hot_help_index . "_" . $help_value_index;
      $help_value_index++;
    }

    # поместим имя и значение параметра в массив, который является заготовкой
    # для хеша
    push( @configuration, $param_name, $param_value );
  }
  # TODO Сделать проверку на предмет нарушения структуры параметров "быстрых"
  #      вставок. Например, есть параметр _TITLE, но ему не поставлен
  #      в соответствие ни один параметр _VALUE или, наоборот, есть _VALUE,
  #      но для него нет параметра _TITLE.
  
  close( CONFIG );

  return ( @configuration );
}

# -----------------------------------------------------------------------------
# считывание файла конфигурации экспорта/импорта
# -----------------------------------------------------------------------------
sub read_exp_config
{
  # параметр - путь к конфигурационному файлу
  my $config_file = shift;

  # имя и значение параметра конфигурации
  my( $param_name, $param_value );

  my %config;     # хеш-массив конфигурации экспорта/импорта
  my $line = 0;   # номер строки в конфиг. файле
  
  # список ключевых слов конфиг. файла (пока что не используется)
  # my @keywords = ( 'TABLE', 'KEY_FIELDS', 'CHECK_FIELDS', 'FIELDS',
  #                  'FOREIGN_KEY', 'TABLE_EXPORT', 'FOREIGN_KEYS_EXCLUDE',
  #                  'DEPENDENT_TABLES' );

  # параметр конфиг. файла (он может располагаться не только на одной строке
  # конфиг. файла, но и на двух и более строках, в последнем случае в конце
  # "незавершенной" строки должен быть символ "\")
  my $param;
  
  # признак того, что мы находимся внутри многострочного параметра
  my $inside_multiline = 0;

  my $table;              # имя таблицы
  my $ref_table;          # имя ссылочной таблицы
  my $f_key_name;         # имя внешнего ключа (в пределах данной таблицы)
  my @tables_order = ();  # список таблиц в порядке их следования
                          # в конфигурационном файле (он нужен для выполнения
                          # последовательной обработки команд вставки
                          # записей в таблицы с "уважением" внешних ключей)
  my @bib_rec_areas = (); # список таблиц, соответствующих областям 
                          # биб. описания
  my $error = 0;          # признак наличия ошибок в конфигурационном файле
      
  # открываем файл ...
  open( CONFIG, "< $config_file" ) or 
      die "Не удалось открыть файл $config_file. Ошибка: $!\n";

  # ... и читаем его построчно
  while( <CONFIG> )
  {
    $line++;        # номер строки в конфиг. файле
    chomp;          # уберем символ конца строки

    # отбрасываем пустые строки и строки, состоящие из пробелов и 
    # символов табуляции
    next if /^\s*$/;

    # комментарии должны начинаться символом "#" в первой позиции
    next if /^#/;

    s/\s*$//;   # замыкающие пробелы, если они есть, не берем
    s/^\s*//;   # на всякий случай удалим и лидирующие пробелы
        
    # если строка "незавершенная"
    if ( $_ =~ /\\$/ )
    {
      s/\\$//;   # уберем символ "\"
      
      # мы получили из файла НЕ первый фрагмент многострочного параметра
      if ( $inside_multiline )
      {
        $param .= ' ' . $_; # вставим пробел между фрагментами параметра
      }
      else   # мы получили из файла первый фрагмент многострочного параметра
      {
        $param = $_;        # начинаем формирование многострочного параметра
        $inside_multiline = 1;
      }  
 
      # параметр еще "не готов", не дошел до кондиции ("Бриллиантовая рука")
      next;
    }
    else
    # строка "завершенная" (единственная строка однострочного параметра или
    # последняя строка многострочного параметра)
    {
      if ( $inside_multiline ) # последняя строка многострочного параметра
      {
        $param .= ' ' . $_;    # вставим пробел между фрагментами параметра
        $inside_multiline = 0;
      }
      else                     # единственная строка однострочного параметра
      {
        $param = $_;           # однострочный параметр
      }  
    }

    # делим строку на две части: первая часть - это наименование параметра,
    # она состоит из символов до первого пробела; вторая часть строки - 
    # это значение параметра, оно включает в себя всю остальную часть строки
    ( $param_name, $param_value ) = $param =~ /^(\S+)\s+(.+)$/;

    if ( $param_name eq 'TABLE' )          # имя таблицы
    {
      $table = $param_value;
      push( @tables_order, $table );
    }
    elsif ( $param_name eq 'TABLE_NAME' )  # наименование таблицы
    {
      $config{ TABLES }{ $table }{ TABLE_NAME } = $param_value;
    }
    elsif ( $param_name eq 'KEY_FIELDS' )  # ключевые поля (первичный ключ)
    {
      # разорвем строку по символу "," (возможно, окруженному пробелами)
      # и ссылку на полученный массив запишем в гнездо хеш-массива
      # по текущему значению имени таблицы $table в качестве ключа
      $config{ TABLES }{ $table }{ KEY_FIELDS } =
             [ split( /\s*,\s*/, $param_value ) ];
    }
    # поля для проверки наличия записи в целевой БД
    elsif ( $param_name eq 'CHECK_FIELDS' )
    {
      $config{ TABLES }{ $table }{ CHECK_FIELDS } =
             [ split( /\s*,\s*/, $param_value ) ];
    }
    elsif ( $param_name eq 'FIELDS' )      # полный список всех полей
    {
      $config{ TABLES }{ $table }{ FIELDS } =
             [ split( /\s*,\s*/, $param_value ) ];
    }
    elsif ( $param_name eq 'FOREIGN_KEY' ) # внешний ключ
    {
      # сначала разделим параметр на компоненты: имена полей внешнего ключа,
      # имя ссылочной таблицы, имена полей в ссылочной таблице (они будут
      # записаны в переменные $1, $2 и $3)
      # ПРИМЕЧАНИЕ. В имени ссылочной таблицы может быть суффикс -- число 1
      #             или 2, поскольку таблица может иметь два внешних ключа,
      #             ссылающихся на одну таблицу.
      # ВАЖНО!!! При обработке составных строк (соединяемых символом "\")
      #          перед ключевым словом REFERENCES образуется два пробела,
      #          например: FOREIGN_KEY spec_mat_group_code  REFERENCES ...
      #          Используем НЕЖАДНЫЙ оператор /^(.+?)\s+... Если убрать
      #          знак "?", то жадный оператор захватывает также и один из двух
      #          символов пробела. При этом в целом регулярное выражение
      #          выполняется, только имя поля внешнего ключа дополняется
      #          в конце пробелом, в результате при обработке внешних ключей
      #          в процедуре export_process_referenced_tables() данный внешний
      #          ключ игнорируется, как-будто значение ключевого поля
      #          равно undef (NULL).
      $param_value =~ /^(.+?)\s+REFERENCES\s+(\S+)\s+\(\s*(.+)\s+\)$/;
      
      # имя внешнего ключа (оно может содержать цифру 1 или 2 в конце)
      # ПРИМЕЧАНИЕ. В большинстве случаев имя внешнего ключа совпадает
      #             с именем ссылочной таблицы. Только когда два внешних
      #             ключа ссылаются на одну и ту же таблицу, приходится
      #             использовать суффикс 1 или 2.
      # (внешних ключей может и не быть -- это не беда)
      $f_key_name = $2;

      # ВНИМАНИЕ! Ключевое слово конфиг. файла -- FOREIGN_KEY, 
      # а ключ хеш-массива -- FOREIGN_KEYS
      $config{ TABLES }{ $table }{ FOREIGN_KEYS }{ $f_key_name }
             { F_KEY_FIELDS } = [ split( /\s*,\s*/, $1 ) ];

      $config{ TABLES }{ $table }{ FOREIGN_KEYS }{ $f_key_name }
             { REF_FIELDS } = [ split( /\s*,\s*/, $3 ) ];

      $ref_table = $2;
      $ref_table =~ s/\d$//;  # если в конце имени есть цифра -- уберем ее

      $config{ TABLES }{ $table }{ FOREIGN_KEYS }{ $f_key_name }
             { REF_TABLE } = $ref_table;
    }
    # внешние ключи, которые нужно исключить из обработки
    elsif ( $param_name eq 'FOREIGN_KEYS_EXCLUDE' )
    {
      $config{ TABLES }{ $table }{ FOREIGN_KEYS_EXCLUDE } =
             [ split( /\s*,\s*/, $param_value ) ];
    }
    # список таблиц, зависящих от данной таблицы
    elsif ( $param_name eq 'DEPENDENT_TABLES' )
    {
      $config{ TABLES }{ $table }{ DEPENDENT_TABLES } =
             [ split( /\s*,\s*/, $param_value ) ];
    }
    # список полей, значения которых подлежат согласованию при импорте
    elsif ( $param_name eq 'ADJUSTABLE_FIELDS' )
    {
      $config{ TABLES }{ $table }{ ADJUSTABLE_FIELDS } =
             [ split( /\s*,\s*/, $param_value ) ];
    }
    # таблицу экспортировать не нужно
    elsif ( $param_name eq 'TABLE_EXPORT' )
    {
      if ( $param_value eq 'disabled' )
      {
        $config{ TABLES }{ $table }{ TABLE_EXPORT } = 'disabled';
      }
      else
      {
        $error = 1;

        # выводим сообщение об ошибке в лог
        print STDERR "Строка $line, параметр $param_name: " .
                     "ошибочное значение '$param_value'\n";
      }
    }
    elsif ( $param_name eq 'TABLE_IMPORT' )
    {
      if ( $param_value eq 'disabled' )
      {
        $config{ TABLES }{ $table }{ TABLE_IMPORT } = 'disabled';
      }
      else
      {
        $error = 1;

        # выводим сообщение об ошибке в лог
        print STDERR "Строка $line, параметр $param_name: " .
                     "ошибочное значение '$param_value'\n";
      }
    }
    elsif ( $param_name eq 'IMPORT_MODE' )
    {
      $config{ TABLES }{ $table }{ IMPORT_MODE } = $param_value;
    }
    elsif ( $param_name eq 'ADJUSTABLE_FIELDS_INCREASE' )
    {
      $config{ PARAMS }{ ADJUSTABLE_FIELDS_INCREASE } = $param_value;
    }
    else   # ошибочное наименование параметра
    {
      $error = 1;
      # выводим сообщение об ошибке в лог
      print STDERR "Строка $line: ошибочное наименование " .
                   "параметра $param_name\n";
    }
  }

  close( CONFIG );

  # упорядоченный список имен таблиц (так, как в конфиг. файле экспорта)
  $config{ TABLES_ORDER } = [ @tables_order ];

  if ( $error )
  {
    # выводим сообщение об ошибке в лог
    # TODO. В каких еще случаях имеет смысл указывать __LINE__ и __FILE__ ?
    print STDERR "Line " . __LINE__ . " at " . __FILE__ . ": " .
          "Ошибки в конфигурационном файле экспорта $config_file\n";
    die "Line " . __LINE__ . " at " . __FILE__ . ": " .
        "Ошибки в конфигурационном файле экспорта $config_file\n";
  }
  
  return ( \%config );
}

# -----------------------------------------------------------------------------
# получение русской буквы из ее числового представления
# -----------------------------------------------------------------------------
sub reveal_rus_letter
{
  # параметр
  my $letter = shift;       # русская буква

  my @letters;              # массив отдельных букв
  my $letter_num;           # порядковый номер русской буквы

  # если первый символ -- "_", то это русская буква, замененная числом
  if ( $letter =~ /^_/ )
  {
    # отбросим символ подчеркивания, который используется при маскировке
    # русских букв (путем замены их порядковыми номерами)
    ( $letter_num ) = $letter =~ /^_(\d+)/;
    
    # разделим "русскую" строку-алфавит на отдельные буквы
    # (символ-разделитель -- пробел)
    @letters = split( /\s+/, $CFG{ STRING_LETTERS_RUS } );

    $letter = $letters[ $letter_num - 1 ];  # нумерация букв -- с 1
  }

  if ( $CFG{ CHARSET } eq "UTF-8" )
  {
    use Encode;

    # придадим этой символьной строке флаг utf-8 (он не является обязательным
    # для английских букв, но если $letter -- английская буква, то вреда нет)
    $letter = decode( "UTF-8", $letter );
  }  

  return $letter;
}

# -----------------------------------------------------------------------------
# экранирование кавычек при подготовке значений переменных для работы с БД
# -----------------------------------------------------------------------------
sub screen_qts
{
  # параметры: ссылки на обрабатываемые переменные

  my $tmp;

  foreach $tmp ( @_ )
  {
    $$tmp =~ s/^\s*//;      # уберем лидирующие ...
    $$tmp =~ s/\s*$//;      # ... и замыкающие пробелы
    $$tmp =~ s/\'/\'\'/g;   # см. комментарий в функции make_cmd
  }

  return;
}

# -----------------------------------------------------------------------------
# непосредственное обновление записи в БД
# -----------------------------------------------------------------------------
sub update_rec
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            ссылка на функцию для формирования верхней части окна
  #              со списком "команд" для пользователя (create_top);
  #            ссылка на функцию для проверки значений, введенных в поля формы
  #              (check_param);
  #            ссылка на функцию для формирования строки команды для работы 
  #              с БД (make_command);
  #            ссылка на функцию для вывода дополнительной информации 
  #              (print_add_info)

  my $query = $prms{ query }; # для удобства

  # имя окна браузера для вывода HTML-страницы
  my $target_win = $query->param( 'target_win' );
  $target_win = "_self" unless $target_win;

  my( $conn, $result );     # для работы с БД
  my $command;              # строка команды для обновления записи

  # формируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => $target_win );

  open_top();                  # начинаем оформление верхней части окна
  &{ $prms{ create_top } }();  # формируем верхнюю часть окна со списком
                               # "команд" для пользователя
  close_top();                 # завершаем оформление верхней части окна

  open_bottom();               # начинаем оформление нижней части окна

  # выведем дополнительную информацию на экран
  &{ $prms{ print_add_info } }() if defined( $prms{ print_add_info } );

  # если проверка введенных значений прошла успешно, выполним обновление
  # ПРИМЕЧАНИЕ. Обновляется только ОДНА запись.
  if ( &{ $prms{ check_param } }() )
  {
    # сформируем строку-команду для обновления записи
    $command = &{ $prms{ make_command } }( 'UPDATE' );

    # DEBUG 
    print_debug_info( $command ) if $DEBUG;  # печатаем строку команды

    $conn = exec_connect_db();         # подключаемся к БД
    $result = $conn->exec( $command ); # выполним команду обновления записи в БД

    # если произошла ошибка при обновлении записей в базе данных
    if ( PGRES_COMMAND_OK ne $result->resultStatus )
    {
      # сообщение для пользователя
      print "<p class=\"error\">$CFG{ ERROR_UPDATE }</p>\n";
      print STDERR $command . "\n";             # выводим строку команды в лог
      die $conn->errorMessage;
    }

    # проверим число фактически обновленных записей
    if ( $result->cmdTuples == 1 )
    {
      print "<p class=\"info\">";
      print "Запись в базе данных обновлена</p>\n";
    }
    elsif ( $result->cmdTuples == 0 )
    {
      print "<p class=\"info\">";
      print "Запись в базе данных НЕ обновлена</p>\n";
    }
    else          # ( $result->cmdTuples > 1 )
    {
      print "<p class=\"error\">";
      print "В базе данных обновлено " . $result->cmdTuples .
            " записей. Это ошибка! Обратитесь к программисту</p>\n";
    }
  }  

  close_bottom();      # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

# -----------------------------------------------------------------------------
# просмотр одной записи в виде формы
# -----------------------------------------------------------------------------
sub view_rec
{
  # используем именованные параметры
  # (они передаются парами: имя параметра => значение параметра)
  my %prms = @_;

  # параметры: CGI-объект (query);
  #            имя функции для формирования верхнего блока в окне со списком
  #              "команд" для пользователя (create_top);
  #            имя функции для организации формы (make_form);
  #            URL скрипта для обработки формы (action);
  #            целевое окно на экране (target);
  #            имя кнопки submit (submit_name);
  #            надпись на кнопке submit (submit_value);
  #            строка команды для выборки записи из БД (command);
  #            строка сообщения об ошибке при выборке записи из БД (error);
  #            флаг, разрешающий или запрещающий выполнение операции
  #            обновления записи (значения: 1 или 0) (can_update)

  # ПРИМЕЧАНИЕ. Если необходимо создать более одной кнопки, то параметры
  #             submit_name и submit_value должны представлять собой
  #             ссылки на массивы.

  my $query = $prms{ query };

  my( $conn, $result );           # для работы с БД
  my @row;                        # для хранения одной записи из выборки
  my $i;

  # если этот параметр не передан, то по умолчанию запретим выполнять
  # обновление записи в таблице БД
  $prms{ can_update } = 0 if ( ! exists $prms{ can_update } );

  # формируем HTTP- и HTML-заголовки
  http_html_headers( query => $query, target => $prms{ target } );

  open_top();          # начинаем оформление верхней части окна
  &{ $prms{ create_top } }();  # формируем верхнюю часть окна со списком
                       # "команд" для пользователя
  close_top();         # завершаем оформление верхней части окна

  open_bottom();       # начинаем оформление нижней части окна

  # DEBUG 
  print_debug_info( $prms{ command } ) if $DEBUG;  # печатаем строку команды

  $conn = exec_connect_db();                   # подключаемся к БД
  $result = $conn->exec( $prms{ command } );   # выполняем выборку из БД

  # если произошла ошибка при выборке из базы данных
  if ( PGRES_TUPLES_OK ne $result->resultStatus )
  {
    # сообщение для пользователя
    print "<p class=\"error\">$CFG{ ERROR_SELECT }</p>\n";
    print STDERR $prms{ command } . "\n";     # выводим строку команды в лог
    die $conn->errorMessage;
  }

  # проверим число выбранных записей
  if ( $result->ntuples == 0 )
  {
    print "<p class=\"info\">";
    print "Записей, соответствующих указанному критерию, " .
          "нет в базе данных</p>\n";
  }
  elsif ( $result->ntuples > 1 )
  {
    print "<p class=\"error\">";
    print $prms{ error } . "</p>\n";  # должна быть ОДНА запись
  }
  else
  {
    @row = $result->fetchrow;  # берем запись из выборки

    # ПРИМЕЧАНИЕ. См. комментарий в функции do_add().
    # Если при выполнении корректировки допущены ошибки при заполнении
    # полей формы, то сообщение об этом будет появляться в чистом окне.
    # Если же убрать параметр action, то сообщение будет выведено
    # внизу формы.
    print $query->start_form( -action => $prms{ action },
                              -target => $prms{ target }
                            ), "\n";
    # сформируем исходный код функции на языке JavaScript, которая разблокирует
    # заблокированные поля HTML-формы (если таковые имеются) -- иначе их 
    # значения не будут отправлены web-серверу
    create_enable_elements_func();

    # формируем поля формы
    &{ $prms{ make_form } }( \@row, $result );

    # кнопку submit вынесем за пределы функции make_form() ради ее 
    # универсальности

    # кнопки типа submit будем формировать только в том случае, если флаг
    # $prms{ can_update } разрешает выполнять обновление записи в таблице БД
    if ( $prms{ can_update } )
    {
      # если передано более одной кнопки, то сформируем их все
      # ПРИМЕЧАНИЕ. В массивах $prms{ submit_name } и $prms{ submit_value }
      #             должно быть одинаковое число элементов. Проверку соблюдения
      #             этого условия не делаем: считаем, что программист
      #             не ошибется.
      if ( ref( $prms{ submit_name } ) eq 'ARRAY' )
      {
        for( $i = 0; $i < scalar @{ $prms{ submit_name } }; $i++ )
        {
          print $query->submit( -name => ${ $prms{ submit_name } }[ $i ],
                                -value => ${ $prms{ submit_value } }[ $i ],
                                -class => 'submit',
                                -onclick => "enable_elements()"
                              ), "&nbsp;\n";
        }
      }
      else                # кнопка всего одна
      {
        print $query->submit( -name => $prms{ submit_name },
                              -value => $prms{ submit_value },
                              -class => 'submit',
                              -onclick => "enable_elements()"
                            ), "\n";
      }
    }
    print $query->end_form();
  }

  close_bottom();         # завершаем оформление нижней части окна
  print $query->end_html();
  return ( 0 );
}

END {   };

1;
